SDL_AddAtomicInt

Function SDL_AddAtomicInt 

pub unsafe extern "C" fn SDL_AddAtomicInt(
    a: *mut SDL_AtomicInt,
    v: c_int,
) -> c_int
Add to an atomic variable.

This function also acts as a full memory barrier.

***Note: If you don’t know what this function is for, you shouldn’t use

it!***

Parameter: a a pointer to an SDL_AtomicInt variable to be modified.

Parameter: v the desired value to add.

Returns: the previous value of the atomic variable.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_AtomicDecRef

See Also: SDL_AtomicIncRef