SDL_AddGamepadMappingsFromFile

Function SDL_AddGamepadMappingsFromFile 

pub unsafe extern "C" fn SDL_AddGamepadMappingsFromFile(
    file: *const c_char,
) -> c_int
Load a set of gamepad mappings from a file.

You can call this function several times, if needed, to load different database files.

If a new mapping is loaded for an already known gamepad GUID, the later version will overwrite the one currently loaded.

Any new mappings for already plugged in controllers will generate SDL_EVENT_GAMEPAD_ADDED events.

Mappings not belonging to the current platform or with no platform field specified will be ignored (i.e. mappings for Linux will be ignored in Windows, etc).

Parameter: file the mappings file to load. Returns: the number of mappings added or -1 on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_AddGamepadMapping See Also: SDL_AddGamepadMappingsFromIO See Also: SDL_GetGamepadMapping See Also: SDL_GetGamepadMappingForGUID See Also: SDL_HINT_GAMECONTROLLERCONFIG See Also: SDL_HINT_GAMECONTROLLERCONFIG_FILE See Also: SDL_EVENT_GAMEPAD_ADDED