SDL_BeginGPUCopyPass

Function SDL_BeginGPUCopyPass 

pub unsafe extern "C" fn SDL_BeginGPUCopyPass(
    command_buffer: *mut SDL_GPUCommandBuffer,
) -> *mut SDL_GPUCopyPass
Begins a copy pass on a command buffer.

All operations related to copying to or from buffers or textures take place inside a copy pass. You must not begin another copy pass, or a render pass or compute pass before ending the copy pass.

Parameter: command_buffer a command buffer. Returns: a copy pass handle.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_EndGPUCopyPass