SDL_BindGPUComputeStorageTextures

Function SDL_BindGPUComputeStorageTextures 

pub unsafe extern "C" fn SDL_BindGPUComputeStorageTextures(
    compute_pass: *mut SDL_GPUComputePass,
    first_slot: Uint32,
    storage_textures: *const *mut SDL_GPUTexture,
    num_bindings: Uint32,
)
Binds storage textures as readonly for use on the compute pipeline.

These textures must have been created with SDL_GPU_TEXTUREUSAGE_COMPUTE_STORAGE_READ.

Be sure your shader is set up according to the requirements documented in SDL_CreateGPUComputePipeline().

Parameter: compute_pass a compute pass handle. Parameter: first_slot the compute storage texture slot to begin binding from. Parameter: storage_textures an array of storage textures. Parameter: num_bindings the number of storage textures to bind from the array.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateGPUComputePipeline