pub unsafe extern "C" fn SDL_BindGPUGraphicsPipeline(
render_pass: *mut SDL_GPURenderPass,
graphics_pipeline: *mut SDL_GPUGraphicsPipeline,
)Expand description
Binds a graphics pipeline on a render pass to be used in rendering.
A graphics pipeline must be bound before making any draw calls.
Parameter: render_pass a render pass handle. Parameter: graphics_pipeline the graphics pipeline to bind.
Available Since: This function is available since SDL 3.2.0.