SDL_CancelGPUCommandBuffer

Function SDL_CancelGPUCommandBuffer 

pub unsafe extern "C" fn SDL_CancelGPUCommandBuffer(
    command_buffer: *mut SDL_GPUCommandBuffer,
) -> bool
Cancels a command buffer.

None of the enqueued commands are executed.

It is an error to call this function after a swapchain texture has been acquired.

This must be called from the thread the command buffer was acquired on.

You must not reference the command buffer after calling this function.

Parameter: command_buffer a command buffer. Returns: true on success, false on error; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_WaitAndAcquireGPUSwapchainTexture See Also: SDL_AcquireGPUCommandBuffer See Also: SDL_AcquireGPUSwapchainTexture