SDL_CleanupTLS

Function SDL_CleanupTLS 

pub unsafe extern "C" fn SDL_CleanupTLS()
Cleanup all TLS data for this thread.

If you are creating your threads outside of SDL and then calling SDL functions, you should call this function before your thread exits, to properly clean up SDL memory.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.