pub unsafe extern "C" fn SDL_ConvertEventToRenderCoordinates(
renderer: *mut SDL_Renderer,
event: *mut SDL_Event,
) -> boolExpand description
Convert the coordinates in an event to render coordinates.
This takes into account several states:
- The window dimensions.
- The logical presentation settings (SDL_SetRenderLogicalPresentation)
- The scale (SDL_SetRenderScale)
- The viewport (SDL_SetRenderViewport)
Various event types are converted with this function: mouse, touch, pen, etc.
Touch coordinates are converted from normalized coordinates in the window to non-normalized rendering coordinates.
Relative mouse coordinates (xrel and yrel event fields) are also converted. Applications that do not want these fields converted should use SDL_RenderCoordinatesFromWindow() on the specific event fields instead of converting the entire event structure.
Once converted, coordinates may be outside the rendering area.
Parameter: renderer the rendering context. Parameter: event the event to modify. Returns: true if the event is converted or doesn’t need conversion, or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_RenderCoordinatesFromWindow