SDL_ConvertPixelsAndColorspace

Function SDL_ConvertPixelsAndColorspace 

pub unsafe extern "C" fn SDL_ConvertPixelsAndColorspace(
    width: c_int,
    height: c_int,
    src_format: SDL_PixelFormat,
    src_colorspace: SDL_Colorspace,
    src_properties: SDL_PropertiesID,
    src: *const c_void,
    src_pitch: c_int,
    dst_format: SDL_PixelFormat,
    dst_colorspace: SDL_Colorspace,
    dst_properties: SDL_PropertiesID,
    dst: *mut c_void,
    dst_pitch: c_int,
) -> bool
Copy a block of pixels of one format and colorspace to another format and colorspace.

Parameter: width the width of the block to copy, in pixels. Parameter: height the height of the block to copy, in pixels. Parameter: src_format an SDL_PixelFormat value of the src pixels format. Parameter: src_colorspace an SDL_Colorspace value describing the colorspace of the src pixels. Parameter: src_properties an SDL_PropertiesID with additional source color properties, or 0. Parameter: src a pointer to the source pixels. Parameter: src_pitch the pitch of the source pixels, in bytes. Parameter: dst_format an SDL_PixelFormat value of the dst pixels format. Parameter: dst_colorspace an SDL_Colorspace value describing the colorspace of the dst pixels. Parameter: dst_properties an SDL_PropertiesID with additional destination color properties, or 0. Parameter: dst a pointer to be filled in with new pixel data. Parameter: dst_pitch the pitch of the destination pixels, in bytes. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: The same destination pixels should not be used from two threads at once. It is safe to use the same source pixels from multiple threads.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_ConvertPixels