pub unsafe extern "C" fn SDL_ConvertSurface(
surface: *mut SDL_Surface,
format: SDL_PixelFormat,
) -> *mut SDL_SurfaceExpand description
Copy an existing surface to a new surface of the specified format.
This function is used to optimize images for faster repeat blitting. This is accomplished by converting the original and storing the result as a new surface. The new, optimized surface can then be used as the source for future blits, making them faster.
If you are converting to an indexed surface and want to map colors to a palette, you can use SDL_ConvertSurfaceAndColorspace() instead.
If the original surface has alternate images, the new surface will have a reference to them as well.
Parameter: surface the existing SDL_Surface structure to convert. Parameter: format the new pixel format. Returns: the new SDL_Surface structure that is created or NULL on failure; call SDL_GetError() for more information.
Thread Safety: This function can be called on different threads with different surfaces.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_ConvertSurfaceAndColorspace See Also: SDL_DestroySurface