SDL_CopyGPUBufferToBuffer

Function SDL_CopyGPUBufferToBuffer 

pub unsafe extern "C" fn SDL_CopyGPUBufferToBuffer(
    copy_pass: *mut SDL_GPUCopyPass,
    source: *const SDL_GPUBufferLocation,
    destination: *const SDL_GPUBufferLocation,
    size: Uint32,
    cycle: bool,
)
Performs a buffer-to-buffer copy.

This copy occurs on the GPU timeline. You may assume the copy has finished in subsequent commands.

Parameter: copy_pass a copy pass handle. Parameter: source the buffer and offset to copy from. Parameter: destination the buffer and offset to copy to. Parameter: size the length of the buffer to copy. Parameter: cycle if true, cycles the destination buffer if it is already bound, otherwise overwrites the data.

Available Since: This function is available since SDL 3.2.0.