pub unsafe extern "C" fn SDL_CreateDirectory(
path: *const c_char,
) -> boolExpand description
Create a directory, and any missing parent directories.
This reports success if path already exists as a directory.
If parent directories are missing, it will also create them. Note that if this fails, it will not remove any parent directories it already made.
Parameter: path the path of the directory to create. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.