SDL_CreateEnvironment

Function SDL_CreateEnvironment 

pub unsafe extern "C" fn SDL_CreateEnvironment(
    populated: bool,
) -> *mut SDL_Environment
Create a set of environment variables

Parameter: populated true to initialize it from the C runtime environment, false to create an empty environment. Returns: a pointer to the new environment or NULL on failure; call SDL_GetError() for more information.

Thread Safety: If populated is false, it is safe to call this function from any thread, otherwise it is safe if no other threads are calling setenv() or unsetenv()

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetEnvironmentVariable See Also: SDL_GetEnvironmentVariables See Also: SDL_SetEnvironmentVariable See Also: SDL_UnsetEnvironmentVariable See Also: SDL_DestroyEnvironment