SDL_CreateGPUGraphicsPipeline

Function SDL_CreateGPUGraphicsPipeline 

pub unsafe extern "C" fn SDL_CreateGPUGraphicsPipeline(
    device: *mut SDL_GPUDevice,
    createinfo: *const SDL_GPUGraphicsPipelineCreateInfo,
) -> *mut SDL_GPUGraphicsPipeline
Creates a pipeline object to be used in a graphics workflow.

There are optional properties that can be provided through props. These are the supported properties:

  • SDL_PROP_GPU_GRAPHICSPIPELINE_CREATE_NAME_STRING: a name that can be displayed in debugging tools.

Parameter: device a GPU Context. Parameter: createinfo a struct describing the state of the graphics pipeline to create. Returns: a graphics pipeline object on success, or NULL on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateGPUShader See Also: SDL_BindGPUGraphicsPipeline See Also: SDL_ReleaseGPUGraphicsPipeline