SDL_CreateHapticEffect

Function SDL_CreateHapticEffect 

pub unsafe extern "C" fn SDL_CreateHapticEffect(
    haptic: *mut SDL_Haptic,
    effect: *const SDL_HapticEffect,
) -> SDL_HapticEffectID
Create a new haptic effect on a specified device.

Parameter: haptic an SDL_Haptic device to create the effect on. Parameter: effect an SDL_HapticEffect structure containing the properties of the effect to create. Returns: the ID of the effect on success or -1 on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_DestroyHapticEffect See Also: SDL_RunHapticEffect See Also: SDL_UpdateHapticEffect