SDL_CreateProcess

Function SDL_CreateProcess 

pub unsafe extern "C" fn SDL_CreateProcess(
    args: *const *const c_char,
    pipe_stdio: bool,
) -> *mut SDL_Process
Create a new process.

The path to the executable is supplied in args[0]. args[1..N] are additional arguments passed on the command line of the new process, and the argument list should be terminated with a NULL, e.g.:

const char *args[] = { "myprogram", "argument", NULL };

Setting pipe_stdio to true is equivalent to setting SDL_PROP_PROCESS_CREATE_STDIN_NUMBER and SDL_PROP_PROCESS_CREATE_STDOUT_NUMBER to SDL_PROCESS_STDIO_APP, and will allow the use of SDL_ReadProcess() or SDL_GetProcessInput() and SDL_GetProcessOutput().

See SDL_CreateProcessWithProperties() for more details.

Parameter: args the path and arguments for the new process. Parameter: pipe_stdio true to create pipes to the process’s standard input and from the process’s standard output, false for the process to have no input and inherit the application’s standard output. Returns: the newly created and running process, or NULL if the process couldn’t be created.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateProcessWithProperties See Also: SDL_GetProcessProperties See Also: SDL_ReadProcess See Also: SDL_GetProcessInput See Also: SDL_GetProcessOutput See Also: SDL_KillProcess See Also: SDL_WaitProcess See Also: SDL_DestroyProcess