SDL_CreateProperties

Function SDL_CreateProperties 

pub unsafe extern "C" fn SDL_CreateProperties() -> SDL_PropertiesID
Create a group of properties.

All properties are automatically destroyed when SDL_Quit() is called.

Returns: an ID for a new group of properties, or 0 on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_DestroyProperties