pub unsafe extern "C" fn SDL_CreateSoftwareRenderer(
surface: *mut SDL_Surface,
) -> *mut SDL_RendererExpand description
Create a 2D software rendering context for a surface.
Two other API which can be used to create SDL_Renderer: SDL_CreateRenderer() and SDL_CreateWindowAndRenderer(). These can also create a software renderer, but they are intended to be used with an SDL_Window as the final destination and not an SDL_Surface.
Parameter: surface the SDL_Surface structure representing the surface where rendering is done. Returns: a valid rendering context or NULL if there was an error; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_DestroyRenderer