SDL_CreateTexture

Function SDL_CreateTexture 

pub unsafe extern "C" fn SDL_CreateTexture(
    renderer: *mut SDL_Renderer,
    format: SDL_PixelFormat,
    access: SDL_TextureAccess,
    w: c_int,
    h: c_int,
) -> *mut SDL_Texture
Create a texture for a rendering context.

The contents of a texture when first created are not defined.

Parameter: renderer the rendering context. Parameter: format one of the enumerated values in SDL_PixelFormat. Parameter: access one of the enumerated values in SDL_TextureAccess. Parameter: w the width of the texture in pixels. Parameter: h the height of the texture in pixels. Returns: the created texture or NULL on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateTextureFromSurface See Also: SDL_CreateTextureWithProperties See Also: SDL_DestroyTexture See Also: SDL_GetTextureSize See Also: SDL_UpdateTexture