SDL_CreateTextureFromSurface

Function SDL_CreateTextureFromSurface 

pub unsafe extern "C" fn SDL_CreateTextureFromSurface(
    renderer: *mut SDL_Renderer,
    surface: *mut SDL_Surface,
) -> *mut SDL_Texture
Create a texture from an existing surface.

The surface is not modified or freed by this function.

The SDL_TextureAccess hint for the created texture is SDL_TEXTUREACCESS_STATIC.

The pixel format of the created texture may be different from the pixel format of the surface, and can be queried using the SDL_PROP_TEXTURE_FORMAT_NUMBER property.

Parameter: renderer the rendering context. Parameter: surface the SDL_Surface structure containing pixel data used to fill the texture. Returns: the created texture or NULL on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateTexture See Also: SDL_CreateTextureWithProperties See Also: SDL_DestroyTexture