SDL_CreateThreadRuntime

Function SDL_CreateThreadRuntime 

pub unsafe extern "C" fn SDL_CreateThreadRuntime(
    fn_: SDL_ThreadFunction,
    name: *const c_char,
    data: *mut c_void,
    pfnBeginThread: SDL_FunctionPointer,
    pfnEndThread: SDL_FunctionPointer,
) -> *mut SDL_Thread
The actual entry point for SDL_CreateThread.

Parameter: fn the SDL_ThreadFunction function to call in the new thread Parameter: name the name of the thread Parameter: data a pointer that is passed to fn Parameter: pfnBeginThread the C runtime’s _beginthreadex (or whatnot). Can be NULL. Parameter: pfnEndThread the C runtime’s _endthreadex (or whatnot). Can be NULL. Returns: an opaque pointer to the new thread object on success, NULL if the new thread could not be created; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.