SDL_CreateThreadWithPropertiesRuntime

Function SDL_CreateThreadWithPropertiesRuntime 

pub unsafe extern "C" fn SDL_CreateThreadWithPropertiesRuntime(
    props: SDL_PropertiesID,
    pfnBeginThread: SDL_FunctionPointer,
    pfnEndThread: SDL_FunctionPointer,
) -> *mut SDL_Thread
The actual entry point for SDL_CreateThreadWithProperties.

Parameter: props the properties to use Parameter: pfnBeginThread the C runtime’s _beginthreadex (or whatnot). Can be NULL. Parameter: pfnEndThread the C runtime’s _endthreadex (or whatnot). Can be NULL. Returns: an opaque pointer to the new thread object on success, NULL if the new thread could not be created; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.