SDL_DestroyWindow

Function SDL_DestroyWindow 

pub unsafe extern "C" fn SDL_DestroyWindow(window: *mut SDL_Window)
Destroy a window.

Any child windows owned by the window will be recursively destroyed as well.

Note that on some platforms, the visible window may not actually be removed from the screen until the SDL event loop is pumped again, even though the SDL_Window is no longer valid after this call.

Parameter: window the window to destroy.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreatePopupWindow See Also: SDL_CreateWindow See Also: SDL_CreateWindowWithProperties