SDL_DispatchGPUCompute

Function SDL_DispatchGPUCompute 

pub unsafe extern "C" fn SDL_DispatchGPUCompute(
    compute_pass: *mut SDL_GPUComputePass,
    groupcount_x: Uint32,
    groupcount_y: Uint32,
    groupcount_z: Uint32,
)
Dispatches compute work.

You must not call this function before binding a compute pipeline.

A VERY IMPORTANT NOTE If you dispatch multiple times in a compute pass, and the dispatches write to the same resource region as each other, there is no guarantee of which order the writes will occur. If the write order matters, you MUST end the compute pass and begin another one.

Parameter: compute_pass a compute pass handle. Parameter: groupcount_x number of local workgroups to dispatch in the X dimension. Parameter: groupcount_y number of local workgroups to dispatch in the Y dimension. Parameter: groupcount_z number of local workgroups to dispatch in the Z dimension.

Available Since: This function is available since SDL 3.2.0.