SDL_FilterEvents

Function SDL_FilterEvents 

pub unsafe extern "C" fn SDL_FilterEvents(
    filter: SDL_EventFilter,
    userdata: *mut c_void,
)
Run a specific filter function on the current event queue, removing any events for which the filter returns false.

See SDL_SetEventFilter() for more information. Unlike SDL_SetEventFilter(), this function does not change the filter permanently, it only uses the supplied filter until this function returns.

Parameter: filter the SDL_EventFilter function to call when an event happens. Parameter: userdata a pointer that is passed to filter.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetEventFilter See Also: SDL_SetEventFilter