pub unsafe extern "C" fn SDL_GL_CreateContext(
window: *mut SDL_Window,
) -> SDL_GLContextExpand description
Create an OpenGL context for an OpenGL window, and make it current.
The OpenGL context will be created with the current states set through SDL_GL_SetAttribute().
The SDL_Window specified must have been created with the SDL_WINDOW_OPENGL flag, or context creation will fail.
Windows users new to OpenGL should note that, for historical reasons, GL functions added after OpenGL version 1.1 are not available by default. Those functions must be loaded at run-time, either with an OpenGL extension-handling library or with SDL_GL_GetProcAddress() and its related functions.
SDL_GLContext is opaque to the application.
Parameter: window the window to associate with the context.
Returns: the OpenGL context associated with window or NULL on failure;
call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GL_DestroyContext See Also: SDL_GL_MakeCurrent