pub unsafe extern "C" fn SDL_GL_LoadLibrary(
path: *const c_char,
) -> boolExpand description
Dynamically load an OpenGL library.
This should be done after initializing the video driver, but before creating any OpenGL windows. If no OpenGL library is loaded, the default library will be loaded upon creation of the first OpenGL window.
If you do this, you need to retrieve all of the GL functions used in your program from the dynamic library using SDL_GL_GetProcAddress().
Parameter: path the platform dependent OpenGL library name, or NULL to open the default OpenGL library. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GL_GetProcAddress See Also: SDL_GL_UnloadLibrary