SDL_GL_SetAttribute

Function SDL_GL_SetAttribute 

pub unsafe extern "C" fn SDL_GL_SetAttribute(
    attr: SDL_GLAttr,
    value: c_int,
) -> bool
Set an OpenGL window attribute before window creation.

This function sets the OpenGL attribute attr to value. The requested attributes should be set before creating an OpenGL window. You should use SDL_GL_GetAttribute() to check the values after creating the OpenGL context, since the values obtained can differ from the requested ones.

Parameter: attr an enum value specifying the OpenGL attribute to set. Parameter: value the desired value for the attribute. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GL_CreateContext See Also: SDL_GL_GetAttribute See Also: SDL_GL_ResetAttributes