SDL_GetAtomicInt

Function SDL_GetAtomicInt 

pub unsafe extern "C" fn SDL_GetAtomicInt(
    a: *mut SDL_AtomicInt,
) -> c_int
Get the value of an atomic variable.

Note: If you don’t know what this function is for, you shouldn’t use it!

Parameter: a a pointer to an SDL_AtomicInt variable. Returns: the current value of an atomic variable.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetAtomicInt