SDL_GetAudioStreamDevice

Function SDL_GetAudioStreamDevice 

pub unsafe extern "C" fn SDL_GetAudioStreamDevice(
    stream: *mut SDL_AudioStream,
) -> SDL_AudioDeviceID
Query an audio stream for its currently-bound device.

This reports the logical audio device that an audio stream is currently bound to.

If not bound, or invalid, this returns zero, which is not a valid device ID.

Parameter: stream the audio stream to query. Returns: the bound audio device, or 0 if not bound or invalid.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_BindAudioStream See Also: SDL_BindAudioStreams