SDL_GetCameraDriver

Function SDL_GetCameraDriver 

pub unsafe extern "C" fn SDL_GetCameraDriver(
    index: c_int,
) -> *const c_char
Use this function to get the name of a built in camera driver.

The list of camera drivers is given in the order that they are normally initialized by default; the drivers that seem more reasonable to choose first (as far as the SDL developers believe) are earlier in the list.

The names of drivers are all simple, low-ASCII identifiers, like “v4l2”, “coremedia” or “android”. These never have Unicode characters, and are not meant to be proper names.

Parameter: index the index of the camera driver; the value ranges from 0 to SDL_GetNumCameraDrivers() - 1. Returns: the name of the camera driver at the requested index, or NULL if an invalid index was specified.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetNumCameraDrivers