pub unsafe extern "C" fn SDL_GetCurrentRenderOutputSize(
renderer: *mut SDL_Renderer,
w: *mut c_int,
h: *mut c_int,
) -> boolExpand description
Get the current output size in pixels of a rendering context.
If a rendering target is active, this will return the size of the rendering target in pixels, otherwise return the value of SDL_GetRenderOutputSize().
Rendering target or not, the output will be adjusted by the current logical presentation state, dictated by SDL_SetRenderLogicalPresentation().
Parameter: renderer the rendering context. Parameter: w a pointer filled in with the current width. Parameter: h a pointer filled in with the current height. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetRenderOutputSize