pub unsafe extern "C" fn SDL_GetCurrentThreadID() -> SDL_ThreadIDExpand description
Get the thread identifier for the current thread.
This thread identifier is as reported by the underlying operating system. If SDL is running on a platform that does not support threads the return value will always be zero.
This function also returns a valid thread ID when called from the main thread.
Returns: the ID of the current thread.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetThreadID