SDL_GetCurrentTime

Function SDL_GetCurrentTime 

pub unsafe extern "C" fn SDL_GetCurrentTime(
    ticks: *mut SDL_Time,
) -> bool
Gets the current value of the system realtime clock in nanoseconds since Jan 1, 1970 in Universal Coordinated Time (UTC).

Parameter: ticks the SDL_Time to hold the returned tick count. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.