SDL_GetDefaultTextureScaleMode

Function SDL_GetDefaultTextureScaleMode 

pub unsafe extern "C" fn SDL_GetDefaultTextureScaleMode(
    renderer: *mut SDL_Renderer,
    scale_mode: *mut SDL_ScaleMode,
) -> bool
Get default texture scale mode of the given renderer.

Parameter: renderer the renderer to get data from. Parameter: scale_mode a SDL_ScaleMode filled with current default scale mode. See SDL_SetDefaultTextureScaleMode() for the meaning of the value. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.4.0.

See Also: SDL_SetDefaultTextureScaleMode