SDL_GetDisplayForRect

Function SDL_GetDisplayForRect 

pub unsafe extern "C" fn SDL_GetDisplayForRect(
    rect: *const SDL_Rect,
) -> SDL_DisplayID
Get the display primarily containing a rect.

Parameter: rect the rect to query. Returns: the instance ID of the display entirely containing the rect or closest to the center of the rect on success or 0 on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetDisplayBounds See Also: SDL_GetDisplays