SDL_GetDisplayForWindow

Function SDL_GetDisplayForWindow 

pub unsafe extern "C" fn SDL_GetDisplayForWindow(
    window: *mut SDL_Window,
) -> SDL_DisplayID
Get the display associated with a window.

Parameter: window the window to query. Returns: the instance ID of the display containing the center of the window on success or 0 on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetDisplayBounds See Also: SDL_GetDisplays