pub unsafe extern "C" fn SDL_GetEnvironment() -> *mut SDL_EnvironmentExpand description
Get the process environment.
This is initialized at application start and is not affected by setenv() and unsetenv() calls after that point. Use SDL_SetEnvironmentVariable() and SDL_UnsetEnvironmentVariable() if you want to modify this environment, or SDL_setenv_unsafe() or SDL_unsetenv_unsafe() if you want changes to persist in the C runtime environment after SDL_Quit().
Returns: a pointer to the environment for the process or NULL on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetEnvironmentVariable See Also: SDL_GetEnvironmentVariables See Also: SDL_SetEnvironmentVariable See Also: SDL_UnsetEnvironmentVariable