SDL_GetFullscreenDisplayModes

Function SDL_GetFullscreenDisplayModes 

pub unsafe extern "C" fn SDL_GetFullscreenDisplayModes(
    displayID: SDL_DisplayID,
    count: *mut c_int,
) -> *mut *mut SDL_DisplayMode
Get a list of fullscreen display modes available on a display.

The display modes are sorted in this priority:

  • w -> largest to smallest
  • h -> largest to smallest
  • bits per pixel -> more colors to fewer colors
  • packed pixel layout -> largest to smallest
  • refresh rate -> highest to lowest
  • pixel density -> lowest to highest

Parameter: displayID the instance ID of the display to query. Parameter: count a pointer filled in with the number of display modes returned, may be NULL. Returns: a NULL terminated array of display mode pointers or NULL on failure; call SDL_GetError() for more information. This is a single allocation that should be freed with SDL_free() when it is no longer needed.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetDisplays