SDL_GetGamepadAxisFromString

Function SDL_GetGamepadAxisFromString 

pub unsafe extern "C" fn SDL_GetGamepadAxisFromString(
    str_: *const c_char,
) -> SDL_GamepadAxis
Convert a string into SDL_GamepadAxis enum.

This function is called internally to translate SDL_Gamepad mapping strings for the underlying joystick device into the consistent SDL_Gamepad mapping. You do not normally need to call this function unless you are parsing SDL_Gamepad mappings in your own code.

Note specially that “righttrigger” and “lefttrigger” map to SDL_GAMEPAD_AXIS_RIGHT_TRIGGER and SDL_GAMEPAD_AXIS_LEFT_TRIGGER, respectively.

Parameter: str string representing a SDL_Gamepad axis. Returns: the SDL_GamepadAxis enum corresponding to the input string, or SDL_GAMEPAD_AXIS_INVALID if no match was found.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetGamepadStringForAxis