SDL_GetGamepadButtonLabel

Function SDL_GetGamepadButtonLabel 

pub unsafe extern "C" fn SDL_GetGamepadButtonLabel(
    gamepad: *mut SDL_Gamepad,
    button: SDL_GamepadButton,
) -> SDL_GamepadButtonLabel
Get the label of a button on a gamepad.

Parameter: gamepad a gamepad. Parameter: button a button index (one of the SDL_GamepadButton values). Returns: the SDL_GamepadButtonLabel enum corresponding to the button label.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetGamepadButtonLabelForType