SDL_GetGamepadButtonLabelForType

Function SDL_GetGamepadButtonLabelForType 

pub unsafe extern "C" fn SDL_GetGamepadButtonLabelForType(
    type_: SDL_GamepadType,
    button: SDL_GamepadButton,
) -> SDL_GamepadButtonLabel
Get the label of a button on a gamepad.

Parameter: type the type of gamepad to check. Parameter: button a button index (one of the SDL_GamepadButton values). Returns: the SDL_GamepadButtonLabel enum corresponding to the button label.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetGamepadButtonLabel