SDL_GetGamepadPath

Function SDL_GetGamepadPath 

pub unsafe extern "C" fn SDL_GetGamepadPath(
    gamepad: *mut SDL_Gamepad,
) -> *const c_char
Get the implementation-dependent path for an opened gamepad.

Parameter: gamepad a gamepad identifier previously returned by SDL_OpenGamepad(). Returns: the implementation dependent path for the gamepad, or NULL if there is no path or the identifier passed is invalid.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetGamepadPathForID