SDL_GetGamepadSensorData

Function SDL_GetGamepadSensorData 

pub unsafe extern "C" fn SDL_GetGamepadSensorData(
    gamepad: *mut SDL_Gamepad,
    type_: SDL_SensorType,
    data: *mut f32,
    num_values: c_int,
) -> bool
Get the current state of a gamepad sensor.

The number of values and interpretation of the data is sensor dependent. See the remarks in SDL_SensorType for details for each type of sensor.

Parameter: gamepad the gamepad to query. Parameter: type the type of sensor to query. Parameter: data a pointer filled with the current sensor state. Parameter: num_values the number of values to write to data. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.