SDL_GetGamepadStringForAxis

Function SDL_GetGamepadStringForAxis 

pub unsafe extern "C" fn SDL_GetGamepadStringForAxis(
    axis: SDL_GamepadAxis,
) -> *const c_char
Convert from an SDL_GamepadAxis enum to a string.

Parameter: axis an enum value for a given SDL_GamepadAxis. Returns: a string for the given axis, or NULL if an invalid axis is specified. The string returned is of the format used by SDL_Gamepad mapping strings.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetGamepadAxisFromString