SDL_GetGamepadStringForType

Function SDL_GetGamepadStringForType 

pub unsafe extern "C" fn SDL_GetGamepadStringForType(
    type_: SDL_GamepadType,
) -> *const c_char
Convert from an SDL_GamepadType enum to a string.

Parameter: type an enum value for a given SDL_GamepadType. Returns: a string for the given type, or NULL if an invalid type is specified. The string returned is of the format used by SDL_Gamepad mapping strings.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetGamepadTypeFromString