pub unsafe extern "C" fn SDL_GetGamepadTypeFromString(
str_: *const c_char,
) -> SDL_GamepadTypeExpand description
Convert a string into SDL_GamepadType enum.
This function is called internally to translate SDL_Gamepad mapping strings for the underlying joystick device into the consistent SDL_Gamepad mapping. You do not normally need to call this function unless you are parsing SDL_Gamepad mappings in your own code.
Parameter: str string representing a SDL_GamepadType type.
Returns: the SDL_GamepadType enum corresponding to the input string, or
SDL_GAMEPAD_TYPE_UNKNOWN if no match was found.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetGamepadStringForType