pub unsafe extern "C" fn SDL_GetIOStatus(
context: *mut SDL_IOStream,
) -> SDL_IOStatusExpand description
Query the stream status of an SDL_IOStream.
This information can be useful to decide if a short read or write was due to an error, an EOF, or a non-blocking operation that isn’t yet ready to complete.
An SDL_IOStream’s status is only expected to change after a SDL_ReadIO or SDL_WriteIO call; don’t expect it to change if you just call this query function in a tight loop.
Parameter: context the SDL_IOStream to query. Returns: an SDL_IOStatus enum with the current state.
Thread Safety: Do not use the same SDL_IOStream from two threads at once.
Available Since: This function is available since SDL 3.2.0.