SDL_GetKeyName

Function SDL_GetKeyName 

pub unsafe extern "C" fn SDL_GetKeyName(
    key: SDL_Keycode,
) -> *const c_char
Get a human-readable name for a key.

If the key doesn’t have a name, this function returns an empty string (“”).

Letters will be presented in their uppercase form, if applicable.

Parameter: key the desired SDL_Keycode to query. Returns: a UTF-8 encoded string of the key name.

Thread Safety: This function is not thread safe.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetKeyFromName See Also: SDL_GetKeyFromScancode See Also: SDL_GetScancodeFromKey