SDL_GetKeyboardState

Function SDL_GetKeyboardState 

pub unsafe extern "C" fn SDL_GetKeyboardState(
    numkeys: *mut c_int,
) -> *const bool
Get a snapshot of the current state of the keyboard.

The pointer returned is a pointer to an internal SDL array. It will be valid for the whole lifetime of the application and should not be freed by the caller.

A array element with a value of true means that the key is pressed and a value of false means that it is not. Indexes into this array are obtained by using SDL_Scancode values.

Use SDL_PumpEvents() to update the state array.

This function gives you the current state after all events have been processed, so if a key or button has been pressed and released before you process events, then the pressed state will never show up in the SDL_GetKeyboardState() calls.

Note: This function doesn’t take into account whether shift has been pressed or not.

Parameter: numkeys if non-NULL, receives the length of the returned array. Returns: a pointer to an array of key states.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_PumpEvents See Also: SDL_ResetKeyboard