SDL_GetLogOutputFunction

Function SDL_GetLogOutputFunction 

pub unsafe extern "C" fn SDL_GetLogOutputFunction(
    callback: *mut SDL_LogOutputFunction,
    userdata: *mut *mut c_void,
)
Get the current log output function.

Parameter: callback an SDL_LogOutputFunction filled in with the current log callback. Parameter: userdata a pointer filled in with the pointer that is passed to callback.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetDefaultLogOutputFunction See Also: SDL_SetLogOutputFunction