SDL_GetMemoryFunctions

Function SDL_GetMemoryFunctions 

pub unsafe extern "C" fn SDL_GetMemoryFunctions(
    malloc_func: *mut SDL_malloc_func,
    calloc_func: *mut SDL_calloc_func,
    realloc_func: *mut SDL_realloc_func,
    free_func: *mut SDL_free_func,
)
Get the current set of SDL memory functions.

Parameter: malloc_func filled with malloc function. Parameter: calloc_func filled with calloc function. Parameter: realloc_func filled with realloc function. Parameter: free_func filled with free function.

Thread Safety: This does not hold a lock, so do not call this in the unlikely event of a background thread calling SDL_SetMemoryFunctions simultaneously.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetMemoryFunctions See Also: SDL_GetOriginalMemoryFunctions