SDL_GetPathInfo

Function SDL_GetPathInfo 

pub unsafe extern "C" fn SDL_GetPathInfo(
    path: *const c_char,
    info: *mut SDL_PathInfo,
) -> bool
Get information about a filesystem path.

Symlinks, on filesystems that support them, are always followed, so you will always get information on what the symlink eventually points to, and not the symlink itself.

Parameter: path the path to query. Parameter: info a pointer filled in with information about the path, or NULL to check for the existence of a file. Returns: true on success or false if the file doesn’t exist, or another failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.