pub unsafe extern "C" fn SDL_GetPerformanceCounter() -> Uint64Expand description
Get the current value of the high resolution counter.
This function is typically used for profiling.
The counter values are only meaningful relative to each other. Differences between values can be converted to times by using SDL_GetPerformanceFrequency().
Returns: the current counter value.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetPerformanceFrequency