SDL_GetPixelFormatForMasks

Function SDL_GetPixelFormatForMasks 

pub unsafe extern "C" fn SDL_GetPixelFormatForMasks(
    bpp: c_int,
    Rmask: Uint32,
    Gmask: Uint32,
    Bmask: Uint32,
    Amask: Uint32,
) -> SDL_PixelFormat
Convert a bpp value and RGBA masks to an enumerated pixel format.

This will return SDL_PIXELFORMAT_UNKNOWN if the conversion wasn’t possible.

Parameter: bpp a bits per pixel value; usually 15, 16, or 32. Parameter: Rmask the red mask for the format. Parameter: Gmask the green mask for the format. Parameter: Bmask the blue mask for the format. Parameter: Amask the alpha mask for the format. Returns: the SDL_PixelFormat value corresponding to the format masks, or SDL_PIXELFORMAT_UNKNOWN if there isn’t a match.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetMasksForPixelFormat