SDL_GetPixelFormatName

Function SDL_GetPixelFormatName 

pub unsafe extern "C" fn SDL_GetPixelFormatName(
    format: SDL_PixelFormat,
) -> *const c_char
Get the human readable name of a pixel format.

Parameter: format the pixel format to query. Returns: the human readable name of the specified pixel format or “SDL_PIXELFORMAT_UNKNOWN” if the format isn’t recognized.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.