pub unsafe extern "C" fn SDL_GetProcessOutput(
process: *mut SDL_Process,
) -> *mut SDL_IOStreamExpand description
Get the SDL_IOStream associated with process standard output.
The process must have been created with SDL_CreateProcess() and pipe_stdio
set to true, or with SDL_CreateProcessWithProperties() and
SDL_PROP_PROCESS_CREATE_STDOUT_NUMBER set to SDL_PROCESS_STDIO_APP.
Reading from this stream can return 0 with SDL_GetIOStatus() returning SDL_IO_STATUS_NOT_READY if no output is available yet.
Parameter: process The process to get the output stream for. Returns: the output stream or NULL on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_CreateProcess See Also: SDL_CreateProcessWithProperties See Also: SDL_GetProcessInput