SDL_GetRenderColorScale

Function SDL_GetRenderColorScale 

pub unsafe extern "C" fn SDL_GetRenderColorScale(
    renderer: *mut SDL_Renderer,
    scale: *mut f32,
) -> bool
Get the color scale used for render operations.

Parameter: renderer the rendering context. Parameter: scale a pointer filled in with the current color scale value. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetRenderColorScale