SDL_GetRenderScale

Function SDL_GetRenderScale 

pub unsafe extern "C" fn SDL_GetRenderScale(
    renderer: *mut SDL_Renderer,
    scaleX: *mut f32,
    scaleY: *mut f32,
) -> bool
Get the drawing scale for the current target.

Each render target has its own scale. This function gets the scale for the current render target.

Parameter: renderer the rendering context. Parameter: scaleX a pointer filled in with the horizontal scaling factor. Parameter: scaleY a pointer filled in with the vertical scaling factor. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetRenderScale