SDL_GetRenderTarget

Function SDL_GetRenderTarget 

pub unsafe extern "C" fn SDL_GetRenderTarget(
    renderer: *mut SDL_Renderer,
) -> *mut SDL_Texture
Get the current render target.

The default render target is the window for which the renderer was created, and is reported a NULL here.

Parameter: renderer the rendering context. Returns: the current render target or NULL for the default render target.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetRenderTarget