SDL_GetScancodeFromKey

Function SDL_GetScancodeFromKey 

pub unsafe extern "C" fn SDL_GetScancodeFromKey(
    key: SDL_Keycode,
    modstate: *mut SDL_Keymod,
) -> SDL_Scancode
Get the scancode corresponding to the given key code according to the current keyboard layout.

Note that there may be multiple scancode+modifier states that can generate this keycode, this will just return the first one found.

Parameter: key the desired SDL_Keycode to query. Parameter: modstate a pointer to the modifier state that would be used when the scancode generates this key, may be NULL. Returns: the SDL_Scancode that corresponds to the given SDL_Keycode.

Thread Safety: This function is not thread safe.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetKeyFromScancode See Also: SDL_GetScancodeName