SDL_GetSensorData

Function SDL_GetSensorData 

pub unsafe extern "C" fn SDL_GetSensorData(
    sensor: *mut SDL_Sensor,
    data: *mut f32,
    num_values: c_int,
) -> bool
Get the current state of an opened sensor.

The number of values and interpretation of the data is sensor dependent.

Parameter: sensor the SDL_Sensor object to query. Parameter: data a pointer filled with the current sensor state. Parameter: num_values the number of values to write to data. Returns: true on success or false on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.