SDL_GetStorageFileSize

Function SDL_GetStorageFileSize 

pub unsafe extern "C" fn SDL_GetStorageFileSize(
    storage: *mut SDL_Storage,
    path: *const c_char,
    length: *mut Uint64,
) -> bool
Query the size of a file within a storage container.

Parameter: storage a storage container to query. Parameter: path the relative path of the file to query. Parameter: length a pointer to be filled with the file’s length. Returns: true if the file could be queried or false on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_ReadStorageFile See Also: SDL_StorageReady