SDL_GetStoragePathInfo

Function SDL_GetStoragePathInfo 

pub unsafe extern "C" fn SDL_GetStoragePathInfo(
    storage: *mut SDL_Storage,
    path: *const c_char,
    info: *mut SDL_PathInfo,
) -> bool
Get information about a filesystem path in a storage container.

Parameter: storage a storage container. Parameter: path the path to query. Parameter: info a pointer filled in with information about the path, or NULL to check for the existence of a file. Returns: true on success or false if the file doesn’t exist, or another failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_StorageReady