SDL_GetStringProperty

Function SDL_GetStringProperty 

pub unsafe extern "C" fn SDL_GetStringProperty(
    props: SDL_PropertiesID,
    name: *const c_char,
    default_value: *const c_char,
) -> *const c_char
Get a string property from a group of properties.

Parameter: props the properties to query. Parameter: name the name of the property to query. Parameter: default_value the default value of the property. Returns: the value of the property, or default_value if it is not set or not a string property.

Thread Safety: It is safe to call this function from any thread, although the data returned is not protected and could potentially be freed if you call SDL_SetStringProperty() or SDL_ClearProperty() on these properties from another thread. If you need to avoid this, use SDL_LockProperties() and SDL_UnlockProperties().

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetPropertyType See Also: SDL_HasProperty See Also: SDL_SetStringProperty