SDL_GetTextInputArea

Function SDL_GetTextInputArea 

pub unsafe extern "C" fn SDL_GetTextInputArea(
    window: *mut SDL_Window,
    rect: *mut SDL_Rect,
    cursor: *mut c_int,
) -> bool
Get the area used to type Unicode text input.

This returns the values previously set by SDL_SetTextInputArea().

Parameter: window the window for which to query the text input area. Parameter: rect a pointer to an SDL_Rect filled in with the text input area, may be NULL. Parameter: cursor a pointer to the offset of the current cursor location relative to rect->x, may be NULL. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetTextInputArea