SDL_GetTextureAlphaModFloat

Function SDL_GetTextureAlphaModFloat 

pub unsafe extern "C" fn SDL_GetTextureAlphaModFloat(
    texture: *mut SDL_Texture,
    alpha: *mut f32,
) -> bool
Get the additional alpha value multiplied into render copy operations.

Parameter: texture the texture to query. Parameter: alpha a pointer filled in with the current alpha value. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetTextureAlphaMod See Also: SDL_GetTextureColorModFloat See Also: SDL_SetTextureAlphaModFloat