SDL_GetTextureColorMod

Function SDL_GetTextureColorMod 

pub unsafe extern "C" fn SDL_GetTextureColorMod(
    texture: *mut SDL_Texture,
    r: *mut Uint8,
    g: *mut Uint8,
    b: *mut Uint8,
) -> bool
Get the additional color value multiplied into render copy operations.

Parameter: texture the texture to query. Parameter: r a pointer filled in with the current red color value. Parameter: g a pointer filled in with the current green color value. Parameter: b a pointer filled in with the current blue color value. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetTextureAlphaMod See Also: SDL_GetTextureColorModFloat See Also: SDL_SetTextureColorMod