SDL_GetThreadName

Function SDL_GetThreadName 

pub unsafe extern "C" fn SDL_GetThreadName(
    thread: *mut SDL_Thread,
) -> *const c_char
Get the thread name as it was specified in SDL_CreateThread().

Parameter: thread the thread to query. Returns: a pointer to a UTF-8 string that names the specified thread, or NULL if it doesn’t have a name.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.