SDL_GetTrayEntryChecked

Function SDL_GetTrayEntryChecked 

pub unsafe extern "C" fn SDL_GetTrayEntryChecked(
    entry: *mut SDL_TrayEntry,
) -> bool
Gets whether or not an entry is checked.

The entry must have been created with the SDL_TRAYENTRY_CHECKBOX flag.

Parameter: entry the entry to be read. Returns: true if the entry is checked; false otherwise.

Thread Safety: This function should be called on the thread that created the tray.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetTrayEntries See Also: SDL_InsertTrayEntryAt See Also: SDL_SetTrayEntryChecked