pub unsafe extern "C" fn SDL_GetUserFolder(
folder: SDL_Folder,
) -> *const c_charExpand description
Finds the most suitable user folder for a specific purpose.
Many OSes provide certain standard folders for certain purposes, such as storing pictures, music or videos for a certain user. This function gives the path for many of those special locations.
This function is specifically for user folders, which are meant for the user to access and manage. For application-specific folders, meant to hold data for the application to manage, see SDL_GetBasePath() and SDL_GetPrefPath().
The returned path is guaranteed to end with a path separator (‘\’ on Windows, ‘/’ on most other platforms).
If NULL is returned, the error may be obtained with SDL_GetError().
Parameter: folder the type of folder to find. Returns: either a null-terminated C string containing the full path to the folder, or NULL if an error happened.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.