SDL_GetWindowID

Function SDL_GetWindowID 

pub unsafe extern "C" fn SDL_GetWindowID(
    window: *mut SDL_Window,
) -> SDL_WindowID
Get the numeric ID of a window.

The numeric ID is what SDL_WindowEvent references, and is necessary to map these events to specific SDL_Window objects.

Parameter: window the window to query. Returns: the ID of the window on success or 0 on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetWindowFromID