SDL_GetWindowMaximumSize

Function SDL_GetWindowMaximumSize 

pub unsafe extern "C" fn SDL_GetWindowMaximumSize(
    window: *mut SDL_Window,
    w: *mut c_int,
    h: *mut c_int,
) -> bool
Get the maximum size of a window’s client area.

Parameter: window the window to query. Parameter: w a pointer filled in with the maximum width of the window, may be NULL. Parameter: h a pointer filled in with the maximum height of the window, may be NULL. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetWindowMinimumSize See Also: SDL_SetWindowMaximumSize