SDL_GetWindowMouseRect

Function SDL_GetWindowMouseRect 

pub unsafe extern "C" fn SDL_GetWindowMouseRect(
    window: *mut SDL_Window,
) -> *const SDL_Rect
Get the mouse confinement rectangle of a window.

Parameter: window the window to query. Returns: a pointer to the mouse confinement rectangle of a window, or NULL if there isn’t one.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetWindowMouseRect See Also: SDL_GetWindowMouseGrab See Also: SDL_SetWindowMouseGrab