SDL_GetWindowOpacity

Function SDL_GetWindowOpacity 

pub unsafe extern "C" fn SDL_GetWindowOpacity(
    window: *mut SDL_Window,
) -> f32
Get the opacity of a window.

If transparency isn’t supported on this platform, opacity will be returned as 1.0f without error.

Parameter: window the window to get the current opacity value from. Returns: the opacity, (0.0f - transparent, 1.0f - opaque), or -1.0f on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetWindowOpacity