pub unsafe extern "C" fn SDL_GetWindowPosition(
window: *mut SDL_Window,
x: *mut c_int,
y: *mut c_int,
) -> boolExpand description
Get the position of a window.
This is the current position of the window as last reported by the windowing system.
If you do not need the value for one of the positions a NULL may be passed
in the x or y parameter.
Parameter: window the window to query. Parameter: x a pointer filled in with the x position of the window, may be NULL. Parameter: y a pointer filled in with the y position of the window, may be NULL. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetWindowPosition