SDL_GetWindowProgressState

Function SDL_GetWindowProgressState 

pub unsafe extern "C" fn SDL_GetWindowProgressState(
    window: *mut SDL_Window,
) -> SDL_ProgressState
Get the state of the progress bar for the given window’s taskbar icon.

Parameter: window the window to get the current progress state from. Returns: the progress state, or SDL_PROGRESS_STATE_INVALID on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.4.0.