SDL_GetWindowSurfaceVSync

Function SDL_GetWindowSurfaceVSync 

pub unsafe extern "C" fn SDL_GetWindowSurfaceVSync(
    window: *mut SDL_Window,
    vsync: *mut c_int,
) -> bool
Get VSync for the window surface.

Parameter: window the window to query. Parameter: vsync an int filled with the current vertical refresh sync interval. See SDL_SetWindowSurfaceVSync() for the meaning of the value. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetWindowSurfaceVSync