pub unsafe extern "C" fn SDL_GetWindows(
count: *mut c_int,
) -> *mut *mut SDL_WindowExpand description
Get a list of valid windows.
Parameter: count a pointer filled in with the number of windows returned, may be NULL. Returns: a NULL terminated array of SDL_Window pointers or NULL on failure; call SDL_GetError() for more information. This is a single allocation that should be freed with SDL_free() when it is no longer needed.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.