pub unsafe extern "C" fn SDL_InsertGPUDebugLabel(
command_buffer: *mut SDL_GPUCommandBuffer,
text: *const c_char,
)Expand description
Inserts an arbitrary string label into the command buffer callstream.
Useful for debugging.
On Direct3D 12, using SDL_InsertGPUDebugLabel requires WinPixEventRuntime.dll to be in your PATH or in the same directory as your executable. See here for instructions on how to obtain it.
Parameter: command_buffer a command buffer. Parameter: text a UTF-8 string constant to insert as the label.
Available Since: This function is available since SDL 3.2.0.