SDL_KillProcess

Function SDL_KillProcess 

pub unsafe extern "C" fn SDL_KillProcess(
    process: *mut SDL_Process,
    force: bool,
) -> bool
Stop a process.

Parameter: process The process to stop. Parameter: force true to terminate the process immediately, false to try to stop the process gracefully. In general you should try to stop the process gracefully first as terminating a process may leave it with half-written data or in some other unstable state. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function is not thread safe.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateProcess See Also: SDL_CreateProcessWithProperties See Also: SDL_WaitProcess See Also: SDL_DestroyProcess