pub unsafe extern "C" fn SDL_LoadBMP(
file: *const c_char,
) -> *mut SDL_SurfaceExpand description
Load a BMP image from a file.
The new surface should be freed with SDL_DestroySurface(). Not doing so will result in a memory leak.
Parameter: file the BMP file to load. Returns: a pointer to a new SDL_Surface structure or NULL on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_DestroySurface See Also: SDL_LoadBMP_IO See Also: SDL_SaveBMP