SDL_LogMessage

Function SDL_LogMessage 

pub unsafe extern "C" fn SDL_LogMessage(
    category: c_int,
    priority: SDL_LogPriority,
    fmt: *const c_char,
    ...
)
Log a message with the specified category and priority.

Parameter: category the category of the message. Parameter: priority the priority of the message. Parameter: fmt a printf() style message format string. Parameter: … additional parameters matching % tokens in the fmt string, if any.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_Log See Also: SDL_LogCritical See Also: SDL_LogDebug See Also: SDL_LogError See Also: SDL_LogInfo See Also: SDL_LogMessageV See Also: SDL_LogTrace See Also: SDL_LogVerbose See Also: SDL_LogWarn