pub unsafe extern "C" fn SDL_LogMessageV(
category: c_int,
priority: SDL_LogPriority,
fmt: *const c_char,
ap: *mut __va_list_tag,
)Expand description
Log a message with the specified category and priority.
Parameter: category the category of the message. Parameter: priority the priority of the message. Parameter: fmt a printf() style message format string. Parameter: ap a variable argument list.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_Log See Also: SDL_LogCritical See Also: SDL_LogDebug See Also: SDL_LogError See Also: SDL_LogInfo See Also: SDL_LogMessage See Also: SDL_LogTrace See Also: SDL_LogVerbose See Also: SDL_LogWarn