SDL_MapGPUTransferBuffer

Function SDL_MapGPUTransferBuffer 

pub unsafe extern "C" fn SDL_MapGPUTransferBuffer(
    device: *mut SDL_GPUDevice,
    transfer_buffer: *mut SDL_GPUTransferBuffer,
    cycle: bool,
) -> *mut c_void
Maps a transfer buffer into application address space.

You must unmap the transfer buffer before encoding upload commands. The memory is owned by the graphics driver - do NOT call SDL_free() on the returned pointer.

Parameter: device a GPU context. Parameter: transfer_buffer a transfer buffer. Parameter: cycle if true, cycles the transfer buffer if it is already bound. Returns: the address of the mapped transfer buffer memory, or NULL on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.