SDL_MemoryBarrierAcquireFunction

Function SDL_MemoryBarrierAcquireFunction 

pub unsafe extern "C" fn SDL_MemoryBarrierAcquireFunction()
Insert a memory acquire barrier (function version).

Please refer to SDL_MemoryBarrierRelease for details. This is a function version, which might be useful if you need to use this functionality from a scripting language, etc. Also, some of the macro versions call this function behind the scenes, where more heavy lifting can happen inside of SDL. Generally, though, an app written in C/C++/etc should use the macro version, as it will be more efficient.

Thread Safety: Obviously this function is safe to use from any thread at any time, but if you find yourself needing this, you are probably dealing with some very sensitive code; be careful!

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_MemoryBarrierAcquire