pub unsafe extern "C" fn SDL_Metal_CreateView(
window: *mut SDL_Window,
) -> SDL_MetalViewExpand description
Create a CAMetalLayer-backed NSView/UIView and attach it to the specified window.
On macOS, this does not associate a MTLDevice with the CAMetalLayer on its own. It is up to user code to do that.
The returned handle can be casted directly to a NSView or UIView. To access the backing CAMetalLayer, call SDL_Metal_GetLayer().
Parameter: window the window. Returns: handle NSView or UIView.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_Metal_DestroyView See Also: SDL_Metal_GetLayer