SDL_PopGPUDebugGroup

Function SDL_PopGPUDebugGroup 

pub unsafe extern "C" fn SDL_PopGPUDebugGroup(
    command_buffer: *mut SDL_GPUCommandBuffer,
)
Ends the most-recently pushed debug group.

On Direct3D 12, using SDL_PopGPUDebugGroup requires WinPixEventRuntime.dll to be in your PATH or in the same directory as your executable. See here for instructions on how to obtain it.

Parameter: command_buffer a command buffer.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_PushGPUDebugGroup