SDL_PutAudioStreamData

Function SDL_PutAudioStreamData 

pub unsafe extern "C" fn SDL_PutAudioStreamData(
    stream: *mut SDL_AudioStream,
    buf: *const c_void,
    len: c_int,
) -> bool
Add data to the stream.

This data must match the format/channels/samplerate specified in the latest call to SDL_SetAudioStreamFormat, or the format specified when creating the stream if it hasn’t been changed.

Note that this call simply copies the unconverted data for later. This is different than SDL2, where data was converted during the Put call and the Get call would just dequeue the previously-converted data.

Parameter: stream the stream the audio data is being added to. Parameter: buf a pointer to the audio data to add. Parameter: len the number of bytes to write to the stream. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread, but if the stream has a callback set, the caller might need to manage extra locking.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_ClearAudioStream See Also: SDL_FlushAudioStream See Also: SDL_GetAudioStreamData See Also: SDL_GetAudioStreamQueued