pub unsafe extern "C" fn SDL_ReadStorageFile(
storage: *mut SDL_Storage,
path: *const c_char,
destination: *mut c_void,
length: Uint64,
) -> boolExpand description
Synchronously read a file from a storage container into a client-provided buffer.
The value of length must match the length of the file exactly; call
SDL_GetStorageFileSize() to get this value. This behavior may be relaxed in
a future release.
Parameter: storage a storage container to read from. Parameter: path the relative path of the file to read. Parameter: destination a client-provided buffer to read the file into. Parameter: length the length of the destination buffer. Returns: true if the file was read or false on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetStorageFileSize See Also: SDL_StorageReady See Also: SDL_WriteStorageFile