SDL_RectEmptyFloat

Function SDL_RectEmptyFloat 

pub unsafe extern "C" fn SDL_RectEmptyFloat(
    r: *const SDL_FRect,
) -> bool
Determine whether a floating point rectangle takes no space.

A rectangle is considered “empty” for this function if r is NULL, or if r’s width and/or height are < 0.0f.

Note that this is a forced-inline function in a header, and not a public API function available in the SDL library (which is to say, the code is embedded in the calling program and the linker and dynamic loader will not be able to find this function inside SDL itself).

Parameter: r the rectangle to test. Returns: true if the rectangle is “empty”, false otherwise.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.