SDL_RectToFRect

Function SDL_RectToFRect 

pub unsafe extern "C" fn SDL_RectToFRect(
    rect: *const SDL_Rect,
    frect: *mut SDL_FRect,
)
Convert an SDL_Rect to SDL_FRect

Parameter: rect a pointer to an SDL_Rect. Parameter: frect a pointer filled in with the floating point representation of rect.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.