pub unsafe extern "C" fn SDL_RenderDebugTextFormat(
renderer: *mut SDL_Renderer,
x: f32,
y: f32,
fmt: *const c_char,
...
) -> boolExpand description
Draw debug text to an SDL_Renderer.
This function will render a printf()-style format string to a renderer. Note that this is a convenience function for debugging, with severe limitations, and is not intended to be used for production apps and games.
For the full list of limitations and other useful information, see SDL_RenderDebugText.
Parameter: renderer the renderer which should draw the text.
Parameter: x the x coordinate where the top-left corner of the text will draw.
Parameter: y the y coordinate where the top-left corner of the text will draw.
Parameter: fmt the format string to draw.
Parameter: … additional parameters matching % tokens in the fmt string, if
any.
Returns: true on success or false on failure; call SDL_GetError() for more
information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_RenderDebugText See Also: SDL_DEBUG_TEXT_FONT_CHARACTER_SIZE