SDL_RenderFillRect

Function SDL_RenderFillRect 

pub unsafe extern "C" fn SDL_RenderFillRect(
    renderer: *mut SDL_Renderer,
    rect: *const SDL_FRect,
) -> bool
Fill a rectangle on the current rendering target with the drawing color at subpixel precision.

Parameter: renderer the renderer which should fill a rectangle. Parameter: rect a pointer to the destination rectangle, or NULL for the entire rendering target. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_RenderFillRects