SDL_RenderRect

Function SDL_RenderRect 

pub unsafe extern "C" fn SDL_RenderRect(
    renderer: *mut SDL_Renderer,
    rect: *const SDL_FRect,
) -> bool
Draw a rectangle on the current rendering target at subpixel precision.

Parameter: renderer the renderer which should draw a rectangle. Parameter: rect a pointer to the destination rectangle, or NULL to outline the entire rendering target. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_RenderRects