SDL_RenderTexture

Function SDL_RenderTexture 

pub unsafe extern "C" fn SDL_RenderTexture(
    renderer: *mut SDL_Renderer,
    texture: *mut SDL_Texture,
    srcrect: *const SDL_FRect,
    dstrect: *const SDL_FRect,
) -> bool
Copy a portion of the texture to the current rendering target at subpixel precision.

Parameter: renderer the renderer which should copy parts of a texture. Parameter: texture the source texture. Parameter: srcrect a pointer to the source rectangle, or NULL for the entire texture. Parameter: dstrect a pointer to the destination rectangle, or NULL for the entire rendering target. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_RenderTextureRotated See Also: SDL_RenderTextureTiled