SDL_RestoreWindow

Function SDL_RestoreWindow 

pub unsafe extern "C" fn SDL_RestoreWindow(
    window: *mut SDL_Window,
) -> bool
Request that the size and position of a minimized or maximized window be restored.

If the window is in a fullscreen state, this request has no direct effect. It may alter the state the window is returned to when leaving fullscreen.

On some windowing systems this request is asynchronous and the new window state may not have have been applied immediately upon the return of this function. If an immediate change is required, call SDL_SyncWindow() to block until the changes have taken effect.

When the window state changes, an SDL_EVENT_WINDOW_RESTORED event will be emitted. Note that, as this is just a request, the windowing system can deny the state change.

Parameter: window the window to restore. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_MaximizeWindow See Also: SDL_MinimizeWindow See Also: SDL_SyncWindow