pub unsafe extern "C" fn SDL_RunOnMainThread(
callback: SDL_MainThreadCallback,
userdata: *mut c_void,
wait_complete: bool,
) -> boolExpand description
Call a function on the main thread during event processing.
If this is called on the main thread, the callback is executed immediately. If this is called on another thread, this callback is queued for execution on the main thread during event processing.
Be careful of deadlocks when using this functionality. You should not have
the main thread wait for the current thread while this function is being
called with wait_complete true.
Parameter: callback the callback to call on the main thread.
Parameter: userdata a pointer that is passed to callback.
Parameter: wait_complete true to wait for the callback to complete, false to
return immediately.
Returns: true on success or false on failure; call SDL_GetError() for more
information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_IsMainThread