SDL_SendJoystickVirtualSensorData

Function SDL_SendJoystickVirtualSensorData 

pub unsafe extern "C" fn SDL_SendJoystickVirtualSensorData(
    joystick: *mut SDL_Joystick,
    type_: SDL_SensorType,
    sensor_timestamp: Uint64,
    data: *const f32,
    num_values: c_int,
) -> bool
Send a sensor update for an opened virtual joystick.

Please note that values set here will not be applied until the next call to SDL_UpdateJoysticks, which can either be called directly, or can be called indirectly through various other SDL APIs, including, but not limited to the following: SDL_PollEvent, SDL_PumpEvents, SDL_WaitEventTimeout, SDL_WaitEvent.

Parameter: joystick the virtual joystick on which to set state. Parameter: type the type of the sensor on the virtual joystick to update. Parameter: sensor_timestamp a 64-bit timestamp in nanoseconds associated with the sensor reading. Parameter: data the data associated with the sensor reading. Parameter: num_values the number of values pointed to by data. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetJoystickVirtualAxis See Also: SDL_SetJoystickVirtualButton See Also: SDL_SetJoystickVirtualBall See Also: SDL_SetJoystickVirtualHat See Also: SDL_SetJoystickVirtualTouchpad