SDL_SetAtomicPointer

Function SDL_SetAtomicPointer 

pub unsafe extern "C" fn SDL_SetAtomicPointer(
    a: *mut *mut c_void,
    v: *mut c_void,
) -> *mut c_void
Set a pointer to a value atomically.

Note: If you don’t know what this function is for, you shouldn’t use it!

Parameter: a a pointer to a pointer. Parameter: v the desired pointer value. Returns: the previous value of the pointer.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CompareAndSwapAtomicPointer See Also: SDL_GetAtomicPointer