SDL_SetBooleanProperty

Function SDL_SetBooleanProperty 

pub unsafe extern "C" fn SDL_SetBooleanProperty(
    props: SDL_PropertiesID,
    name: *const c_char,
    value: bool,
) -> bool
Set a boolean property in a group of properties.

Parameter: props the properties to modify. Parameter: name the name of the property to modify. Parameter: value the new value of the property. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetBooleanProperty