SDL_SetDefaultTextureScaleMode

Function SDL_SetDefaultTextureScaleMode 

pub unsafe extern "C" fn SDL_SetDefaultTextureScaleMode(
    renderer: *mut SDL_Renderer,
    scale_mode: SDL_ScaleMode,
) -> bool
Set default scale mode for new textures for given renderer.

When a renderer is created, scale_mode defaults to SDL_SCALEMODE_LINEAR.

Parameter: renderer the renderer to update. Parameter: scale_mode the scale mode to change to for new textures. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.4.0.

See Also: SDL_GetDefaultTextureScaleMode