SDL_SetEnvironmentVariable

Function SDL_SetEnvironmentVariable 

pub unsafe extern "C" fn SDL_SetEnvironmentVariable(
    env: *mut SDL_Environment,
    name: *const c_char,
    value: *const c_char,
    overwrite: bool,
) -> bool
Set the value of a variable in the environment.

Parameter: env the environment to modify. Parameter: name the name of the variable to set. Parameter: value the value of the variable to set. Parameter: overwrite true to overwrite the variable if it exists, false to return success without setting the variable if it already exists. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetEnvironment See Also: SDL_CreateEnvironment See Also: SDL_GetEnvironmentVariable See Also: SDL_GetEnvironmentVariables See Also: SDL_UnsetEnvironmentVariable