SDL_SetGPUBufferName

Function SDL_SetGPUBufferName 

pub unsafe extern "C" fn SDL_SetGPUBufferName(
    device: *mut SDL_GPUDevice,
    buffer: *mut SDL_GPUBuffer,
    text: *const c_char,
)
Sets an arbitrary string constant to label a buffer.

You should use SDL_PROP_GPU_BUFFER_CREATE_NAME_STRING with SDL_CreateGPUBuffer instead of this function to avoid thread safety issues.

Parameter: device a GPU Context. Parameter: buffer a buffer to attach the name to. Parameter: text a UTF-8 string constant to mark as the name of the buffer.

Thread Safety: This function is not thread safe, you must make sure the buffer is not simultaneously used by any other thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateGPUBuffer