SDL_SetGamepadEventsEnabled

Function SDL_SetGamepadEventsEnabled 

pub unsafe extern "C" fn SDL_SetGamepadEventsEnabled(enabled: bool)
Set the state of gamepad event processing.

If gamepad events are disabled, you must call SDL_UpdateGamepads() yourself and check the state of the gamepad when you want gamepad information.

Parameter: enabled whether to process gamepad events or not.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GamepadEventsEnabled See Also: SDL_UpdateGamepads