SDL_SetGamepadLED

Function SDL_SetGamepadLED 

pub unsafe extern "C" fn SDL_SetGamepadLED(
    gamepad: *mut SDL_Gamepad,
    red: Uint8,
    green: Uint8,
    blue: Uint8,
) -> bool
Update a gamepad’s LED color.

An example of a joystick LED is the light on the back of a PlayStation 4’s DualShock 4 controller.

For gamepads with a single color LED, the maximum of the RGB values will be used as the LED brightness.

Parameter: gamepad the gamepad to update. Parameter: red the intensity of the red LED. Parameter: green the intensity of the green LED. Parameter: blue the intensity of the blue LED. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.