SDL_SetLogOutputFunction

Function SDL_SetLogOutputFunction 

pub unsafe extern "C" fn SDL_SetLogOutputFunction(
    callback: SDL_LogOutputFunction,
    userdata: *mut c_void,
)
Replace the default log output function with one of your own.

Parameter: callback an SDL_LogOutputFunction to call instead of the default. Parameter: userdata a pointer that is passed to callback.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetDefaultLogOutputFunction See Also: SDL_GetLogOutputFunction