pub unsafe extern "C" fn SDL_SetMemoryFunctions(
malloc_func: SDL_malloc_func,
calloc_func: SDL_calloc_func,
realloc_func: SDL_realloc_func,
free_func: SDL_free_func,
) -> boolExpand description
Replace SDL’s memory allocation functions with a custom set.
It is not safe to call this function once any allocations have been made, as future calls to SDL_free will use the new allocator, even if they came from an SDL_malloc made with the old one!
If used, usually this needs to be the first call made into the SDL library, if not the very first thing done at program startup time.
Parameter: malloc_func custom malloc function. Parameter: calloc_func custom calloc function. Parameter: realloc_func custom realloc function. Parameter: free_func custom free function. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread, but one should not replace the memory functions once any allocations are made!
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetMemoryFunctions See Also: SDL_GetOriginalMemoryFunctions