SDL_SetPointerProperty

Function SDL_SetPointerProperty 

pub unsafe extern "C" fn SDL_SetPointerProperty(
    props: SDL_PropertiesID,
    name: *const c_char,
    value: *mut c_void,
) -> bool
Set a pointer property in a group of properties.

Parameter: props the properties to modify. Parameter: name the name of the property to modify. Parameter: value the new value of the property, or NULL to delete the property. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetPointerProperty See Also: SDL_HasProperty See Also: SDL_SetBooleanProperty See Also: SDL_SetFloatProperty See Also: SDL_SetNumberProperty See Also: SDL_SetPointerPropertyWithCleanup See Also: SDL_SetStringProperty