pub unsafe extern "C" fn SDL_SetRelativeMouseTransform(
callback: SDL_MouseMotionTransformCallback,
userdata: *mut c_void,
) -> boolExpand description
Set a user-defined function by which to transform relative mouse inputs.
This overrides the relative system scale and relative speed scale hints. Should be called prior to enabling relative mouse mode, fails otherwise.
Parameter: callback a callback used to transform relative mouse motion, or NULL
for default behavior.
Parameter: userdata a pointer that will be passed to callback.
Returns: true on success or false on failure; call SDL_GetError() for more
information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.4.0.