SDL_SetRenderColorScale

Function SDL_SetRenderColorScale 

pub unsafe extern "C" fn SDL_SetRenderColorScale(
    renderer: *mut SDL_Renderer,
    scale: f32,
) -> bool
Set the color scale used for render operations.

The color scale is an additional scale multiplied into the pixel color value while rendering. This can be used to adjust the brightness of colors during HDR rendering, or changing HDR video brightness when playing on an SDR display.

The color scale does not affect the alpha channel, only the color brightness.

Parameter: renderer the rendering context. Parameter: scale the color scale value. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetRenderColorScale