SDL_SetRenderDrawColor

Function SDL_SetRenderDrawColor 

pub unsafe extern "C" fn SDL_SetRenderDrawColor(
    renderer: *mut SDL_Renderer,
    r: Uint8,
    g: Uint8,
    b: Uint8,
    a: Uint8,
) -> bool
Set the color used for drawing operations.

Set the color for drawing or filling rectangles, lines, and points, and for SDL_RenderClear().

Parameter: renderer the rendering context. Parameter: r the red value used to draw on the rendering target. Parameter: g the green value used to draw on the rendering target. Parameter: b the blue value used to draw on the rendering target. Parameter: a the alpha value used to draw on the rendering target; usually SDL_ALPHA_OPAQUE (255). Use SDL_SetRenderDrawBlendMode to specify how the alpha channel is used. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetRenderDrawColor See Also: SDL_SetRenderDrawColorFloat