pub unsafe extern "C" fn SDL_SetRenderTarget(
renderer: *mut SDL_Renderer,
texture: *mut SDL_Texture,
) -> boolExpand description
Set a texture as the current rendering target.
The default render target is the window for which the renderer was created.
To stop rendering to a texture and render to the window again, call this
function with a NULL texture.
Viewport, cliprect, scale, and logical presentation are unique to each render target. Get and set functions for these states apply to the current render target set by this function, and those states persist on each target when the current render target changes.
Parameter: renderer the rendering context.
Parameter: texture the targeted texture, which must be created with the
SDL_TEXTUREACCESS_TARGET flag, or NULL to render to the
window instead of a texture.
Returns: true on success or false on failure; call SDL_GetError() for more
information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetRenderTarget