SDL_SetStringProperty

Function SDL_SetStringProperty 

pub unsafe extern "C" fn SDL_SetStringProperty(
    props: SDL_PropertiesID,
    name: *const c_char,
    value: *const c_char,
) -> bool
Set a string property in a group of properties.

This function makes a copy of the string; the caller does not have to preserve the data after this call completes.

Parameter: props the properties to modify. Parameter: name the name of the property to modify. Parameter: value the new value of the property, or NULL to delete the property. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetStringProperty