SDL_SetSurfaceColorKey

Function SDL_SetSurfaceColorKey 

pub unsafe extern "C" fn SDL_SetSurfaceColorKey(
    surface: *mut SDL_Surface,
    enabled: bool,
    key: Uint32,
) -> bool
Set the color key (transparent pixel) in a surface.

The color key defines a pixel value that will be treated as transparent in a blit. For example, one can use this to specify that cyan pixels should be considered transparent, and therefore not rendered.

It is a pixel of the format used by the surface, as generated by SDL_MapRGB().

Parameter: surface the SDL_Surface structure to update. Parameter: enabled true to enable color key, false to disable color key. Parameter: key the transparent pixel. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function can be called on different threads with different surfaces.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetSurfaceColorKey See Also: SDL_SetSurfaceRLE See Also: SDL_SurfaceHasColorKey