SDL_SetSurfaceColorMod

Function SDL_SetSurfaceColorMod 

pub unsafe extern "C" fn SDL_SetSurfaceColorMod(
    surface: *mut SDL_Surface,
    r: Uint8,
    g: Uint8,
    b: Uint8,
) -> bool
Set an additional color value multiplied into blit operations.

When this surface is blitted, during the blit operation each source color channel is modulated by the appropriate color value according to the following formula:

srcC = srcC * (color / 255)

Parameter: surface the SDL_Surface structure to update. Parameter: r the red color value multiplied into blit operations. Parameter: g the green color value multiplied into blit operations. Parameter: b the blue color value multiplied into blit operations. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function can be called on different threads with different surfaces.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetSurfaceColorMod See Also: SDL_SetSurfaceAlphaMod