SDL_SetTLS

Function SDL_SetTLS 

pub unsafe extern "C" fn SDL_SetTLS(
    id: *mut SDL_TLSID,
    value: *const c_void,
    destructor: SDL_TLSDestructorCallback,
) -> bool
Set the current thread’s value associated with a thread local storage ID.

If the thread local storage ID is not initialized (the value is 0), a new ID will be created in a thread-safe way, so all calls using a pointer to the same ID will refer to the same local storage.

Note that replacing a value from a previous call to this function on the same thread does not call the previous value’s destructor!

destructor can be NULL; it is assumed that value does not need to be cleaned up if so.

Parameter: id a pointer to the thread local storage ID, may not be NULL. Parameter: value the value to associate with the ID for the current thread. Parameter: destructor a function called when the thread exits, to free the value, may be NULL. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetTLS