pub unsafe extern "C" fn SDL_SetTextureScaleMode(
texture: *mut SDL_Texture,
scaleMode: SDL_ScaleMode,
) -> boolExpand description
Set the scale mode used for texture scale operations.
The default texture scale mode is SDL_SCALEMODE_LINEAR.
If the scale mode is not supported, the closest supported mode is chosen.
Parameter: texture the texture to update. Parameter: scaleMode the SDL_ScaleMode to use for texture scaling. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetTextureScaleMode