SDL_SetWindowBordered

Function SDL_SetWindowBordered 

pub unsafe extern "C" fn SDL_SetWindowBordered(
    window: *mut SDL_Window,
    bordered: bool,
) -> bool
Set the border state of a window.

This will add or remove the window’s SDL_WINDOW_BORDERLESS flag and add or remove the border from the actual window. This is a no-op if the window’s border already matches the requested state.

You can’t change the border state of a fullscreen window.

Parameter: window the window of which to change the border state. Parameter: bordered false to remove border, true to add border. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetWindowFlags