SDL_SetWindowFocusable

Function SDL_SetWindowFocusable 

pub unsafe extern "C" fn SDL_SetWindowFocusable(
    window: *mut SDL_Window,
    focusable: bool,
) -> bool
Set whether the window may have input focus.

Parameter: window the window to set focusable state. Parameter: focusable true to allow input focus, false to not allow input focus. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.