SDL_SetWindowIcon

Function SDL_SetWindowIcon 

pub unsafe extern "C" fn SDL_SetWindowIcon(
    window: *mut SDL_Window,
    icon: *mut SDL_Surface,
) -> bool
Set the icon for a window.

If this function is passed a surface with alternate representations added using SDL_AddSurfaceAlternateImage(), the surface will be interpreted as the content to be used for 100% display scale, and the alternate representations will be used for high DPI situations. For example, if the original surface is 32x32, then on a 2x macOS display or 200% display scale on Windows, a 64x64 version of the image will be used, if available. If a matching version of the image isn’t available, the closest larger size image will be downscaled to the appropriate size and be used instead, if available. Otherwise, the closest smaller image will be upscaled and be used instead.

Parameter: window the window to change. Parameter: icon an SDL_Surface structure containing the icon for the window. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_AddSurfaceAlternateImage