SDL_SetWindowMaximumSize

Function SDL_SetWindowMaximumSize 

pub unsafe extern "C" fn SDL_SetWindowMaximumSize(
    window: *mut SDL_Window,
    max_w: c_int,
    max_h: c_int,
) -> bool
Set the maximum size of a window’s client area.

Parameter: window the window to change. Parameter: max_w the maximum width of the window, or 0 for no limit. Parameter: max_h the maximum height of the window, or 0 for no limit. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetWindowMaximumSize See Also: SDL_SetWindowMinimumSize