SDL_SetWindowMinimumSize

Function SDL_SetWindowMinimumSize 

pub unsafe extern "C" fn SDL_SetWindowMinimumSize(
    window: *mut SDL_Window,
    min_w: c_int,
    min_h: c_int,
) -> bool
Set the minimum size of a window’s client area.

Parameter: window the window to change. Parameter: min_w the minimum width of the window, or 0 for no limit. Parameter: min_h the minimum height of the window, or 0 for no limit. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetWindowMinimumSize See Also: SDL_SetWindowMaximumSize