SDL_SetWindowMouseRect

Function SDL_SetWindowMouseRect 

pub unsafe extern "C" fn SDL_SetWindowMouseRect(
    window: *mut SDL_Window,
    rect: *const SDL_Rect,
) -> bool
Confines the cursor to the specified area of a window.

Note that this does NOT grab the cursor, it only defines the area a cursor is restricted to when the window has mouse focus.

Parameter: window the window that will be associated with the barrier. Parameter: rect a rectangle area in window-relative coordinates. If NULL the barrier for the specified window will be destroyed. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetWindowMouseRect See Also: SDL_GetWindowMouseGrab See Also: SDL_SetWindowMouseGrab