SDL_SetWindowProgressState

Function SDL_SetWindowProgressState 

pub unsafe extern "C" fn SDL_SetWindowProgressState(
    window: *mut SDL_Window,
    state: SDL_ProgressState,
) -> bool
Sets the state of the progress bar for the given window’s taskbar icon.

Parameter: window the window whose progress state is to be modified. Parameter: state the progress state. SDL_PROGRESS_STATE_NONE stops displaying the progress bar. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.4.0.