SDL_SetWindowResizable

Function SDL_SetWindowResizable 

pub unsafe extern "C" fn SDL_SetWindowResizable(
    window: *mut SDL_Window,
    resizable: bool,
) -> bool
Set the user-resizable state of a window.

This will add or remove the window’s SDL_WINDOW_RESIZABLE flag and allow/disallow user resizing of the window. This is a no-op if the window’s resizable state already matches the requested state.

You can’t change the resizable state of a fullscreen window.

Parameter: window the window of which to change the resizable state. Parameter: resizable true to allow resizing, false to disallow. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetWindowFlags