SDL_SetWindowSurfaceVSync

Function SDL_SetWindowSurfaceVSync 

pub unsafe extern "C" fn SDL_SetWindowSurfaceVSync(
    window: *mut SDL_Window,
    vsync: c_int,
) -> bool
Toggle VSync for the window surface.

When a window surface is created, vsync defaults to SDL_WINDOW_SURFACE_VSYNC_DISABLED.

The vsync parameter can be 1 to synchronize present with every vertical refresh, 2 to synchronize present with every second vertical refresh, etc., SDL_WINDOW_SURFACE_VSYNC_ADAPTIVE for late swap tearing (adaptive vsync), or SDL_WINDOW_SURFACE_VSYNC_DISABLED to disable. Not every value is supported by every driver, so you should check the return value to see whether the requested setting is supported.

Parameter: window the window. Parameter: vsync the vertical refresh sync interval. Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetWindowSurfaceVSync