pub unsafe extern "C" fn SDL_SignalAsyncIOQueue(
queue: *mut SDL_AsyncIOQueue,
)Expand description
Wake up any threads that are blocking in SDL_WaitAsyncIOResult().
This will unblock any threads that are sleeping in a call to SDL_WaitAsyncIOResult for the specified queue, and cause them to return from that function.
This can be useful when destroying a queue to make sure nothing is touching it indefinitely. In this case, once this call completes, the caller should take measures to make sure any previously-blocked threads have returned from their wait and will not touch the queue again (perhaps by setting a flag to tell the threads to terminate and then using SDL_WaitThread() to make sure they’ve done so).
Parameter: queue the async I/O task queue to signal.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_WaitAsyncIOResult