pub unsafe extern "C" fn SDL_StopTextInput(
window: *mut SDL_Window,
) -> boolExpand description
Stop receiving any text input events in a window.
If SDL_StartTextInput() showed the screen keyboard, this function will hide it.
Parameter: window the window to disable text input. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_StartTextInput