pub unsafe extern "C" fn SDL_SubmitGPUCommandBuffer(
command_buffer: *mut SDL_GPUCommandBuffer,
) -> boolExpand description
Submits a command buffer so its commands can be processed on the GPU.
It is invalid to use the command buffer after this is called.
This must be called from the thread the command buffer was acquired on.
All commands in the submission are guaranteed to begin executing before any command in a subsequent submission begins executing.
Parameter: command_buffer a command buffer. Returns: true on success, false on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_AcquireGPUCommandBuffer See Also: SDL_WaitAndAcquireGPUSwapchainTexture See Also: SDL_AcquireGPUSwapchainTexture See Also: SDL_SubmitGPUCommandBufferAndAcquireFence