SDL_SurfaceHasColorKey

Function SDL_SurfaceHasColorKey 

pub unsafe extern "C" fn SDL_SurfaceHasColorKey(
    surface: *mut SDL_Surface,
) -> bool
Returns whether the surface has a color key.

It is safe to pass a NULL surface here; it will return false.

Parameter: surface the SDL_Surface structure to query. Returns: true if the surface has a color key, false otherwise.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SetSurfaceColorKey See Also: SDL_GetSurfaceColorKey