SDL_TextInputActive

Function SDL_TextInputActive 

pub unsafe extern "C" fn SDL_TextInputActive(
    window: *mut SDL_Window,
) -> bool
Check whether or not Unicode text input events are enabled for a window.

Parameter: window the window to check. Returns: true if text input events are enabled else false.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_StartTextInput