SDL_UnloadObject

Function SDL_UnloadObject 

pub unsafe extern "C" fn SDL_UnloadObject(
    handle: *mut SDL_SharedObject,
)
Unload a shared object from memory.

Note that any pointers from this object looked up through SDL_LoadFunction() will no longer be valid.

Parameter: handle a valid shared object handle returned by SDL_LoadObject().

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_LoadObject