SDL_UpdateHapticEffect

Function SDL_UpdateHapticEffect 

pub unsafe extern "C" fn SDL_UpdateHapticEffect(
    haptic: *mut SDL_Haptic,
    effect: SDL_HapticEffectID,
    data: *const SDL_HapticEffect,
) -> bool
Update the properties of an effect.

Can be used dynamically, although behavior when dynamically changing direction may be strange. Specifically the effect may re-upload itself and start playing from the start. You also cannot change the type either when running SDL_UpdateHapticEffect().

Parameter: haptic the SDL_Haptic device that has the effect. Parameter: effect the identifier of the effect to update. Parameter: data an SDL_HapticEffect structure containing the new effect properties to use. Returns: true on success or false on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateHapticEffect See Also: SDL_RunHapticEffect