pub unsafe extern "C" fn SDL_UpdateTexture(
texture: *mut SDL_Texture,
rect: *const SDL_Rect,
pixels: *const c_void,
pitch: c_int,
) -> boolExpand description
Update the given texture rectangle with new pixel data.
The pixel data must be in the pixel format of the texture, which can be queried using the SDL_PROP_TEXTURE_FORMAT_NUMBER property.
This is a fairly slow function, intended for use with static textures that do not change often.
If the texture is intended to be updated often, it is preferred to create the texture as streaming and use the locking functions referenced below. While this function will work with streaming textures, for optimization reasons you may not get the pixels back if you lock the texture afterward.
Parameter: texture the texture to update. Parameter: rect an SDL_Rect structure representing the area to update, or NULL to update the entire texture. Parameter: pixels the raw pixel data in the format of the texture. Parameter: pitch the number of bytes in a row of pixel data, including padding between lines. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_LockTexture See Also: SDL_UnlockTexture See Also: SDL_UpdateNVTexture See Also: SDL_UpdateYUVTexture