SDL_WaitEventTimeout

Function SDL_WaitEventTimeout 

pub unsafe extern "C" fn SDL_WaitEventTimeout(
    event: *mut SDL_Event,
    timeoutMS: Sint32,
) -> bool
Wait until the specified timeout (in milliseconds) for the next available event.

If event is not NULL, the next event is removed from the queue and stored in the SDL_Event structure pointed to by event.

As this function may implicitly call SDL_PumpEvents(), you can only call this function in the thread that initialized the video subsystem.

The timeout is not guaranteed, the actual wait time could be longer due to system scheduling.

Parameter: event the SDL_Event structure to be filled in with the next event from the queue, or NULL. Parameter: timeoutMS the maximum number of milliseconds to wait for the next available event. Returns: true if this got an event or false if the timeout elapsed without any events available.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_PollEvent See Also: SDL_PushEvent See Also: SDL_WaitEvent