SDL_WaitForGPUFences

Function SDL_WaitForGPUFences 

pub unsafe extern "C" fn SDL_WaitForGPUFences(
    device: *mut SDL_GPUDevice,
    wait_all: bool,
    fences: *const *mut SDL_GPUFence,
    num_fences: Uint32,
) -> bool
Blocks the thread until the given fences are signaled.

Parameter: device a GPU context. Parameter: wait_all if 0, wait for any fence to be signaled, if 1, wait for all fences to be signaled. Parameter: fences an array of fences to wait on. Parameter: num_fences the number of fences in the fences array. Returns: true on success, false on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_SubmitGPUCommandBufferAndAcquireFence See Also: SDL_WaitForGPUIdle