SDL_WriteStorageFile

Function SDL_WriteStorageFile 

pub unsafe extern "C" fn SDL_WriteStorageFile(
    storage: *mut SDL_Storage,
    path: *const c_char,
    source: *const c_void,
    length: Uint64,
) -> bool
Synchronously write a file from client memory into a storage container.

Parameter: storage a storage container to write to. Parameter: path the relative path of the file to write. Parameter: source a client-provided buffer to write from. Parameter: length the length of the source buffer. Returns: true if the file was written or false on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_GetStorageSpaceRemaining See Also: SDL_ReadStorageFile See Also: SDL_StorageReady