SDL_aligned_free

Function SDL_aligned_free 

pub unsafe extern "C" fn SDL_aligned_free(mem: *mut c_void)
Free memory allocated by SDL_aligned_alloc().

The pointer is no longer valid after this call and cannot be dereferenced anymore.

If mem is NULL, this function does nothing.

Parameter: mem a pointer previously returned by SDL_aligned_alloc(), or NULL.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_aligned_alloc