SDL_ispunct

Function SDL_ispunct 

pub unsafe extern "C" fn SDL_ispunct(x: c_int) -> c_int
Report if a character is a punctuation mark.

WARNING: Regardless of system locale, this is equivalent to ((SDL_isgraph(x)) && (!SDL_isalnum(x))).

Parameter: x character value to check. Returns: non-zero if x falls within the character class, zero otherwise.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_isgraph See Also: SDL_isalnum