SDL_malloc

Function SDL_malloc 

pub unsafe extern "C" fn SDL_malloc(size: usize) -> *mut c_void
Allocate uninitialized memory.

The allocated memory returned by this function must be freed with SDL_free().

If size is 0, it will be set to 1.

If the allocation is successful, the returned pointer is guaranteed to be aligned to either the fundamental alignment (alignof(max_align_t) in C11 and later) or 2 * sizeof(void *), whichever is smaller. Use SDL_aligned_alloc() if you need to allocate memory aligned to an alignment greater than this guarantee.

Parameter: size the size to allocate. Returns: a pointer to the allocated memory, or NULL if allocation failed.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_free See Also: SDL_calloc See Also: SDL_realloc See Also: SDL_aligned_alloc