pub unsafe extern "C" fn SDL_strcmp(
str1: *const c_char,
str2: *const c_char,
) -> c_intExpand description
Compare two null-terminated UTF-8 strings.
Due to the nature of UTF-8 encoding, this will work with Unicode strings, since effectively this function just compares bytes until it hits a null-terminating character. Also due to the nature of UTF-8, this can be used with SDL_qsort() to put strings in (roughly) alphabetical order.
Parameter: str1 the first string to compare. NULL is not permitted! Parameter: str2 the second string to compare. NULL is not permitted! Returns: less than zero if str1 is “less than” str2, greater than zero if str1 is “greater than” str2, and zero if the strings match exactly.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.