pub unsafe extern "C" fn SDL_vsnprintf(
text: *mut c_char,
maxlen: usize,
fmt: *const c_char,
ap: *mut __va_list_tag,
) -> c_intExpand description
This works exactly like vsnprintf() but doesn’t require access to a C runtime.
Functions identically to SDL_snprintf(), except it takes a va_list
instead of using ... variable arguments.
Parameter: text the buffer to write the string into. Must not be NULL.
Parameter: maxlen the maximum bytes to write, including the null-terminator.
Parameter: fmt a printf-style format string. Must not be NULL.
Parameter: ap a va_list values to be used with the format string.
Returns: the number of bytes that should be written, not counting the
null-terminator char, or a negative value on error.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.