SDL_AppResult

Struct SDL_AppResult 

#[repr(transparent)]
pub struct SDL_AppResult(pub c_uint);
Return values for optional main callbacks.

Returning SDL_APP_SUCCESS or SDL_APP_FAILURE from SDL_AppInit, SDL_AppEvent, or SDL_AppIterate will terminate the program and report success/failure to the operating system. What that means is platform-dependent. On Unix, for example, on success, the process error code will be zero, and on failure it will be 1. This interface doesn’t allow you to return specific exit codes, just whether there was an error generally or not.

Returning SDL_APP_CONTINUE from these functions will let the app continue to run.

See Main callbacks in SDL3 for complete details.

Available Since: This enum is available since SDL 3.2.0.

Tuple Fields

0: c_uint

Implementations

Source

impl SDL_AppResult

pub const SDL_APP_CONTINUE: SDL_AppResult

< Value that requests that the app continue from the main callbacks.

pub const SDL_APP_SUCCESS: SDL_AppResult

< Value that requests termination with success from the main callbacks.

pub const SDL_APP_FAILURE: SDL_AppResult

< Value that requests termination with error from the main callbacks.