#[repr(C)]pub struct SDL_AssertData {
pub always_ignore: bool,
pub trigger_count: c_uint,
pub condition: *const c_char,
pub filename: *const c_char,
pub linenum: c_int,
pub function: *const c_char,
pub next: *const SDL_AssertData,
}Expand description
Information about an assertion failure.
This structure is filled in with information about a triggered assertion, used by the assertion handler, then added to the assertion report. This is returned as a linked list from SDL_GetAssertionReport().
Available Since: This struct is available since SDL 3.2.0.
Fields
always_ignore: bool< true if app should always continue when assertion is triggered.
trigger_count: c_uint< Number of times this assertion has been triggered.
condition: *const c_char< A string of this assert’s test code.
filename: *const c_char< The source file where this assert lives.
linenum: c_int< The line in filename where this assert lives.
function: *const c_char< The name of the function where this assert lives.
next: *const SDL_AssertData< next item in the linked list.