#[repr(transparent)]pub struct SDL_AssertState(pub c_uint);Expand description
Possible outcomes from a triggered assertion.
When an enabled assertion triggers, it may call the assertion handler (possibly one provided by the app via SDL_SetAssertionHandler), which will return one of these values, possibly after asking the user.
Then SDL will respond based on this outcome (loop around to retry the condition, try to break in a debugger, kill the program, or ignore the problem).
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_AssertState
impl SDL_AssertState
Sourcepub const SDL_ASSERTION_RETRY: SDL_AssertState
pub const SDL_ASSERTION_RETRY: SDL_AssertState
< Retry the assert immediately.
Sourcepub const SDL_ASSERTION_BREAK: SDL_AssertState
pub const SDL_ASSERTION_BREAK: SDL_AssertState
< Make the debugger trigger a breakpoint.
Sourcepub const SDL_ASSERTION_ABORT: SDL_AssertState
pub const SDL_ASSERTION_ABORT: SDL_AssertState
< Terminate the program.
Sourcepub const SDL_ASSERTION_IGNORE: SDL_AssertState
pub const SDL_ASSERTION_IGNORE: SDL_AssertState
< Ignore the assert.
Sourcepub const SDL_ASSERTION_ALWAYS_IGNORE: SDL_AssertState
pub const SDL_ASSERTION_ALWAYS_IGNORE: SDL_AssertState
< Ignore the assert from now on.