SDL_AsyncIOOutcome

Struct SDL_AsyncIOOutcome 

#[repr(C)]
pub struct SDL_AsyncIOOutcome { pub asyncio: *mut SDL_AsyncIO, pub type_: SDL_AsyncIOTaskType, pub result: SDL_AsyncIOResult, pub buffer: *mut c_void, pub offset: Uint64, pub bytes_requested: Uint64, pub bytes_transferred: Uint64, pub userdata: *mut c_void, }
Information about a completed asynchronous I/O request.

Available Since: This struct is available since SDL 3.2.0.

Fields

asyncio: *mut SDL_AsyncIO

< what generated this task. This pointer will be invalid if it was closed!

type_: SDL_AsyncIOTaskType

< What sort of task was this? Read, write, etc?

result: SDL_AsyncIOResult

< the result of the work (success, failure, cancellation).

buffer: *mut c_void

< buffer where data was read/written.

offset: Uint64

< offset in the SDL_AsyncIO where data was read/written.

bytes_requested: Uint64

< number of bytes the task was to read/write.

bytes_transferred: Uint64

< actual number of bytes that were read/written.

userdata: *mut c_void

< pointer provided by the app when starting the task