#[repr(transparent)]pub struct SDL_BlendFactor(pub c_uint);Expand description
The normalized factor used to multiply pixel components.
The blend factors are multiplied with the pixels from a drawing operation (src) and the pixels from the render target (dst) before the blend operation. The comma-separated factors listed above are always applied in the component order red, green, blue, and alpha.
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_BlendFactor
impl SDL_BlendFactor
Sourcepub const SDL_BLENDFACTOR_ZERO: SDL_BlendFactor
pub const SDL_BLENDFACTOR_ZERO: SDL_BlendFactor
< 0, 0, 0, 0
Sourcepub const SDL_BLENDFACTOR_ONE: SDL_BlendFactor
pub const SDL_BLENDFACTOR_ONE: SDL_BlendFactor
< 1, 1, 1, 1
Sourcepub const SDL_BLENDFACTOR_SRC_COLOR: SDL_BlendFactor
pub const SDL_BLENDFACTOR_SRC_COLOR: SDL_BlendFactor
< srcR, srcG, srcB, srcA
Sourcepub const SDL_BLENDFACTOR_ONE_MINUS_SRC_COLOR: SDL_BlendFactor
pub const SDL_BLENDFACTOR_ONE_MINUS_SRC_COLOR: SDL_BlendFactor
< 1-srcR, 1-srcG, 1-srcB, 1-srcA
Sourcepub const SDL_BLENDFACTOR_SRC_ALPHA: SDL_BlendFactor
pub const SDL_BLENDFACTOR_SRC_ALPHA: SDL_BlendFactor
< srcA, srcA, srcA, srcA
Sourcepub const SDL_BLENDFACTOR_ONE_MINUS_SRC_ALPHA: SDL_BlendFactor
pub const SDL_BLENDFACTOR_ONE_MINUS_SRC_ALPHA: SDL_BlendFactor
< 1-srcA, 1-srcA, 1-srcA, 1-srcA
Sourcepub const SDL_BLENDFACTOR_DST_COLOR: SDL_BlendFactor
pub const SDL_BLENDFACTOR_DST_COLOR: SDL_BlendFactor
< dstR, dstG, dstB, dstA
Sourcepub const SDL_BLENDFACTOR_ONE_MINUS_DST_COLOR: SDL_BlendFactor
pub const SDL_BLENDFACTOR_ONE_MINUS_DST_COLOR: SDL_BlendFactor
< 1-dstR, 1-dstG, 1-dstB, 1-dstA
Sourcepub const SDL_BLENDFACTOR_DST_ALPHA: SDL_BlendFactor
pub const SDL_BLENDFACTOR_DST_ALPHA: SDL_BlendFactor
< dstA, dstA, dstA, dstA
Sourcepub const SDL_BLENDFACTOR_ONE_MINUS_DST_ALPHA: SDL_BlendFactor
pub const SDL_BLENDFACTOR_ONE_MINUS_DST_ALPHA: SDL_BlendFactor
< 1-dstA, 1-dstA, 1-dstA, 1-dstA