#[repr(transparent)]pub struct SDL_DisplayOrientation(pub c_uint);Expand description
Display orientation values; the way a display is rotated.
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_DisplayOrientation
impl SDL_DisplayOrientation
Sourcepub const SDL_ORIENTATION_UNKNOWN: SDL_DisplayOrientation
pub const SDL_ORIENTATION_UNKNOWN: SDL_DisplayOrientation
< The display orientation can’t be determined
Sourcepub const SDL_ORIENTATION_LANDSCAPE: SDL_DisplayOrientation
pub const SDL_ORIENTATION_LANDSCAPE: SDL_DisplayOrientation
< The display is in landscape mode, with the right side up, relative to portrait mode
Sourcepub const SDL_ORIENTATION_LANDSCAPE_FLIPPED: SDL_DisplayOrientation
pub const SDL_ORIENTATION_LANDSCAPE_FLIPPED: SDL_DisplayOrientation
< The display is in landscape mode, with the left side up, relative to portrait mode
Sourcepub const SDL_ORIENTATION_PORTRAIT: SDL_DisplayOrientation
pub const SDL_ORIENTATION_PORTRAIT: SDL_DisplayOrientation
< The display is in portrait mode
Sourcepub const SDL_ORIENTATION_PORTRAIT_FLIPPED: SDL_DisplayOrientation
pub const SDL_ORIENTATION_PORTRAIT_FLIPPED: SDL_DisplayOrientation
< The display is in portrait mode, upside down