#[repr(C)]pub struct SDL_DropEvent {
pub type_: SDL_EventType,
pub reserved: Uint32,
pub timestamp: Uint64,
pub windowID: SDL_WindowID,
pub x: f32,
pub y: f32,
pub source: *const c_char,
pub data: *const c_char,
}Expand description
An event used to drop text or request a file open by the system (event.drop.*)
Available Since: This struct is available since SDL 3.2.0.
Fields
type_: SDL_EventType< SDL_EVENT_DROP_BEGIN or SDL_EVENT_DROP_FILE or SDL_EVENT_DROP_TEXT or SDL_EVENT_DROP_COMPLETE or SDL_EVENT_DROP_POSITION
reserved: Uint32timestamp: Uint64< In nanoseconds, populated using SDL_GetTicksNS()
windowID: SDL_WindowID< The window that was dropped on, if any
x: f32< X coordinate, relative to window (not on begin)
y: f32< Y coordinate, relative to window (not on begin)
source: *const c_char< The source app that sent this drop event, or NULL if that isn’t available
data: *const c_char< The text for SDL_EVENT_DROP_TEXT and the file name for SDL_EVENT_DROP_FILE, NULL for other events