#[repr(C)]pub struct SDL_Finger {
pub id: SDL_FingerID,
pub x: f32,
pub y: f32,
pub pressure: f32,
}Expand description
Data about a single finger in a multitouch event.
Each touch event is a collection of fingers that are simultaneously in contact with the touch device (so a “touch” can be a “multitouch,” in reality), and this struct reports details of the specific fingers.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_GetTouchFingers
Fields
id: SDL_FingerID< the finger ID
x: f32< the x-axis location of the touch event, normalized (0…1)
y: f32< the y-axis location of the touch event, normalized (0…1)
pressure: f32< the quantity of pressure applied, normalized (0…1)