SDL_Folder

Struct SDL_Folder 

#[repr(transparent)]
pub struct SDL_Folder(pub c_uint);
The type of the OS-provided default folder for a specific purpose.

Note that the Trash folder isn’t included here, because trashing files usually involves extra OS-specific functionality to remember the file’s original location.

The folders supported per platform are:

WindowsmacOS/iOStvOSUnix (XDG)HaikuEmscripten
HOMEXXXXX
DESKTOPXXXX
DOCUMENTSXXX
DOWNLOADSVista+XX
MUSICXXX
PICTURESXXX
PUBLICSHAREXX
SAVEDGAMESVista+
SCREENSHOTSVista+
TEMPLATESXXX
VIDEOSXX*X

Note that on macOS/iOS, the Videos folder is called “Movies”.

Available Since: This enum is available since SDL 3.2.0.

See Also: SDL_GetUserFolder

Tuple Fields

0: c_uint

Implementations

Source

impl SDL_Folder

pub const SDL_FOLDER_HOME: SDL_Folder

< The folder which contains all of the current user’s data, preferences, and documents. It usually contains most of the other folders. If a requested folder does not exist, the home folder can be considered a safe fallback to store a user’s documents.

pub const SDL_FOLDER_DESKTOP: SDL_Folder

< The folder of files that are displayed on the desktop. Note that the existence of a desktop folder does not guarantee that the system does show icons on its desktop; certain GNU/Linux distros with a graphical environment may not have desktop icons.

pub const SDL_FOLDER_DOCUMENTS: SDL_Folder

< User document files, possibly application-specific. This is a good place to save a user’s projects.

pub const SDL_FOLDER_DOWNLOADS: SDL_Folder

< Standard folder for user files downloaded from the internet.

pub const SDL_FOLDER_MUSIC: SDL_Folder

< Music files that can be played using a standard music player (mp3, ogg…).

pub const SDL_FOLDER_PICTURES: SDL_Folder

< Image files that can be displayed using a standard viewer (png, jpg…).

pub const SDL_FOLDER_PUBLICSHARE: SDL_Folder

< Files that are meant to be shared with other users on the same computer.

pub const SDL_FOLDER_SAVEDGAMES: SDL_Folder

< Save files for games.

pub const SDL_FOLDER_SCREENSHOTS: SDL_Folder

< Application screenshots.

pub const SDL_FOLDER_TEMPLATES: SDL_Folder

< Template files to be used when the user requests the desktop environment to create a new file in a certain folder, such as “New Text File.txt”. Any file in the Templates folder can be used as a starting point for a new file.

pub const SDL_FOLDER_VIDEOS: SDL_Folder

< Video files that can be played using a standard video player (mp4, webm…).

pub const SDL_FOLDER_COUNT: SDL_Folder

< Total number of types in this enum, not a folder type by itself.