SDL_GPUBlendFactor

Struct SDL_GPUBlendFactor 

#[repr(transparent)]
pub struct SDL_GPUBlendFactor(pub c_uint);
Specifies a blending factor to be used when pixels in a render target are blended with existing pixels in the texture.

The source color is the value written by the fragment shader. The destination color is the value currently existing in the texture.

Available Since: This enum is available since SDL 3.2.0.

See Also: SDL_CreateGPUGraphicsPipeline

Tuple Fields

0: c_uint

Implementations