#[repr(C)]pub struct SDL_GPUColorTargetBlendState {
pub src_color_blendfactor: SDL_GPUBlendFactor,
pub dst_color_blendfactor: SDL_GPUBlendFactor,
pub color_blend_op: SDL_GPUBlendOp,
pub src_alpha_blendfactor: SDL_GPUBlendFactor,
pub dst_alpha_blendfactor: SDL_GPUBlendFactor,
pub alpha_blend_op: SDL_GPUBlendOp,
pub color_write_mask: SDL_GPUColorComponentFlags,
pub enable_blend: bool,
pub enable_color_write_mask: bool,
pub padding1: Uint8,
pub padding2: Uint8,
}Expand description
A structure specifying the blend state of a color target.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_GPUColorTargetDescription See Also: SDL_GPUBlendFactor See Also: SDL_GPUBlendOp See Also: SDL_GPUColorComponentFlags
Fields
src_color_blendfactor: SDL_GPUBlendFactor< The value to be multiplied by the source RGB value.
dst_color_blendfactor: SDL_GPUBlendFactor< The value to be multiplied by the destination RGB value.
color_blend_op: SDL_GPUBlendOp< The blend operation for the RGB components.
src_alpha_blendfactor: SDL_GPUBlendFactor< The value to be multiplied by the source alpha.
dst_alpha_blendfactor: SDL_GPUBlendFactor< The value to be multiplied by the destination alpha.
alpha_blend_op: SDL_GPUBlendOp< The blend operation for the alpha component.
color_write_mask: SDL_GPUColorComponentFlags< A bitmask specifying which of the RGBA components are enabled for writing. Writes to all channels if enable_color_write_mask is false.
enable_blend: bool< Whether blending is enabled for the color target.
enable_color_write_mask: bool< Whether the color write mask is enabled.
padding1: Uint8padding2: Uint8Trait Implementations
Sourceimpl Clone for SDL_GPUColorTargetBlendState
impl Clone for SDL_GPUColorTargetBlendState
Sourcefn clone(&self) -> SDL_GPUColorTargetBlendState
fn clone(&self) -> SDL_GPUColorTargetBlendState
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more