#[repr(C)]pub struct SDL_GPUColorTargetDescription {
pub format: SDL_GPUTextureFormat,
pub blend_state: SDL_GPUColorTargetBlendState,
}Expand description
A structure specifying the parameters of color targets used in a graphics pipeline.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_GPUGraphicsPipelineTargetInfo
Fields
format: SDL_GPUTextureFormat< The pixel format of the texture to be used as a color target.
blend_state: SDL_GPUColorTargetBlendState< The blend state to be used for the color target.