SDL_GPUDepthStencilState

Struct SDL_GPUDepthStencilState 

#[repr(C)]
pub struct SDL_GPUDepthStencilState { pub compare_op: SDL_GPUCompareOp, pub back_stencil_state: SDL_GPUStencilOpState, pub front_stencil_state: SDL_GPUStencilOpState, pub compare_mask: Uint8, pub write_mask: Uint8, pub enable_depth_test: bool, pub enable_depth_write: bool, pub enable_stencil_test: bool, pub padding1: Uint8, pub padding2: Uint8, pub padding3: Uint8, }
A structure specifying the parameters of the graphics pipeline depth stencil state.

Available Since: This struct is available since SDL 3.2.0.

See Also: SDL_GPUGraphicsPipelineCreateInfo

Fields

compare_op: SDL_GPUCompareOp

< The comparison operator used for depth testing.

back_stencil_state: SDL_GPUStencilOpState

< The stencil op state for back-facing triangles.

front_stencil_state: SDL_GPUStencilOpState

< The stencil op state for front-facing triangles.

compare_mask: Uint8

< Selects the bits of the stencil values participating in the stencil test.

write_mask: Uint8

< Selects the bits of the stencil values updated by the stencil test.

enable_depth_test: bool

< true enables the depth test.

enable_depth_write: bool

< true enables depth writes. Depth writes are always disabled when enable_depth_test is false.

enable_stencil_test: bool

< true enables the stencil test.

padding1: Uint8padding2: Uint8padding3: Uint8