#[repr(transparent)]pub struct SDL_GPUFrontFace(pub c_uint);Expand description
Specifies the vertex winding that will cause a triangle to be determined to be front-facing.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_CreateGPUGraphicsPipeline
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GPUFrontFace
impl SDL_GPUFrontFace
Sourcepub const SDL_GPU_FRONTFACE_COUNTER_CLOCKWISE: SDL_GPUFrontFace
pub const SDL_GPU_FRONTFACE_COUNTER_CLOCKWISE: SDL_GPUFrontFace
< A triangle with counter-clockwise vertex winding will be considered front-facing.
Sourcepub const SDL_GPU_FRONTFACE_CLOCKWISE: SDL_GPUFrontFace
pub const SDL_GPU_FRONTFACE_CLOCKWISE: SDL_GPUFrontFace
< A triangle with clockwise vertex winding will be considered front-facing.