#[repr(C)]pub struct SDL_GPUGraphicsPipelineCreateInfo {
pub vertex_shader: *mut SDL_GPUShader,
pub fragment_shader: *mut SDL_GPUShader,
pub vertex_input_state: SDL_GPUVertexInputState,
pub primitive_type: SDL_GPUPrimitiveType,
pub rasterizer_state: SDL_GPURasterizerState,
pub multisample_state: SDL_GPUMultisampleState,
pub depth_stencil_state: SDL_GPUDepthStencilState,
pub target_info: SDL_GPUGraphicsPipelineTargetInfo,
pub props: SDL_PropertiesID,
}Expand description
A structure specifying the parameters of a graphics pipeline state.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_CreateGPUGraphicsPipeline See Also: SDL_GPUShader See Also: SDL_GPUVertexInputState See Also: SDL_GPUPrimitiveType See Also: SDL_GPURasterizerState See Also: SDL_GPUMultisampleState See Also: SDL_GPUDepthStencilState See Also: SDL_GPUGraphicsPipelineTargetInfo
Fields
vertex_shader: *mut SDL_GPUShader< The vertex shader used by the graphics pipeline.
fragment_shader: *mut SDL_GPUShader< The fragment shader used by the graphics pipeline.
vertex_input_state: SDL_GPUVertexInputState< The vertex layout of the graphics pipeline.
primitive_type: SDL_GPUPrimitiveType< The primitive topology of the graphics pipeline.
rasterizer_state: SDL_GPURasterizerState< The rasterizer state of the graphics pipeline.
multisample_state: SDL_GPUMultisampleState< The multisample state of the graphics pipeline.
depth_stencil_state: SDL_GPUDepthStencilState< The depth-stencil state of the graphics pipeline.
target_info: SDL_GPUGraphicsPipelineTargetInfo< Formats and blend modes for the render targets of the graphics pipeline.
props: SDL_PropertiesID< A properties ID for extensions. Should be 0 if no extensions are needed.