#[repr(C)]pub struct SDL_GPUGraphicsPipelineTargetInfo {
pub color_target_descriptions: *const SDL_GPUColorTargetDescription,
pub num_color_targets: Uint32,
pub depth_stencil_format: SDL_GPUTextureFormat,
pub has_depth_stencil_target: bool,
pub padding1: Uint8,
pub padding2: Uint8,
pub padding3: Uint8,
}Expand description
A structure specifying the descriptions of render targets used in a graphics pipeline.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_GPUGraphicsPipelineCreateInfo See Also: SDL_GPUColorTargetDescription See Also: SDL_GPUTextureFormat
Fields
color_target_descriptions: *const SDL_GPUColorTargetDescription< A pointer to an array of color target descriptions.
num_color_targets: Uint32< The number of color target descriptions in the above array.
depth_stencil_format: SDL_GPUTextureFormat< The pixel format of the depth-stencil target. Ignored if has_depth_stencil_target is false.
has_depth_stencil_target: bool< true specifies that the pipeline uses a depth-stencil target.
padding1: Uint8padding2: Uint8padding3: Uint8Trait Implementations
Sourceimpl Clone for SDL_GPUGraphicsPipelineTargetInfo
impl Clone for SDL_GPUGraphicsPipelineTargetInfo
Sourcefn clone(&self) -> SDL_GPUGraphicsPipelineTargetInfo
fn clone(&self) -> SDL_GPUGraphicsPipelineTargetInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SDL_GPUGraphicsPipelineTargetInfo