#[repr(C)]pub struct SDL_GPUIndexedIndirectDrawCommand {
pub num_indices: Uint32,
pub num_instances: Uint32,
pub first_index: Uint32,
pub vertex_offset: Sint32,
pub first_instance: Uint32,
}Expand description
A structure specifying the parameters of an indexed indirect draw command.
Note that the first_vertex and first_instance parameters are NOT
compatible with built-in vertex/instance ID variables in shaders (for
example, SV_VertexID); GPU APIs and shader languages do not define these
built-in variables consistently, so if your shader depends on them, the
only way to keep behavior consistent and portable is to always pass 0 for
the correlating parameter in the draw calls.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_DrawGPUIndexedPrimitivesIndirect
Fields
num_indices: Uint32< The number of indices to draw per instance.
num_instances: Uint32< The number of instances to draw.
first_index: Uint32< The base index within the index buffer.
vertex_offset: Sint32< The value added to the vertex index before indexing into the vertex buffer.
first_instance: Uint32< The ID of the first instance to draw.