#[repr(transparent)]pub struct SDL_GPULoadOp(pub c_uint);Expand description
Specifies how the contents of a texture attached to a render pass are treated at the beginning of the render pass.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_BeginGPURenderPass
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GPULoadOp
impl SDL_GPULoadOp
Sourcepub const SDL_GPU_LOADOP_LOAD: SDL_GPULoadOp
pub const SDL_GPU_LOADOP_LOAD: SDL_GPULoadOp
< The previous contents of the texture will be preserved.
Sourcepub const SDL_GPU_LOADOP_CLEAR: SDL_GPULoadOp
pub const SDL_GPU_LOADOP_CLEAR: SDL_GPULoadOp
< The contents of the texture will be cleared to a color.
Sourcepub const SDL_GPU_LOADOP_DONT_CARE: SDL_GPULoadOp
pub const SDL_GPU_LOADOP_DONT_CARE: SDL_GPULoadOp
< The previous contents of the texture need not be preserved. The contents will be undefined.