SDL_GPUPrimitiveType

Struct SDL_GPUPrimitiveType 

#[repr(transparent)]
pub struct SDL_GPUPrimitiveType(pub c_uint);
Specifies the primitive topology of a graphics pipeline.

If you are using POINTLIST you must include a point size output in the vertex shader.

  • For HLSL compiling to SPIRV you must decorate a float output with [[vk::builtin(“PointSize”)]].
  • For GLSL you must set the gl_PointSize builtin.
  • For MSL you must include a float output with the [[point_size]] decorator.

Note that sized point topology is totally unsupported on D3D12. Any size other than 1 will be ignored. In general, you should avoid using point topology for both compatibility and performance reasons. You WILL regret using it.

Available Since: This enum is available since SDL 3.2.0.

See Also: SDL_CreateGPUGraphicsPipeline

Tuple Fields

0: c_uint

Implementations

Source

impl SDL_GPUPrimitiveType

pub const SDL_GPU_PRIMITIVETYPE_TRIANGLELIST: SDL_GPUPrimitiveType

< A series of separate triangles.

pub const SDL_GPU_PRIMITIVETYPE_TRIANGLESTRIP: SDL_GPUPrimitiveType

< A series of connected triangles.

pub const SDL_GPU_PRIMITIVETYPE_LINELIST: SDL_GPUPrimitiveType

< A series of separate lines.

pub const SDL_GPU_PRIMITIVETYPE_LINESTRIP: SDL_GPUPrimitiveType

< A series of connected lines.

pub const SDL_GPU_PRIMITIVETYPE_POINTLIST: SDL_GPUPrimitiveType

< A series of separate points.