SDL_GPURasterizerState

Struct SDL_GPURasterizerState 

#[repr(C)]
pub struct SDL_GPURasterizerState { pub fill_mode: SDL_GPUFillMode, pub cull_mode: SDL_GPUCullMode, pub front_face: SDL_GPUFrontFace, pub depth_bias_constant_factor: f32, pub depth_bias_clamp: f32, pub depth_bias_slope_factor: f32, pub enable_depth_bias: bool, pub enable_depth_clip: bool, pub padding1: Uint8, pub padding2: Uint8, }
A structure specifying the parameters of the graphics pipeline rasterizer state.

Note that SDL_GPU_FILLMODE_LINE is not supported on many Android devices. For those devices, the fill mode will automatically fall back to FILL.

Also note that the D3D12 driver will enable depth clamping even if enable_depth_clip is true. If you need this clamp+clip behavior, consider enabling depth clip and then manually clamping depth in your fragment shaders on Metal and Vulkan.

Available Since: This struct is available since SDL 3.2.0.

See Also: SDL_GPUGraphicsPipelineCreateInfo

Fields

fill_mode: SDL_GPUFillMode

< Whether polygons will be filled in or drawn as lines.

cull_mode: SDL_GPUCullMode

< The facing direction in which triangles will be culled.

front_face: SDL_GPUFrontFace

< The vertex winding that will cause a triangle to be determined as front-facing.

depth_bias_constant_factor: f32

< A scalar factor controlling the depth value added to each fragment.

depth_bias_clamp: f32

< The maximum depth bias of a fragment.

depth_bias_slope_factor: f32

< A scalar factor applied to a fragment’s slope in depth calculations.

enable_depth_bias: bool

< true to bias fragment depth values.

enable_depth_clip: bool

< true to enable depth clip, false to enable depth clamp.

padding1: Uint8padding2: Uint8