#[repr(transparent)]pub struct SDL_GPUSamplerAddressMode(pub c_uint);Expand description
Specifies behavior of texture sampling when the coordinates exceed the 0-1 range.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_CreateGPUSampler
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GPUSamplerAddressMode
impl SDL_GPUSamplerAddressMode
Sourcepub const SDL_GPU_SAMPLERADDRESSMODE_REPEAT: SDL_GPUSamplerAddressMode
pub const SDL_GPU_SAMPLERADDRESSMODE_REPEAT: SDL_GPUSamplerAddressMode
< Specifies that the coordinates will wrap around.
Sourcepub const SDL_GPU_SAMPLERADDRESSMODE_MIRRORED_REPEAT: SDL_GPUSamplerAddressMode
pub const SDL_GPU_SAMPLERADDRESSMODE_MIRRORED_REPEAT: SDL_GPUSamplerAddressMode
< Specifies that the coordinates will wrap around mirrored.
Sourcepub const SDL_GPU_SAMPLERADDRESSMODE_CLAMP_TO_EDGE: SDL_GPUSamplerAddressMode
pub const SDL_GPU_SAMPLERADDRESSMODE_CLAMP_TO_EDGE: SDL_GPUSamplerAddressMode
< Specifies that the coordinates will clamp to the 0-1 range.