SDL_GPUSamplerCreateInfo

Struct SDL_GPUSamplerCreateInfo 

#[repr(C)]
pub struct SDL_GPUSamplerCreateInfo {
Show 16 fields pub min_filter: SDL_GPUFilter, pub mag_filter: SDL_GPUFilter, pub mipmap_mode: SDL_GPUSamplerMipmapMode, pub address_mode_u: SDL_GPUSamplerAddressMode, pub address_mode_v: SDL_GPUSamplerAddressMode, pub address_mode_w: SDL_GPUSamplerAddressMode, pub mip_lod_bias: f32, pub max_anisotropy: f32, pub compare_op: SDL_GPUCompareOp, pub min_lod: f32, pub max_lod: f32, pub enable_anisotropy: bool, pub enable_compare: bool, pub padding1: Uint8, pub padding2: Uint8, pub props: SDL_PropertiesID,
}
A structure specifying the parameters of a sampler.

Note that mip_lod_bias is a no-op for the Metal driver. For Metal, LOD bias must be applied via shader instead.

Available Since: This function is available since SDL 3.2.0.

See Also: SDL_CreateGPUSampler See Also: SDL_GPUFilter See Also: SDL_GPUSamplerMipmapMode See Also: SDL_GPUSamplerAddressMode See Also: SDL_GPUCompareOp

Fields

min_filter: SDL_GPUFilter

< The minification filter to apply to lookups.

mag_filter: SDL_GPUFilter

< The magnification filter to apply to lookups.

mipmap_mode: SDL_GPUSamplerMipmapMode

< The mipmap filter to apply to lookups.

address_mode_u: SDL_GPUSamplerAddressMode

< The addressing mode for U coordinates outside [0, 1).

address_mode_v: SDL_GPUSamplerAddressMode

< The addressing mode for V coordinates outside [0, 1).

address_mode_w: SDL_GPUSamplerAddressMode

< The addressing mode for W coordinates outside [0, 1).

mip_lod_bias: f32

< The bias to be added to mipmap LOD calculation.

max_anisotropy: f32

< The anisotropy value clamp used by the sampler. If enable_anisotropy is false, this is ignored.

compare_op: SDL_GPUCompareOp

< The comparison operator to apply to fetched data before filtering.

min_lod: f32

< Clamps the minimum of the computed LOD value.

max_lod: f32

< Clamps the maximum of the computed LOD value.

enable_anisotropy: bool

< true to enable anisotropic filtering.

enable_compare: bool

< true to enable comparison against a reference value during lookups.

padding1: Uint8padding2: Uint8props: SDL_PropertiesID

< A properties ID for extensions. Should be 0 if no extensions are needed.