#[repr(C)]pub struct SDL_GPUShaderCreateInfo {
pub code_size: usize,
pub code: *const Uint8,
pub entrypoint: *const c_char,
pub format: SDL_GPUShaderFormat,
pub stage: SDL_GPUShaderStage,
pub num_samplers: Uint32,
pub num_storage_textures: Uint32,
pub num_storage_buffers: Uint32,
pub num_uniform_buffers: Uint32,
pub props: SDL_PropertiesID,
}Expand description
A structure specifying code and metadata for creating a shader object.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_CreateGPUShader See Also: SDL_GPUShaderFormat See Also: SDL_GPUShaderStage
Fields
code_size: usize< The size in bytes of the code pointed to.
code: *const Uint8< A pointer to shader code.
entrypoint: *const c_char< A pointer to a null-terminated UTF-8 string specifying the entry point function name for the shader.
format: SDL_GPUShaderFormat< The format of the shader code.
stage: SDL_GPUShaderStage< The stage the shader program corresponds to.
num_samplers: Uint32< The number of samplers defined in the shader.
num_storage_textures: Uint32< The number of storage textures defined in the shader.
num_storage_buffers: Uint32< The number of storage buffers defined in the shader.
num_uniform_buffers: Uint32< The number of uniform buffers defined in the shader.
props: SDL_PropertiesID< A properties ID for extensions. Should be 0 if no extensions are needed.