#[repr(transparent)]pub struct SDL_GPUStencilOp(pub c_uint);Expand description
Specifies what happens to a stored stencil value if stencil tests fail or pass.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_CreateGPUGraphicsPipeline
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GPUStencilOp
impl SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_INVALID: SDL_GPUStencilOp
Sourcepub const SDL_GPU_STENCILOP_KEEP: SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_KEEP: SDL_GPUStencilOp
< Keeps the current value.
Sourcepub const SDL_GPU_STENCILOP_ZERO: SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_ZERO: SDL_GPUStencilOp
< Sets the value to 0.
Sourcepub const SDL_GPU_STENCILOP_REPLACE: SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_REPLACE: SDL_GPUStencilOp
< Sets the value to reference.
Sourcepub const SDL_GPU_STENCILOP_INCREMENT_AND_CLAMP: SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_INCREMENT_AND_CLAMP: SDL_GPUStencilOp
< Increments the current value and clamps to the maximum value.
Sourcepub const SDL_GPU_STENCILOP_DECREMENT_AND_CLAMP: SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_DECREMENT_AND_CLAMP: SDL_GPUStencilOp
< Decrements the current value and clamps to 0.
Sourcepub const SDL_GPU_STENCILOP_INVERT: SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_INVERT: SDL_GPUStencilOp
< Bitwise-inverts the current value.
Sourcepub const SDL_GPU_STENCILOP_INCREMENT_AND_WRAP: SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_INCREMENT_AND_WRAP: SDL_GPUStencilOp
< Increments the current value and wraps back to 0.
Sourcepub const SDL_GPU_STENCILOP_DECREMENT_AND_WRAP: SDL_GPUStencilOp
pub const SDL_GPU_STENCILOP_DECREMENT_AND_WRAP: SDL_GPUStencilOp
< Decrements the current value and wraps to the maximum value.