#[repr(C)]pub struct SDL_GPUStencilOpState {
pub fail_op: SDL_GPUStencilOp,
pub pass_op: SDL_GPUStencilOp,
pub depth_fail_op: SDL_GPUStencilOp,
pub compare_op: SDL_GPUCompareOp,
}Expand description
A structure specifying the stencil operation state of a graphics pipeline.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_GPUDepthStencilState
Fields
fail_op: SDL_GPUStencilOp< The action performed on samples that fail the stencil test.
pass_op: SDL_GPUStencilOp< The action performed on samples that pass the depth and stencil tests.
depth_fail_op: SDL_GPUStencilOp< The action performed on samples that pass the stencil test and fail the depth test.
compare_op: SDL_GPUCompareOp< The comparison operator used in the stencil test.