#[repr(C)]pub struct SDL_GPUStorageBufferReadWriteBinding {
pub buffer: *mut SDL_GPUBuffer,
pub cycle: bool,
pub padding1: Uint8,
pub padding2: Uint8,
pub padding3: Uint8,
}Expand description
A structure specifying parameters related to binding buffers in a compute pass.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_BeginGPUComputePass
Fields
buffer: *mut SDL_GPUBuffer< The buffer to bind. Must have been created with SDL_GPU_BUFFERUSAGE_COMPUTE_STORAGE_WRITE.
cycle: bool< true cycles the buffer if it is already bound.
padding1: Uint8padding2: Uint8padding3: Uint8Trait Implementations
Sourceimpl Clone for SDL_GPUStorageBufferReadWriteBinding
impl Clone for SDL_GPUStorageBufferReadWriteBinding
Sourcefn clone(&self) -> SDL_GPUStorageBufferReadWriteBinding
fn clone(&self) -> SDL_GPUStorageBufferReadWriteBinding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SDL_GPUStorageBufferReadWriteBinding