#[repr(transparent)]pub struct SDL_GPUStoreOp(pub c_uint);Expand description
Specifies how the contents of a texture attached to a render pass are treated at the end of the render pass.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_BeginGPURenderPass
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GPUStoreOp
impl SDL_GPUStoreOp
Sourcepub const SDL_GPU_STOREOP_STORE: SDL_GPUStoreOp
pub const SDL_GPU_STOREOP_STORE: SDL_GPUStoreOp
< The contents generated during the render pass will be written to memory.
Sourcepub const SDL_GPU_STOREOP_DONT_CARE: SDL_GPUStoreOp
pub const SDL_GPU_STOREOP_DONT_CARE: SDL_GPUStoreOp
< The contents generated during the render pass are not needed and may be discarded. The contents will be undefined.
Sourcepub const SDL_GPU_STOREOP_RESOLVE: SDL_GPUStoreOp
pub const SDL_GPU_STOREOP_RESOLVE: SDL_GPUStoreOp
< The multisample contents generated during the render pass will be resolved to a non-multisample texture. The contents in the multisample texture may then be discarded and will be undefined.
Sourcepub const SDL_GPU_STOREOP_RESOLVE_AND_STORE: SDL_GPUStoreOp
pub const SDL_GPU_STOREOP_RESOLVE_AND_STORE: SDL_GPUStoreOp
< The multisample contents generated during the render pass will be resolved to a non-multisample texture. The contents in the multisample texture will be written to memory.