SDL_GPUSwapchainComposition

Struct SDL_GPUSwapchainComposition 

#[repr(transparent)]
pub struct SDL_GPUSwapchainComposition(pub c_uint);
Specifies the texture format and colorspace of the swapchain textures.

SDR will always be supported. Other compositions may not be supported on certain systems.

It is recommended to query SDL_WindowSupportsGPUSwapchainComposition after claiming the window if you wish to change the swapchain composition from SDR.

  • SDR: B8G8R8A8 or R8G8B8A8 swapchain. Pixel values are in sRGB encoding.
  • SDR_LINEAR: B8G8R8A8_SRGB or R8G8B8A8_SRGB swapchain. Pixel values are stored in memory in sRGB encoding but accessed in shaders in “linear sRGB” encoding which is sRGB but with a linear transfer function.
  • HDR_EXTENDED_LINEAR: R16G16B16A16_FLOAT swapchain. Pixel values are in extended linear sRGB encoding and permits values outside of the [0, 1] range.
  • HDR10_ST2084: A2R10G10B10 or A2B10G10R10 swapchain. Pixel values are in BT.2020 ST2084 (PQ) encoding.

Available Since: This enum is available since SDL 3.2.0.

See Also: SDL_SetGPUSwapchainParameters See Also: SDL_WindowSupportsGPUSwapchainComposition See Also: SDL_WaitAndAcquireGPUSwapchainTexture

Tuple Fields

0: c_uint

Implementations