#[repr(C)]pub struct SDL_GPUTextureCreateInfo {
pub type_: SDL_GPUTextureType,
pub format: SDL_GPUTextureFormat,
pub usage: SDL_GPUTextureUsageFlags,
pub width: Uint32,
pub height: Uint32,
pub layer_count_or_depth: Uint32,
pub num_levels: Uint32,
pub sample_count: SDL_GPUSampleCount,
pub props: SDL_PropertiesID,
}Expand description
A structure specifying the parameters of a texture.
Usage flags can be bitwise OR’d together for combinations of usages. Note that certain usage combinations are invalid, for example SAMPLER and GRAPHICS_STORAGE.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_CreateGPUTexture See Also: SDL_GPUTextureType See Also: SDL_GPUTextureFormat See Also: SDL_GPUTextureUsageFlags See Also: SDL_GPUSampleCount
Fields
type_: SDL_GPUTextureType< The base dimensionality of the texture.
format: SDL_GPUTextureFormat< The pixel format of the texture.
usage: SDL_GPUTextureUsageFlags< How the texture is intended to be used by the client.
width: Uint32< The width of the texture.
height: Uint32< The height of the texture.
layer_count_or_depth: Uint32< The layer count or depth of the texture. This value is treated as a layer count on 2D array textures, and as a depth value on 3D textures.
num_levels: Uint32< The number of mip levels in the texture.
sample_count: SDL_GPUSampleCount< The number of samples per texel. Only applies if the texture is used as a render target.
props: SDL_PropertiesID< A properties ID for extensions. Should be 0 if no extensions are needed.