#[repr(transparent)]pub struct SDL_GPUVertexInputRate(pub c_uint);Expand description
Specifies the rate at which vertex attributes are pulled from buffers.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_CreateGPUGraphicsPipeline
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GPUVertexInputRate
impl SDL_GPUVertexInputRate
Sourcepub const SDL_GPU_VERTEXINPUTRATE_VERTEX: SDL_GPUVertexInputRate
pub const SDL_GPU_VERTEXINPUTRATE_VERTEX: SDL_GPUVertexInputRate
< Attribute addressing is a function of the vertex index.
Sourcepub const SDL_GPU_VERTEXINPUTRATE_INSTANCE: SDL_GPUVertexInputRate
pub const SDL_GPU_VERTEXINPUTRATE_INSTANCE: SDL_GPUVertexInputRate
< Attribute addressing is a function of the instance index.