#[repr(transparent)]pub struct SDL_GamepadAxis(pub c_int);Expand description
The list of axes available on a gamepad
Thumbstick axis values range from SDL_JOYSTICK_AXIS_MIN to SDL_JOYSTICK_AXIS_MAX, and are centered within ~8000 of zero, though advanced UI will allow users to set or autodetect the dead zone, which varies between gamepads.
Trigger axis values range from 0 (released) to SDL_JOYSTICK_AXIS_MAX (fully pressed) when reported by SDL_GetGamepadAxis(). Note that this is not the same range that will be reported by the lower-level SDL_GetJoystickAxis().
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_intImplementations
Sourceimpl SDL_GamepadAxis
impl SDL_GamepadAxis
pub const SDL_GAMEPAD_AXIS_INVALID: SDL_GamepadAxis
pub const SDL_GAMEPAD_AXIS_LEFTX: SDL_GamepadAxis
pub const SDL_GAMEPAD_AXIS_LEFTY: SDL_GamepadAxis
pub const SDL_GAMEPAD_AXIS_RIGHTX: SDL_GamepadAxis
pub const SDL_GAMEPAD_AXIS_RIGHTY: SDL_GamepadAxis
pub const SDL_GAMEPAD_AXIS_LEFT_TRIGGER: SDL_GamepadAxis
pub const SDL_GAMEPAD_AXIS_RIGHT_TRIGGER: SDL_GamepadAxis
pub const SDL_GAMEPAD_AXIS_COUNT: SDL_GamepadAxis