SDL_GamepadButton

Struct SDL_GamepadButton 

#[repr(transparent)]
pub struct SDL_GamepadButton(pub c_int);
The list of buttons available on a gamepad

For controllers that use a diamond pattern for the face buttons, the south/east/west/north buttons below correspond to the locations in the diamond pattern. For Xbox controllers, this would be A/B/X/Y, for Nintendo Switch controllers, this would be B/A/Y/X, for GameCube controllers this would be A/X/B/Y, for PlayStation controllers this would be Cross/Circle/Square/Triangle.

For controllers that don’t use a diamond pattern for the face buttons, the south/east/west/north buttons indicate the buttons labeled A, B, C, D, or 1, 2, 3, 4, or for controllers that aren’t labeled, they are the primary, secondary, etc. buttons.

The activate action is often the south button and the cancel action is often the east button, but in some regions this is reversed, so your game should allow remapping actions based on user preferences.

You can query the labels for the face buttons using SDL_GetGamepadButtonLabel()

Available Since: This enum is available since SDL 3.2.0.

Tuple Fields

0: c_int

Implementations

Source

impl SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_INVALID: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_SOUTH: SDL_GamepadButton

< Bottom face button (e.g. Xbox A button)

pub const SDL_GAMEPAD_BUTTON_EAST: SDL_GamepadButton

< Right face button (e.g. Xbox B button)

pub const SDL_GAMEPAD_BUTTON_WEST: SDL_GamepadButton

< Left face button (e.g. Xbox X button)

pub const SDL_GAMEPAD_BUTTON_NORTH: SDL_GamepadButton

< Top face button (e.g. Xbox Y button)

pub const SDL_GAMEPAD_BUTTON_BACK: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_GUIDE: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_START: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_LEFT_STICK: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_RIGHT_STICK: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_LEFT_SHOULDER: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_RIGHT_SHOULDER: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_DPAD_UP: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_DPAD_DOWN: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_DPAD_LEFT: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_DPAD_RIGHT: SDL_GamepadButton

pub const SDL_GAMEPAD_BUTTON_MISC1: SDL_GamepadButton

< Additional button (e.g. Xbox Series X share button, PS5 microphone button, Nintendo Switch Pro capture button, Amazon Luna microphone button, Google Stadia capture button)

pub const SDL_GAMEPAD_BUTTON_RIGHT_PADDLE1: SDL_GamepadButton

< Upper or primary paddle, under your right hand (e.g. Xbox Elite paddle P1, DualSense Edge RB button, Right Joy-Con SR button)

pub const SDL_GAMEPAD_BUTTON_LEFT_PADDLE1: SDL_GamepadButton

< Upper or primary paddle, under your left hand (e.g. Xbox Elite paddle P3, DualSense Edge LB button, Left Joy-Con SL button)

pub const SDL_GAMEPAD_BUTTON_RIGHT_PADDLE2: SDL_GamepadButton

< Lower or secondary paddle, under your right hand (e.g. Xbox Elite paddle P2, DualSense Edge right Fn button, Right Joy-Con SL button)

pub const SDL_GAMEPAD_BUTTON_LEFT_PADDLE2: SDL_GamepadButton

< Lower or secondary paddle, under your left hand (e.g. Xbox Elite paddle P4, DualSense Edge left Fn button, Left Joy-Con SR button)

pub const SDL_GAMEPAD_BUTTON_TOUCHPAD: SDL_GamepadButton

< PS4/PS5 touchpad button

pub const SDL_GAMEPAD_BUTTON_MISC2: SDL_GamepadButton

< Additional button

pub const SDL_GAMEPAD_BUTTON_MISC3: SDL_GamepadButton

< Additional button (e.g. Nintendo GameCube left trigger click)

pub const SDL_GAMEPAD_BUTTON_MISC4: SDL_GamepadButton

< Additional button (e.g. Nintendo GameCube right trigger click)

pub const SDL_GAMEPAD_BUTTON_MISC5: SDL_GamepadButton

< Additional button

pub const SDL_GAMEPAD_BUTTON_MISC6: SDL_GamepadButton

< Additional button

pub const SDL_GAMEPAD_BUTTON_COUNT: SDL_GamepadButton