#[repr(transparent)]pub struct SDL_GamepadButtonLabel(pub c_uint);Expand description
The set of gamepad button labels
This isn’t a complete set, just the face buttons to make it easy to show button prompts.
For a complete set, you should look at the button and gamepad type and have a set of symbols that work well with your art style.
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GamepadButtonLabel
impl SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_UNKNOWN: SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_A: SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_B: SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_X: SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_Y: SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_CROSS: SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_CIRCLE: SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_SQUARE: SDL_GamepadButtonLabel
pub const SDL_GAMEPAD_BUTTON_LABEL_TRIANGLE: SDL_GamepadButtonLabel