#[repr(C)]pub struct SDL_GamepadSensorEvent {
pub type_: SDL_EventType,
pub reserved: Uint32,
pub timestamp: Uint64,
pub which: SDL_JoystickID,
pub sensor: Sint32,
pub data: [f32; 3],
pub sensor_timestamp: Uint64,
}Expand description
Gamepad sensor event structure (event.gsensor.*)
Available Since: This struct is available since SDL 3.2.0.
Fields
type_: SDL_EventType< SDL_EVENT_GAMEPAD_SENSOR_UPDATE
reserved: Uint32timestamp: Uint64< In nanoseconds, populated using SDL_GetTicksNS()
which: SDL_JoystickID< The joystick instance id
sensor: Sint32< The type of the sensor, one of the values of SDL_SensorType
data: [f32; 3]< Up to 3 values from the sensor, as defined in SDL_sensor.h
sensor_timestamp: Uint64< The timestamp of the sensor reading in nanoseconds, not necessarily synchronized with the system clock