#[repr(transparent)]pub struct SDL_GamepadType(pub c_uint);Expand description
Standard gamepad types.
This type does not necessarily map to first-party controllers from Microsoft/Sony/Nintendo; in many cases, third-party controllers can report as these, either because they were designed for a specific console, or they simply most closely match that console’s controllers (does it have A/B/X/Y buttons or X/O/Square/Triangle? Does it have a touchpad? etc).
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GamepadType
impl SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_UNKNOWN: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_STANDARD: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_XBOX360: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_XBOXONE: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_PS3: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_PS4: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_PS5: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_NINTENDO_SWITCH_PRO: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_NINTENDO_SWITCH_JOYCON_LEFT: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_NINTENDO_SWITCH_JOYCON_RIGHT: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_NINTENDO_SWITCH_JOYCON_PAIR: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_GAMECUBE: SDL_GamepadType
pub const SDL_GAMEPAD_TYPE_COUNT: SDL_GamepadType