#[repr(C)]pub struct SDL_HapticRamp {
pub type_: SDL_HapticEffectType,
pub direction: SDL_HapticDirection,
pub length: Uint32,
pub delay: Uint16,
pub button: Uint16,
pub interval: Uint16,
pub start: Sint16,
pub end: Sint16,
pub attack_length: Uint16,
pub attack_level: Uint16,
pub fade_length: Uint16,
pub fade_level: Uint16,
}Expand description
A structure containing a template for a Ramp effect.
This struct is exclusively for the SDL_HAPTIC_RAMP effect.
The ramp effect starts at start strength and ends at end strength. It augments in linear fashion. If you use attack and fade with a ramp the effects get added to the ramp effect making the effect become quadratic instead of linear.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_HAPTIC_RAMP See Also: SDL_HapticEffect
Fields
type_: SDL_HapticEffectType< SDL_HAPTIC_RAMP
direction: SDL_HapticDirection< Direction of the effect.
length: Uint32< Duration of the effect.
delay: Uint16< Delay before starting the effect.
< Button that triggers the effect.
interval: Uint16< How soon it can be triggered again after button.
start: Sint16< Beginning strength level.
end: Sint16< Ending strength level.
attack_length: Uint16< Duration of the attack.
attack_level: Uint16< Level at the start of the attack.
fade_length: Uint16< Duration of the fade.
fade_level: Uint16< Level at the end of the fade.