#[repr(transparent)]pub struct SDL_JoystickType(pub c_uint);Expand description
An enum of some common joystick types.
In some cases, SDL can identify a low-level joystick as being a certain type of device, and will report it through SDL_GetJoystickType (or SDL_GetJoystickTypeForID).
This is by no means a complete list of everything that can be plugged into a computer.
You may refer to XInput Controller Types table for a general understanding of each joystick type.
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_JoystickType
impl SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_UNKNOWN: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_GAMEPAD: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_WHEEL: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_ARCADE_STICK: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_FLIGHT_STICK: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_DANCE_PAD: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_GUITAR: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_DRUM_KIT: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_ARCADE_PAD: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_THROTTLE: SDL_JoystickType
pub const SDL_JOYSTICK_TYPE_COUNT: SDL_JoystickType