SDL_LogCategory

Struct SDL_LogCategory 

#[repr(transparent)]
pub struct SDL_LogCategory(pub c_uint);
The predefined log categories

By default the application and gpu categories are enabled at the INFO level, the assert category is enabled at the WARN level, test is enabled at the VERBOSE level and all other categories are enabled at the ERROR level.

Available Since: This enum is available since SDL 3.2.0.

Tuple Fields

0: c_uint

Implementations