#[repr(C)]pub struct SDL_PenButtonEvent {
pub type_: SDL_EventType,
pub reserved: Uint32,
pub timestamp: Uint64,
pub windowID: SDL_WindowID,
pub which: SDL_PenID,
pub pen_state: SDL_PenInputFlags,
pub x: f32,
pub y: f32,
pub button: Uint8,
pub down: bool,
}Expand description
Pressure-sensitive pen button event structure (event.pbutton.*)
This is for buttons on the pen itself that the user might click. The pen itself pressing down to draw triggers a SDL_EVENT_PEN_DOWN event instead.
Available Since: This struct is available since SDL 3.2.0.
Fields
type_: SDL_EventType< SDL_EVENT_PEN_BUTTON_DOWN or SDL_EVENT_PEN_BUTTON_UP
reserved: Uint32timestamp: Uint64< In nanoseconds, populated using SDL_GetTicksNS()
windowID: SDL_WindowID< The window with mouse focus, if any
which: SDL_PenID< The pen instance id
pen_state: SDL_PenInputFlags< Complete pen input state at time of event
x: f32< X coordinate, relative to window
y: f32< Y coordinate, relative to window
< The pen button index (first button is 1).
down: bool< true if the button is pressed