#[repr(transparent)]pub struct SDL_PenDeviceType(pub c_int);Expand description
An enum that describes the type of a pen device.
A “direct” device is a pen that touches a graphic display (like an Apple Pencil on an iPad’s screen). “Indirect” devices touch an external tablet surface that is connected to the machine but is not a display (like a lower-end Wacom tablet connected over USB).
Apps may use this information to decide if they should draw a cursor; if the pen is touching the screen directly, a cursor doesn’t make sense and can be in the way, but becomes necessary for indirect devices to know where on the display they are interacting.
Available Since: This enum is available since SDL 3.4.0.
Tuple Fields
0: c_intImplementations
Sourceimpl SDL_PenDeviceType
impl SDL_PenDeviceType
Sourcepub const SDL_PEN_DEVICE_TYPE_INVALID: SDL_PenDeviceType
pub const SDL_PEN_DEVICE_TYPE_INVALID: SDL_PenDeviceType
< Not a valid pen device.
Sourcepub const SDL_PEN_DEVICE_TYPE_UNKNOWN: SDL_PenDeviceType
pub const SDL_PEN_DEVICE_TYPE_UNKNOWN: SDL_PenDeviceType
< Don’t know specifics of this pen.
Sourcepub const SDL_PEN_DEVICE_TYPE_DIRECT: SDL_PenDeviceType
pub const SDL_PEN_DEVICE_TYPE_DIRECT: SDL_PenDeviceType
< Pen touches display.
Sourcepub const SDL_PEN_DEVICE_TYPE_INDIRECT: SDL_PenDeviceType
pub const SDL_PEN_DEVICE_TYPE_INDIRECT: SDL_PenDeviceType
< Pen touches something that isn’t the display.