#[repr(C)]pub struct SDL_PenMotionEvent {
pub type_: SDL_EventType,
pub reserved: Uint32,
pub timestamp: Uint64,
pub windowID: SDL_WindowID,
pub which: SDL_PenID,
pub pen_state: SDL_PenInputFlags,
pub x: f32,
pub y: f32,
}Expand description
Pressure-sensitive pen motion event structure (event.pmotion.*)
Depending on the hardware, you may get motion events when the pen is not
touching a tablet, for tracking a pen even when it isn’t drawing. You
should listen for SDL_EVENT_PEN_DOWN and SDL_EVENT_PEN_UP events, or check
pen_state & SDL_PEN_INPUT_DOWN to decide if a pen is “drawing” when
dealing with pen motion.
Available Since: This struct is available since SDL 3.2.0.
Fields
type_: SDL_EventType< SDL_EVENT_PEN_MOTION
reserved: Uint32timestamp: Uint64< In nanoseconds, populated using SDL_GetTicksNS()
windowID: SDL_WindowID< The window with pen focus, if any
which: SDL_PenID< The pen instance id
pen_state: SDL_PenInputFlags< Complete pen input state at time of event
x: f32< X coordinate, relative to window
y: f32< Y coordinate, relative to window