#[repr(transparent)]pub struct SDL_ProgressState(pub c_int);Expand description
Window progress state
Available Since: This enum is available since SDL 3.2.8.
Tuple Fields
0: c_intImplementations
Sourceimpl SDL_ProgressState
impl SDL_ProgressState
Sourcepub const SDL_PROGRESS_STATE_INVALID: SDL_ProgressState
pub const SDL_PROGRESS_STATE_INVALID: SDL_ProgressState
< An invalid progress state indicating an error; check SDL_GetError()
Sourcepub const SDL_PROGRESS_STATE_NONE: SDL_ProgressState
pub const SDL_PROGRESS_STATE_NONE: SDL_ProgressState
< No progress bar is shown
Sourcepub const SDL_PROGRESS_STATE_INDETERMINATE: SDL_ProgressState
pub const SDL_PROGRESS_STATE_INDETERMINATE: SDL_ProgressState
< The progress bar is shown in a indeterminate state
Sourcepub const SDL_PROGRESS_STATE_NORMAL: SDL_ProgressState
pub const SDL_PROGRESS_STATE_NORMAL: SDL_ProgressState
< The progress bar is shown in a normal state
Sourcepub const SDL_PROGRESS_STATE_PAUSED: SDL_ProgressState
pub const SDL_PROGRESS_STATE_PAUSED: SDL_ProgressState
< The progress bar is shown in a paused state
Sourcepub const SDL_PROGRESS_STATE_ERROR: SDL_ProgressState
pub const SDL_PROGRESS_STATE_ERROR: SDL_ProgressState
< The progress bar is shown in a state indicating the application had an error