#[repr(transparent)]pub struct SDL_RendererLogicalPresentation(pub c_uint);Expand description
How the logical size is mapped to the output.
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_RendererLogicalPresentation
impl SDL_RendererLogicalPresentation
Sourcepub const SDL_LOGICAL_PRESENTATION_DISABLED: SDL_RendererLogicalPresentation
pub const SDL_LOGICAL_PRESENTATION_DISABLED: SDL_RendererLogicalPresentation
< There is no logical size in effect
Sourcepub const SDL_LOGICAL_PRESENTATION_STRETCH: SDL_RendererLogicalPresentation
pub const SDL_LOGICAL_PRESENTATION_STRETCH: SDL_RendererLogicalPresentation
< The rendered content is stretched to the output resolution
Sourcepub const SDL_LOGICAL_PRESENTATION_LETTERBOX: SDL_RendererLogicalPresentation
pub const SDL_LOGICAL_PRESENTATION_LETTERBOX: SDL_RendererLogicalPresentation
< The rendered content is fit to the largest dimension and the other dimension is letterboxed with the clear color
Sourcepub const SDL_LOGICAL_PRESENTATION_OVERSCAN: SDL_RendererLogicalPresentation
pub const SDL_LOGICAL_PRESENTATION_OVERSCAN: SDL_RendererLogicalPresentation
< The rendered content is fit to the smallest dimension and the other dimension extends beyond the output bounds
Sourcepub const SDL_LOGICAL_PRESENTATION_INTEGER_SCALE: SDL_RendererLogicalPresentation
pub const SDL_LOGICAL_PRESENTATION_INTEGER_SCALE: SDL_RendererLogicalPresentation
< The rendered content is scaled up by integer multiples to fit the output resolution