SDL_StorageInterface

Struct SDL_StorageInterface 

#[repr(C)]
pub struct SDL_StorageInterface { pub version: Uint32, pub close: Option<unsafe extern "C" fn(userdata: *mut c_void) -> bool>, pub ready: Option<unsafe extern "C" fn(userdata: *mut c_void) -> bool>, pub enumerate: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char, callback: SDL_EnumerateDirectoryCallback, callback_userdata: *mut c_void) -> bool>, pub info: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char, info: *mut SDL_PathInfo) -> bool>, pub read_file: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char, destination: *mut c_void, length: Uint64) -> bool>, pub write_file: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char, source: *const c_void, length: Uint64) -> bool>, pub mkdir: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char) -> bool>, pub remove: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char) -> bool>, pub rename: Option<unsafe extern "C" fn(userdata: *mut c_void, oldpath: *const c_char, newpath: *const c_char) -> bool>, pub copy: Option<unsafe extern "C" fn(userdata: *mut c_void, oldpath: *const c_char, newpath: *const c_char) -> bool>, pub space_remaining: Option<unsafe extern "C" fn(userdata: *mut c_void) -> Uint64>, }
Function interface for SDL_Storage.

Apps that want to supply a custom implementation of SDL_Storage will fill in all the functions in this struct, and then pass it to SDL_OpenStorage to create a custom SDL_Storage object.

It is not usually necessary to do this; SDL provides standard implementations for many things you might expect to do with an SDL_Storage.

This structure should be initialized using SDL_INIT_INTERFACE()

Available Since: This struct is available since SDL 3.2.0.

See Also: SDL_INIT_INTERFACE

Fields

version: Uint32close: Option<unsafe extern "C" fn(userdata: *mut c_void) -> bool>ready: Option<unsafe extern "C" fn(userdata: *mut c_void) -> bool>enumerate: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char, callback: SDL_EnumerateDirectoryCallback, callback_userdata: *mut c_void) -> bool>info: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char, info: *mut SDL_PathInfo) -> bool>read_file: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char, destination: *mut c_void, length: Uint64) -> bool>write_file: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char, source: *const c_void, length: Uint64) -> bool>mkdir: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char) -> bool>remove: Option<unsafe extern "C" fn(userdata: *mut c_void, path: *const c_char) -> bool>rename: Option<unsafe extern "C" fn(userdata: *mut c_void, oldpath: *const c_char, newpath: *const c_char) -> bool>copy: Option<unsafe extern "C" fn(userdata: *mut c_void, oldpath: *const c_char, newpath: *const c_char) -> bool>space_remaining: Option<unsafe extern "C" fn(userdata: *mut c_void) -> Uint64>