SDL_Surface

Struct SDL_Surface 

#[repr(C)]
pub struct SDL_Surface { pub flags: SDL_SurfaceFlags, pub format: SDL_PixelFormat, pub w: c_int, pub h: c_int, pub pitch: c_int, pub pixels: *mut c_void, pub refcount: c_int, pub reserved: *mut c_void, }
A collection of pixels used in software blitting.

Pixels are arranged in memory in rows, with the top row first. Each row occupies an amount of memory given by the pitch (sometimes known as the row stride in non-SDL APIs).

Within each row, pixels are arranged from left to right until the width is reached. Each pixel occupies a number of bits appropriate for its format, with most formats representing each pixel as one or more whole bytes (in some indexed formats, instead multiple pixels are packed into each byte), and a byte order given by the format. After encoding all pixels, any remaining bytes to reach the pitch are used as padding to reach a desired alignment, and have undefined contents.

When a surface holds YUV format data, the planes are assumed to be contiguous without padding between them, e.g. a 32x32 surface in NV12 format with a pitch of 32 would consist of 32x32 bytes of Y plane followed by 32x16 bytes of UV plane.

When a surface holds MJPG format data, pixels points at the compressed JPEG image and pitch is the length of that data.

Available Since: This struct is available since SDL 3.2.0.

See Also: SDL_CreateSurface See Also: SDL_DestroySurface

Fields

flags: SDL_SurfaceFlags

< The flags of the surface, read-only

format: SDL_PixelFormat

< The format of the surface, read-only

w: c_int

< The width of the surface, read-only.

h: c_int

< The height of the surface, read-only.

pitch: c_int

< The distance in bytes between rows of pixels, read-only

pixels: *mut c_void

< A pointer to the pixels of the surface, the pixels are writeable if non-NULL

refcount: c_int

< Application reference count, used when freeing surface

reserved: *mut c_void

< Reserved for internal use