#[repr(transparent)]pub struct SDL_SystemCursor(pub c_uint);Expand description
Cursor types for SDL_CreateSystemCursor().
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_SystemCursor
impl SDL_SystemCursor
Sourcepub const SDL_SYSTEM_CURSOR_DEFAULT: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_DEFAULT: SDL_SystemCursor
< Default cursor. Usually an arrow.
Sourcepub const SDL_SYSTEM_CURSOR_TEXT: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_TEXT: SDL_SystemCursor
< Text selection. Usually an I-beam.
Sourcepub const SDL_SYSTEM_CURSOR_WAIT: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_WAIT: SDL_SystemCursor
< Wait. Usually an hourglass or watch or spinning ball.
Sourcepub const SDL_SYSTEM_CURSOR_CROSSHAIR: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_CROSSHAIR: SDL_SystemCursor
< Crosshair.
Sourcepub const SDL_SYSTEM_CURSOR_PROGRESS: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_PROGRESS: SDL_SystemCursor
< Program is busy but still interactive. Usually it’s WAIT with an arrow.
Sourcepub const SDL_SYSTEM_CURSOR_NWSE_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_NWSE_RESIZE: SDL_SystemCursor
< Double arrow pointing northwest and southeast.
Sourcepub const SDL_SYSTEM_CURSOR_NESW_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_NESW_RESIZE: SDL_SystemCursor
< Double arrow pointing northeast and southwest.
Sourcepub const SDL_SYSTEM_CURSOR_EW_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_EW_RESIZE: SDL_SystemCursor
< Double arrow pointing west and east.
Sourcepub const SDL_SYSTEM_CURSOR_NS_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_NS_RESIZE: SDL_SystemCursor
< Double arrow pointing north and south.
Sourcepub const SDL_SYSTEM_CURSOR_MOVE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_MOVE: SDL_SystemCursor
< Four pointed arrow pointing north, south, east, and west.
Sourcepub const SDL_SYSTEM_CURSOR_NOT_ALLOWED: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_NOT_ALLOWED: SDL_SystemCursor
< Not permitted. Usually a slashed circle or crossbones.
Sourcepub const SDL_SYSTEM_CURSOR_POINTER: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_POINTER: SDL_SystemCursor
< Pointer that indicates a link. Usually a pointing hand.
Sourcepub const SDL_SYSTEM_CURSOR_NW_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_NW_RESIZE: SDL_SystemCursor
< Window resize top-left. This may be a single arrow or a double arrow like NWSE_RESIZE.
Sourcepub const SDL_SYSTEM_CURSOR_N_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_N_RESIZE: SDL_SystemCursor
< Window resize top. May be NS_RESIZE.
Sourcepub const SDL_SYSTEM_CURSOR_NE_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_NE_RESIZE: SDL_SystemCursor
< Window resize top-right. May be NESW_RESIZE.
Sourcepub const SDL_SYSTEM_CURSOR_E_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_E_RESIZE: SDL_SystemCursor
< Window resize right. May be EW_RESIZE.
Sourcepub const SDL_SYSTEM_CURSOR_SE_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_SE_RESIZE: SDL_SystemCursor
< Window resize bottom-right. May be NWSE_RESIZE.
Sourcepub const SDL_SYSTEM_CURSOR_S_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_S_RESIZE: SDL_SystemCursor
< Window resize bottom. May be NS_RESIZE.
Sourcepub const SDL_SYSTEM_CURSOR_SW_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_SW_RESIZE: SDL_SystemCursor
< Window resize bottom-left. May be NESW_RESIZE.
Sourcepub const SDL_SYSTEM_CURSOR_W_RESIZE: SDL_SystemCursor
pub const SDL_SYSTEM_CURSOR_W_RESIZE: SDL_SystemCursor
< Window resize left. May be EW_RESIZE.
pub const SDL_SYSTEM_CURSOR_COUNT: SDL_SystemCursor