SDL_TextInputType

Struct SDL_TextInputType 

#[repr(transparent)]
pub struct SDL_TextInputType(pub c_uint);
Text input type.

These are the valid values for SDL_PROP_TEXTINPUT_TYPE_NUMBER. Not every value is valid on every platform, but where a value isn’t supported, a reasonable fallback will be used.

Available Since: This enum is available since SDL 3.2.0.

See Also: SDL_StartTextInputWithProperties

Tuple Fields

0: c_uint

Implementations

Source

impl SDL_TextInputType

pub const SDL_TEXTINPUT_TYPE_TEXT: SDL_TextInputType

< The input is text

pub const SDL_TEXTINPUT_TYPE_TEXT_NAME: SDL_TextInputType

< The input is a person’s name

pub const SDL_TEXTINPUT_TYPE_TEXT_EMAIL: SDL_TextInputType

< The input is an e-mail address

pub const SDL_TEXTINPUT_TYPE_TEXT_USERNAME: SDL_TextInputType

< The input is a username

pub const SDL_TEXTINPUT_TYPE_TEXT_PASSWORD_HIDDEN: SDL_TextInputType

< The input is a secure password that is hidden

pub const SDL_TEXTINPUT_TYPE_TEXT_PASSWORD_VISIBLE: SDL_TextInputType

< The input is a secure password that is visible

pub const SDL_TEXTINPUT_TYPE_NUMBER: SDL_TextInputType

< The input is a number

pub const SDL_TEXTINPUT_TYPE_NUMBER_PASSWORD_HIDDEN: SDL_TextInputType

< The input is a secure PIN that is hidden

pub const SDL_TEXTINPUT_TYPE_NUMBER_PASSWORD_VISIBLE: SDL_TextInputType

< The input is a secure PIN that is visible