#[repr(transparent)]pub struct SDL_TextureAddressMode(pub c_int);Expand description
The addressing mode for a texture when used in SDL_RenderGeometry().
This affects how texture coordinates are interpreted outside of [0, 1]
Texture wrapping is always supported for power of two texture sizes, and is supported for other texture sizes if SDL_PROP_RENDERER_TEXTURE_WRAPPING_BOOLEAN is set to true.
Available Since: This enum is available since SDL 3.4.0.
Tuple Fields
0: c_intImplementations
Sourceimpl SDL_TextureAddressMode
impl SDL_TextureAddressMode
pub const SDL_TEXTURE_ADDRESS_INVALID: SDL_TextureAddressMode
Sourcepub const SDL_TEXTURE_ADDRESS_AUTO: SDL_TextureAddressMode
pub const SDL_TEXTURE_ADDRESS_AUTO: SDL_TextureAddressMode
< Wrapping is enabled if texture coordinates are outside [0, 1], this is the default
Sourcepub const SDL_TEXTURE_ADDRESS_CLAMP: SDL_TextureAddressMode
pub const SDL_TEXTURE_ADDRESS_CLAMP: SDL_TextureAddressMode
< Texture coordinates are clamped to the [0, 1] range
Sourcepub const SDL_TEXTURE_ADDRESS_WRAP: SDL_TextureAddressMode
pub const SDL_TEXTURE_ADDRESS_WRAP: SDL_TextureAddressMode
< The texture is repeated (tiled)