#[repr(transparent)]pub struct SDL_ThreadState(pub c_uint);Expand description
The SDL thread state.
The current state of a thread can be checked by calling SDL_GetThreadState.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_GetThreadState
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_ThreadState
impl SDL_ThreadState
Sourcepub const SDL_THREAD_UNKNOWN: SDL_ThreadState
pub const SDL_THREAD_UNKNOWN: SDL_ThreadState
< The thread is not valid
Sourcepub const SDL_THREAD_ALIVE: SDL_ThreadState
pub const SDL_THREAD_ALIVE: SDL_ThreadState
< The thread is currently running
Sourcepub const SDL_THREAD_DETACHED: SDL_ThreadState
pub const SDL_THREAD_DETACHED: SDL_ThreadState
< The thread is detached and can’t be waited on
Sourcepub const SDL_THREAD_COMPLETE: SDL_ThreadState
pub const SDL_THREAD_COMPLETE: SDL_ThreadState
< The thread has finished and should be cleaned up with SDL_WaitThread()