#[repr(C)]pub struct SDL_UserEvent {
pub type_: Uint32,
pub reserved: Uint32,
pub timestamp: Uint64,
pub windowID: SDL_WindowID,
pub code: Sint32,
pub data1: *mut c_void,
pub data2: *mut c_void,
}Expand description
A user-defined event type (event.user.*)
This event is unique; it is never created by SDL, but only by the application. The event can be pushed onto the event queue using SDL_PushEvent(). The contents of the structure members are completely up to the programmer; the only requirement is that ‘’‘type’‘’ is a value obtained from SDL_RegisterEvents().
Available Since: This struct is available since SDL 3.2.0.
Fields
type_: Uint32< SDL_EVENT_USER through SDL_EVENT_LAST, Uint32 because these are not in the SDL_EventType enumeration
reserved: Uint32timestamp: Uint64< In nanoseconds, populated using SDL_GetTicksNS()
windowID: SDL_WindowID< The associated window if any
code: Sint32< User defined event code
data1: *mut c_void< User defined data pointer
data2: *mut c_void< User defined data pointer