SDL_AppInit_func

Type Alias SDL_AppInit_func 

pub type SDL_AppInit_func = Option<unsafe extern "C" fn(appstate: *mut *mut c_void, argc: c_int, argv: *mut *mut c_char) -> SDL_AppResult>;
Function pointer typedef for SDL_AppInit.

These are used by SDL_EnterAppMainCallbacks. This mechanism operates behind the scenes for apps using the optional main callbacks. Apps that want to use this should just implement SDL_AppInit directly.

Parameter: appstate a place where the app can optionally store a pointer for future use. Parameter: argc the standard ANSI C main’s argc; number of elements in argv. Parameter: argv the standard ANSI C main’s argv; array of command line arguments. Returns: SDL_APP_FAILURE to terminate with an error, SDL_APP_SUCCESS to terminate with success, SDL_APP_CONTINUE to continue.

Available Since: This datatype is available since SDL 3.2.0.

Aliased Type

pub enum SDL_AppInit_func {
    None,
    Some(unsafe extern "C" fn(*mut *mut c_void, i32, *mut *mut i8) -> SDL_AppResult),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut *mut c_void, i32, *mut *mut i8) -> SDL_AppResult)

Some value of type T.