SDL_EGLAttribArrayCallback

Type Alias SDL_EGLAttribArrayCallback 

pub type SDL_EGLAttribArrayCallback = Option<unsafe extern "C" fn(userdata: *mut c_void) -> *mut SDL_EGLAttrib>;
EGL platform attribute initialization callback.

This is called when SDL is attempting to create an EGL context, to let the app add extra attributes to its eglGetPlatformDisplay() call.

The callback should return a pointer to an EGL attribute array terminated with EGL_NONE. If this function returns NULL, the SDL_CreateWindow process will fail gracefully.

The returned pointer should be allocated with SDL_malloc() and will be passed to SDL_free().

The arrays returned by each callback will be appended to the existing attribute arrays defined by SDL.

Parameter: userdata an app-controlled pointer that is passed to the callback. Returns: a newly-allocated array of attributes, terminated with EGL_NONE.

Available Since: This datatype is available since SDL 3.2.0.

See Also: SDL_EGL_SetAttributeCallbacks

Aliased Type

pub enum SDL_EGLAttribArrayCallback {
    None,
    Some(unsafe extern "C" fn(*mut c_void) -> *mut isize),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void) -> *mut isize)

Some value of type T.