SDL_HapticID

Type Alias SDL_HapticID 

pub type SDL_HapticID = Uint32;
This is a unique ID for a haptic device for the time it is connected to the system, and is never reused for the lifetime of the application.

If the haptic device is disconnected and reconnected, it will get a new ID.

The value 0 is an invalid ID.

Available Since: This datatype is available since SDL 3.2.0.