SDL_InitFlags

Type Alias SDL_InitFlags 

pub type SDL_InitFlags = Uint32;
Initialization flags for SDL_Init and/or SDL_InitSubSystem

These are the flags which may be passed to SDL_Init(). You should specify the subsystems which you will be using in your application.

Available Since: This datatype is available since SDL 3.2.0.

See Also: SDL_Init See Also: SDL_Quit See Also: SDL_InitSubSystem See Also: SDL_QuitSubSystem See Also: SDL_WasInit