SDL_LogOutputFunction

Type Alias SDL_LogOutputFunction 

pub type SDL_LogOutputFunction = Option<unsafe extern "C" fn(userdata: *mut c_void, category: c_int, priority: SDL_LogPriority, message: *const c_char)>;
The prototype for the log output callback function.

This function is called by SDL when there is new text to be logged. A mutex is held so that this function is never called by more than one thread at once.

Parameter: userdata what was passed as userdata to SDL_SetLogOutputFunction(). Parameter: category the category of the message. Parameter: priority the priority of the message. Parameter: message the message being output.

Available Since: This datatype is available since SDL 3.2.0.

Aliased Type

pub enum SDL_LogOutputFunction {
    None,
    Some(unsafe extern "C" fn(*mut c_void, i32, SDL_LogPriority, *const i8)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, i32, SDL_LogPriority, *const i8))

Some value of type T.