pub type SDL_NSTimerCallback = Option<unsafe extern "C" fn(userdata: *mut c_void, timerID: SDL_TimerID, interval: Uint64) -> Uint64>;Expand description
Function prototype for the nanosecond timer callback function.
The callback function is passed the current timer interval and returns the next timer interval, in nanoseconds. If the returned value is the same as the one passed in, the periodic alarm continues, otherwise a new alarm is scheduled. If the callback returns 0, the periodic alarm is canceled and will be removed.
Parameter: userdata an arbitrary pointer provided by the app through SDL_AddTimer, for its own use. Parameter: timerID the current timer being processed. Parameter: interval the current callback time interval. Returns: the new callback time interval, or 0 to disable further runs of the callback.
Thread Safety: SDL may call this callback at any time from a background thread; the application is responsible for locking resources the callback touches that need to be protected.
Available Since: This datatype is available since SDL 3.2.0.
See Also: SDL_AddTimerNS
Aliased Type
pub enum SDL_NSTimerCallback {
None,
Some(unsafe extern "C" fn(*mut c_void, u32, u64) -> u64),
}