SDL_SensorID

Type Alias SDL_SensorID 

pub type SDL_SensorID = Uint32;
This is a unique ID for a sensor for the time it is connected to the system, and is never reused for the lifetime of the application.

The value 0 is an invalid ID.

Available Since: This datatype is available since SDL 3.2.0.