pub type SDL_TLSDestructorCallback = Option<unsafe extern "C" fn(value: *mut c_void)>;Expand description
The callback used to cleanup data passed to SDL_SetTLS.
This is called when a thread exits, to allow an app to free any resources.
Parameter: value a pointer previously handed to SDL_SetTLS.
Available Since: This datatype is available since SDL 3.2.0.
See Also: SDL_SetTLS
Aliased Type
pub enum SDL_TLSDestructorCallback {
None,
Some(unsafe extern "C" fn(*mut c_void)),
}