SDL_TouchID

Type Alias SDL_TouchID 

pub type SDL_TouchID = Uint64;
A unique ID for a touch device.

This ID is valid for the time the device is connected to the system, and is never reused for the lifetime of the application.

The value 0 is an invalid ID.

Available Since: This datatype is available since SDL 3.2.0.