SDL_TrayEntryFlags

Type Alias SDL_TrayEntryFlags 

pub type SDL_TrayEntryFlags = Uint32;
Flags that control the creation of system tray entries.

Some of these flags are required; exactly one of them must be specified at the time a tray entry is created. Other flags are optional; zero or more of those can be OR’ed together with the required flag.

Available Since: This datatype is available since SDL 3.2.0.

See Also: SDL_InsertTrayEntryAt