SDL_free_func

Type Alias SDL_free_func 

pub type SDL_free_func = Option<unsafe extern "C" fn(mem: *mut c_void)>;
A callback used to implement SDL_free().

SDL will always ensure that the passed mem is a non-NULL pointer.

Parameter: mem a pointer to allocated memory.

Thread Safety: It should be safe to call this callback from any thread.

Available Since: This datatype is available since SDL 3.2.0.

See Also: SDL_free See Also: SDL_GetOriginalMemoryFunctions See Also: SDL_GetMemoryFunctions See Also: SDL_SetMemoryFunctions

Aliased Type

pub enum SDL_free_func {
    None,
    Some(unsafe extern "C" fn(*mut c_void)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void))

Some value of type T.