pub unsafe extern "C" fn SDL_BindAudioStream(
devid: SDL_AudioDeviceID,
stream: *mut SDL_AudioStream,
) -> boolExpand description
Bind a single audio stream to an audio device.
This is a convenience function, equivalent to calling
SDL_BindAudioStreams(devid, &stream, 1).
Parameter: devid an audio device to bind a stream to. Parameter: stream an audio stream to bind to a device. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_BindAudioStreams See Also: SDL_UnbindAudioStream See Also: SDL_GetAudioStreamDevice