pub unsafe extern "C" fn SDL_BindGPUFragmentStorageTextures(
render_pass: *mut SDL_GPURenderPass,
first_slot: Uint32,
storage_textures: *const *mut SDL_GPUTexture,
num_bindings: Uint32,
)Expand description
Binds storage textures for use on the fragment shader.
These textures must have been created with SDL_GPU_TEXTUREUSAGE_GRAPHICS_STORAGE_READ.
Be sure your shader is set up according to the requirements documented in SDL_CreateGPUShader().
Parameter: render_pass a render pass handle. Parameter: first_slot the fragment storage texture slot to begin binding from. Parameter: storage_textures an array of storage textures. Parameter: num_bindings the number of storage textures to bind from the array.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_CreateGPUShader