pub unsafe extern "C" fn SDL_ClaimWindowForGPUDevice(
device: *mut SDL_GPUDevice,
window: *mut SDL_Window,
) -> boolExpand description
Claims a window, creating a swapchain structure for it.
This must be called before SDL_AcquireGPUSwapchainTexture is called using the window. You should only call this function from the thread that created the window.
The swapchain will be created with SDL_GPU_SWAPCHAINCOMPOSITION_SDR and SDL_GPU_PRESENTMODE_VSYNC. If you want to have different swapchain parameters, you must call SDL_SetGPUSwapchainParameters after claiming the window.
Parameter: device a GPU context. Parameter: window an SDL_Window. Returns: true on success, or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called from the thread that created the window.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_WaitAndAcquireGPUSwapchainTexture See Also: SDL_ReleaseWindowFromGPUDevice See Also: SDL_WindowSupportsGPUPresentMode See Also: SDL_WindowSupportsGPUSwapchainComposition