pub unsafe extern "C" fn SDL_ConvertPixels(
width: c_int,
height: c_int,
src_format: SDL_PixelFormat,
src: *const c_void,
src_pitch: c_int,
dst_format: SDL_PixelFormat,
dst: *mut c_void,
dst_pitch: c_int,
) -> boolExpand description
Copy a block of pixels of one format to another format.
Parameter: width the width of the block to copy, in pixels.
Parameter: height the height of the block to copy, in pixels.
Parameter: src_format an SDL_PixelFormat value of the src pixels format.
Parameter: src a pointer to the source pixels.
Parameter: src_pitch the pitch of the source pixels, in bytes.
Parameter: dst_format an SDL_PixelFormat value of the dst pixels format.
Parameter: dst a pointer to be filled in with new pixel data.
Parameter: dst_pitch the pitch of the destination pixels, in bytes.
Returns: true on success or false on failure; call SDL_GetError() for more
information.
Thread Safety: The same destination pixels should not be used from two threads at once. It is safe to use the same source pixels from multiple threads.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_ConvertPixelsAndColorspace