pub unsafe extern "C" fn SDL_CreateAsyncIOQueue() -> *mut SDL_AsyncIOQueueExpand description
Create a task queue for tracking multiple I/O operations.
Async I/O operations are assigned to a queue when started. The queue can be checked for completed tasks thereafter.
Returns: a new task queue object or NULL if there was an error; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_DestroyAsyncIOQueue See Also: SDL_GetAsyncIOResult See Also: SDL_WaitAsyncIOResult