pub unsafe extern "C" fn SDL_CreateGPUSampler(
device: *mut SDL_GPUDevice,
createinfo: *const SDL_GPUSamplerCreateInfo,
) -> *mut SDL_GPUSamplerExpand description
Creates a sampler object to be used when binding textures in a graphics workflow.
There are optional properties that can be provided through props. These
are the supported properties:
SDL_PROP_GPU_SAMPLER_CREATE_NAME_STRING: a name that can be displayed in debugging tools.
Parameter: device a GPU Context. Parameter: createinfo a struct describing the state of the sampler to create. Returns: a sampler object on success, or NULL on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_BindGPUVertexSamplers See Also: SDL_BindGPUFragmentSamplers See Also: SDL_ReleaseGPUSampler