pub unsafe extern "C" fn SDL_CreateGPUTransferBuffer(
device: *mut SDL_GPUDevice,
createinfo: *const SDL_GPUTransferBufferCreateInfo,
) -> *mut SDL_GPUTransferBufferExpand description
Creates a transfer buffer to be used when uploading to or downloading from graphics resources.
Download buffers can be particularly expensive to create, so it is good practice to reuse them if data will be downloaded regularly.
There are optional properties that can be provided through props. These
are the supported properties:
SDL_PROP_GPU_TRANSFERBUFFER_CREATE_NAME_STRING: a name that can be displayed in debugging tools.
Parameter: device a GPU Context. Parameter: createinfo a struct describing the state of the transfer buffer to create. Returns: a transfer buffer on success, or NULL on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_UploadToGPUBuffer See Also: SDL_DownloadFromGPUBuffer See Also: SDL_UploadToGPUTexture See Also: SDL_DownloadFromGPUTexture See Also: SDL_ReleaseGPUTransferBuffer