pub unsafe extern "C" fn SDL_DestroyTexture(texture: *mut SDL_Texture)Expand description
Destroy the specified texture.
Passing NULL or an otherwise invalid texture will set the SDL error message to “Invalid texture”.
Parameter: texture the texture to destroy.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_CreateTexture See Also: SDL_CreateTextureFromSurface