pub unsafe extern "C" fn SDL_DrawGPUIndexedPrimitives(
render_pass: *mut SDL_GPURenderPass,
num_indices: Uint32,
num_instances: Uint32,
first_index: Uint32,
vertex_offset: Sint32,
first_instance: Uint32,
)Expand description
Draws data using bound graphics state with an index buffer and instancing enabled.
You must not call this function before binding a graphics pipeline.
Note that the first_vertex and first_instance parameters are NOT
compatible with built-in vertex/instance ID variables in shaders (for
example, SV_VertexID); GPU APIs and shader languages do not define these
built-in variables consistently, so if your shader depends on them, the
only way to keep behavior consistent and portable is to always pass 0 for
the correlating parameter in the draw calls.
Parameter: render_pass a render pass handle. Parameter: num_indices the number of indices to draw per instance. Parameter: num_instances the number of instances to draw. Parameter: first_index the starting index within the index buffer. Parameter: vertex_offset value added to vertex index before indexing into the vertex buffer. Parameter: first_instance the ID of the first instance to draw.
Available Since: This function is available since SDL 3.2.0.