pub unsafe extern "C" fn SDL_DrawGPUPrimitivesIndirect(
render_pass: *mut SDL_GPURenderPass,
buffer: *mut SDL_GPUBuffer,
offset: Uint32,
draw_count: Uint32,
)Expand description
Draws data using bound graphics state and with draw parameters set from a buffer.
The buffer must consist of tightly-packed draw parameter sets that each match the layout of SDL_GPUIndirectDrawCommand. You must not call this function before binding a graphics pipeline.
Parameter: render_pass a render pass handle. Parameter: buffer a buffer containing draw parameters. Parameter: offset the offset to start reading from the draw buffer. Parameter: draw_count the number of draw parameter sets that should be read from the draw buffer.
Available Since: This function is available since SDL 3.2.0.