pub unsafe extern "C" fn SDL_FlashWindow(
window: *mut SDL_Window,
operation: SDL_FlashOperation,
) -> boolExpand description
Request a window to demand attention from the user.
Parameter: window the window to be flashed. Parameter: operation the operation to perform. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.