pub unsafe extern "C" fn SDL_GetAsyncIOSize(
asyncio: *mut SDL_AsyncIO,
) -> Sint64Expand description
Use this function to get the size of the data stream in an SDL_AsyncIO.
This call is not asynchronous; it assumes that obtaining this info is a non-blocking operation in most reasonable cases.
Parameter: asyncio the SDL_AsyncIO to get the size of the data stream from. Returns: the size of the data stream in the SDL_IOStream on success or a negative error code on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.