pub unsafe extern "C" fn SDL_GetAudioFormatName(
format: SDL_AudioFormat,
) -> *const c_charExpand description
Get the human readable name of an audio format.
Parameter: format the audio format to query. Returns: the human readable name of the specified audio format or “SDL_AUDIO_UNKNOWN” if the format isn’t recognized.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.