pub unsafe extern "C" fn SDL_GetBooleanProperty(
props: SDL_PropertiesID,
name: *const c_char,
default_value: bool,
) -> boolExpand description
Get a boolean property from a group of properties.
You can use SDL_GetPropertyType() to query whether the property exists and is a boolean property.
Parameter: props the properties to query.
Parameter: name the name of the property to query.
Parameter: default_value the default value of the property.
Returns: the value of the property, or default_value if it is not set or
not a boolean property.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetPropertyType See Also: SDL_HasProperty See Also: SDL_SetBooleanProperty