pub unsafe extern "C" fn SDL_GetCurrentAudioDriver() -> *const c_charExpand description
Get the name of the current audio driver.
The names of drivers are all simple, low-ASCII identifiers, like “alsa”, “coreaudio” or “wasapi”. These never have Unicode characters, and are not meant to be proper names.
Returns: the name of the current audio driver or NULL if no driver has been initialized.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.