pub unsafe extern "C" fn SDL_GetCurrentVideoDriver() -> *const c_charExpand description
Get the name of the currently initialized video driver.
The names of drivers are all simple, low-ASCII identifiers, like “cocoa”, “x11” or “windows”. These never have Unicode characters, and are not meant to be proper names.
Returns: the name of the current video driver or NULL if no driver has been initialized.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetNumVideoDrivers See Also: SDL_GetVideoDriver