pub unsafe extern "C" fn SDL_GetDesktopDisplayMode(
displayID: SDL_DisplayID,
) -> *const SDL_DisplayModeExpand description
Get information about the desktop’s display mode.
There’s a difference between this function and SDL_GetCurrentDisplayMode() when SDL runs fullscreen and has changed the resolution. In that case this function will return the previous native display mode, and not the current display mode.
Parameter: displayID the instance ID of the display to query. Returns: a pointer to the desktop display mode or NULL on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetCurrentDisplayMode See Also: SDL_GetDisplays