pub unsafe extern "C" fn SDL_GetDisplayForPoint(
point: *const SDL_Point,
) -> SDL_DisplayIDExpand description
Get the display containing a point.
Parameter: point the point to query. Returns: the instance ID of the display containing the point or 0 on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetDisplayBounds See Also: SDL_GetDisplays