pub unsafe extern "C" fn SDL_GetEnvironmentVariable(
env: *mut SDL_Environment,
name: *const c_char,
) -> *const c_charExpand description
Get the value of a variable in the environment.
Parameter: env the environment to query.
Parameter: name the name of the variable to get.
Returns: a pointer to the value of the variable or NULL if it can’t be found.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetEnvironment
See Also: SDL_CreateEnvironment
See Also: SDL_GetEnvironmentVariables
See Also: SDL_SetEnvironmentVariable
See Also: SDL_UnsetEnvironmentVariable