pub unsafe extern "C" fn SDL_GetEnvironmentVariables(
env: *mut SDL_Environment,
) -> *mut *mut c_charExpand description
Get all variables in the environment.
Parameter: env the environment to query. Returns: a NULL terminated array of pointers to environment variables in the form “variable=value” or NULL on failure; call SDL_GetError() for more information. This is a single allocation that should be freed with SDL_free() when it is no longer needed.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetEnvironment See Also: SDL_CreateEnvironment See Also: SDL_GetEnvironmentVariable See Also: SDL_SetEnvironmentVariable See Also: SDL_UnsetEnvironmentVariable