pub unsafe extern "C" fn SDL_GetEventFilter(
filter: *mut SDL_EventFilter,
userdata: *mut *mut c_void,
) -> boolExpand description
Query the current event filter.
This function can be used to “chain” filters, by saving the existing filter before replacing it with a function that will call that saved filter.
Parameter: filter the current callback function will be stored here. Parameter: userdata the pointer that is passed to the current event filter will be stored here. Returns: true on success or false if there is no event filter set.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetEventFilter