pub unsafe extern "C" fn SDL_GetGamepadButtonFromString(
str_: *const c_char,
) -> SDL_GamepadButtonExpand description
Convert a string into an SDL_GamepadButton enum.
This function is called internally to translate SDL_Gamepad mapping strings for the underlying joystick device into the consistent SDL_Gamepad mapping. You do not normally need to call this function unless you are parsing SDL_Gamepad mappings in your own code.
Parameter: str string representing a SDL_Gamepad button.
Returns: the SDL_GamepadButton enum corresponding to the input string, or
SDL_GAMEPAD_BUTTON_INVALID if no match was found.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetGamepadStringForButton