pub unsafe extern "C" fn SDL_GetGamepadGUIDForID(
instance_id: SDL_JoystickID,
) -> SDL_GUIDExpand description
Get the implementation-dependent GUID of a gamepad.
This can be called before any gamepads are opened.
Parameter: instance_id the joystick instance ID. Returns: the GUID of the selected gamepad. If called on an invalid index, this function returns a zero GUID.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GUIDToString See Also: SDL_GetGamepads