pub unsafe extern "C" fn SDL_GetGamepadMappingForGUID(
guid: SDL_GUID,
) -> *mut c_charExpand description
Get the gamepad mapping string for a given GUID.
Parameter: guid a structure containing the GUID for which a mapping is desired. Returns: a mapping string or NULL on failure; call SDL_GetError() for more information. This should be freed with SDL_free() when it is no longer needed.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetJoystickGUIDForID See Also: SDL_GetJoystickGUID