pub unsafe extern "C" fn SDL_GetGamepadPathForID(
instance_id: SDL_JoystickID,
) -> *const c_charExpand description
Get the implementation dependent path of a gamepad.
This can be called before any gamepads are opened.
Parameter: instance_id the joystick instance ID. Returns: the path of the selected gamepad. If no path can be found, this function returns NULL; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetGamepadPath See Also: SDL_GetGamepads