pub unsafe extern "C" fn SDL_GetGamepadStringForButton(
button: SDL_GamepadButton,
) -> *const c_charExpand description
Convert from an SDL_GamepadButton enum to a string.
Parameter: button an enum value for a given SDL_GamepadButton. Returns: a string for the given button, or NULL if an invalid button is specified. The string returned is of the format used by SDL_Gamepad mapping strings.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetGamepadButtonFromString