pub unsafe extern "C" fn SDL_GetHapticEffectStatus(
haptic: *mut SDL_Haptic,
effect: SDL_HapticEffectID,
) -> boolExpand description
Get the status of the current effect on the specified haptic device.
Device must support the SDL_HAPTIC_STATUS feature.
Parameter: haptic the SDL_Haptic device to query for the effect status on. Parameter: effect the ID of the haptic effect to query its status. Returns: true if it is playing, false if it isn’t playing or haptic status isn’t supported.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetHapticFeatures