pub unsafe extern "C" fn SDL_GetJoystickGUIDForID(
instance_id: SDL_JoystickID,
) -> SDL_GUIDExpand description
Get the implementation-dependent GUID of a joystick.
This can be called before any joysticks are opened.
Parameter: instance_id the joystick instance ID. Returns: the GUID of the selected joystick. If called with an invalid instance_id, this function returns a zero GUID.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetJoystickGUID See Also: SDL_GUIDToString