pub unsafe extern "C" fn SDL_GetNumRenderDrivers() -> c_intExpand description
Get the number of 2D rendering drivers available for the current display.
A render driver is a set of code that handles rendering and texture management on a particular display. Normally there is only one, but some drivers may have several available with different capabilities.
There may be none if SDL was compiled without render support.
Returns: the number of built in render drivers.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_CreateRenderer See Also: SDL_GetRenderDriver