pub unsafe extern "C" fn SDL_GetNumVideoDrivers() -> c_intExpand description
Get the number of video drivers compiled into SDL.
Returns: the number of built in video drivers.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetVideoDriver