pub unsafe extern "C" fn SDL_GetPerformanceFrequency() -> Uint64Expand description
Get the count per second of the high resolution counter.
Returns: a platform-specific count per second.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetPerformanceCounter