pub unsafe extern "C" fn SDL_GetPrimarySelectionText() -> *mut c_charExpand description
Get UTF-8 text from the primary selection.
This function returns an empty string if there is not enough memory left for a copy of the primary selection’s content.
Returns: the primary selection text on success or an empty string on failure; call SDL_GetError() for more information. This should be freed with SDL_free() when it is no longer needed.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_HasPrimarySelectionText See Also: SDL_SetPrimarySelectionText