pub unsafe extern "C" fn SDL_GetRectAndLineIntersectionFloat(
rect: *const SDL_FRect,
X1: *mut f32,
Y1: *mut f32,
X2: *mut f32,
Y2: *mut f32,
) -> boolExpand description
Calculate the intersection of a rectangle and line segment with float precision.
This function is used to clip a line segment to a rectangle. A line segment
contained entirely within the rectangle or that does not intersect will
remain unchanged. A line segment that crosses the rectangle at either or
both ends will be clipped to the boundary of the rectangle and the new
coordinates saved in X1, Y1, X2, and/or Y2 as necessary.
Parameter: rect an SDL_FRect structure representing the rectangle to intersect. Parameter: X1 a pointer to the starting X-coordinate of the line. Parameter: Y1 a pointer to the starting Y-coordinate of the line. Parameter: X2 a pointer to the ending X-coordinate of the line. Parameter: Y2 a pointer to the ending Y-coordinate of the line. Returns: true if there is an intersection, false otherwise.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.