pub unsafe extern "C" fn SDL_GetRectUnionFloat(
A: *const SDL_FRect,
B: *const SDL_FRect,
result: *mut SDL_FRect,
) -> boolExpand description
Calculate the union of two rectangles with float precision.
Parameter: A an SDL_FRect structure representing the first rectangle.
Parameter: B an SDL_FRect structure representing the second rectangle.
Parameter: result an SDL_FRect structure filled in with the union of rectangles
A and B.
Returns: true on success or false on failure; call SDL_GetError() for more
information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.