pub unsafe extern "C" fn SDL_GetRenderDrawColor(
renderer: *mut SDL_Renderer,
r: *mut Uint8,
g: *mut Uint8,
b: *mut Uint8,
a: *mut Uint8,
) -> boolExpand description
Get the color used for drawing operations (Rect, Line and Clear).
Parameter: renderer the rendering context.
Parameter: r a pointer filled in with the red value used to draw on the
rendering target.
Parameter: g a pointer filled in with the green value used to draw on the
rendering target.
Parameter: b a pointer filled in with the blue value used to draw on the
rendering target.
Parameter: a a pointer filled in with the alpha value used to draw on the
rendering target; usually SDL_ALPHA_OPAQUE (255).
Returns: true on success or false on failure; call SDL_GetError() for more
information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetRenderDrawColorFloat See Also: SDL_SetRenderDrawColor