pub unsafe extern "C" fn SDL_GetRenderDrawColorFloat(
renderer: *mut SDL_Renderer,
r: *mut f32,
g: *mut f32,
b: *mut f32,
a: *mut f32,
) -> boolExpand description
Get the color used for drawing operations (Rect, Line and Clear).
Parameter: renderer the rendering context. Parameter: r a pointer filled in with the red value used to draw on the rendering target. Parameter: g a pointer filled in with the green value used to draw on the rendering target. Parameter: b a pointer filled in with the blue value used to draw on the rendering target. Parameter: a a pointer filled in with the alpha value used to draw on the rendering target. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetRenderDrawColorFloat See Also: SDL_GetRenderDrawColor