pub unsafe extern "C" fn SDL_GetRenderTextureAddressMode(
renderer: *mut SDL_Renderer,
u_mode: *mut SDL_TextureAddressMode,
v_mode: *mut SDL_TextureAddressMode,
) -> boolExpand description
Get the texture addressing mode used in SDL_RenderGeometry().
Parameter: renderer the rendering context. Parameter: u_mode a pointer filled in with the SDL_TextureAddressMode to use for horizontal texture coordinates in SDL_RenderGeometry(), may be NULL. Parameter: v_mode a pointer filled in with the SDL_TextureAddressMode to use for vertical texture coordinates in SDL_RenderGeometry(), may be NULL. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.4.0.
See Also: SDL_SetRenderTextureAddressMode