pub unsafe extern "C" fn SDL_GetRenderVSync(
renderer: *mut SDL_Renderer,
vsync: *mut c_int,
) -> boolExpand description
Get VSync of the given renderer.
Parameter: renderer the renderer to toggle. Parameter: vsync an int filled with the current vertical refresh sync interval. See SDL_SetRenderVSync() for the meaning of the value. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetRenderVSync