pub unsafe extern "C" fn SDL_GetSurfaceAlphaMod(
surface: *mut SDL_Surface,
alpha: *mut Uint8,
) -> boolExpand description
Get the additional alpha value used in blit operations.
Parameter: surface the SDL_Surface structure to query. Parameter: alpha a pointer filled in with the current alpha value. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetSurfaceColorMod See Also: SDL_SetSurfaceAlphaMod