pub unsafe extern "C" fn SDL_GetSurfaceColorKey(
surface: *mut SDL_Surface,
key: *mut Uint32,
) -> boolExpand description
Get the color key (transparent pixel) for a surface.
The color key is a pixel of the format used by the surface, as generated by SDL_MapRGB().
If the surface doesn’t have color key enabled this function returns false.
Parameter: surface the SDL_Surface structure to query. Parameter: key a pointer filled in with the transparent pixel. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetSurfaceColorKey See Also: SDL_SurfaceHasColorKey