pub unsafe extern "C" fn SDL_GetSurfaceColorMod(
surface: *mut SDL_Surface,
r: *mut Uint8,
g: *mut Uint8,
b: *mut Uint8,
) -> boolExpand description
Get the additional color value multiplied into blit operations.
Parameter: surface the SDL_Surface structure to query.
Parameter: r a pointer filled in with the current red color value.
Parameter: g a pointer filled in with the current green color value.
Parameter: b a pointer filled in with the current blue color value.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function can be called on different threads with different surfaces.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetSurfaceAlphaMod
See Also: SDL_SetSurfaceColorMod