pub unsafe extern "C" fn SDL_GetTextureColorModFloat(
texture: *mut SDL_Texture,
r: *mut f32,
g: *mut f32,
b: *mut f32,
) -> boolExpand description
Get the additional color value multiplied into render copy operations.
Parameter: texture the texture to query. Parameter: r a pointer filled in with the current red color value. Parameter: g a pointer filled in with the current green color value. Parameter: b a pointer filled in with the current blue color value. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetTextureAlphaModFloat See Also: SDL_GetTextureColorMod See Also: SDL_SetTextureColorModFloat