pub unsafe extern "C" fn SDL_GetTextureScaleMode(
texture: *mut SDL_Texture,
scaleMode: *mut SDL_ScaleMode,
) -> boolExpand description
Get the scale mode used for texture scale operations.
Parameter: texture the texture to query. Parameter: scaleMode a pointer filled in with the current scale mode. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetTextureScaleMode