pub unsafe extern "C" fn SDL_GetTextureSize(
texture: *mut SDL_Texture,
w: *mut f32,
h: *mut f32,
) -> boolExpand description
Get the size of a texture, as floating point values.
Parameter: texture the texture to query. Parameter: w a pointer filled in with the width of the texture in pixels. This argument can be NULL if you don’t need this information. Parameter: h a pointer filled in with the height of the texture in pixels. This argument can be NULL if you don’t need this information. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.