pub unsafe extern "C" fn SDL_GetWindowFullscreenMode(
window: *mut SDL_Window,
) -> *const SDL_DisplayModeExpand description
Query the display mode to use when a window is visible at fullscreen.
Parameter: window the window to query. Returns: a pointer to the exclusive fullscreen mode to use or NULL for borderless fullscreen desktop mode.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetWindowFullscreenMode See Also: SDL_SetWindowFullscreen