pub unsafe extern "C" fn SDL_GetWindowRelativeMouseMode(
window: *mut SDL_Window,
) -> boolExpand description
Query whether relative mouse mode is enabled for a window.
Parameter: window the window to query. Returns: true if relative mode is enabled for a window or false otherwise.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetWindowRelativeMouseMode