pub unsafe extern "C" fn SDL_GetWindowSizeInPixels(
window: *mut SDL_Window,
w: *mut c_int,
h: *mut c_int,
) -> boolExpand description
Get the size of a window’s client area, in pixels.
Parameter: window the window from which the drawable size should be queried. Parameter: w a pointer to variable for storing the width in pixels, may be NULL. Parameter: h a pointer to variable for storing the height in pixels, may be NULL. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_CreateWindow See Also: SDL_GetWindowSize