pub unsafe extern "C" fn SDL_HasPrimarySelectionText() -> boolExpand description
Query whether the primary selection exists and contains a non-empty text string.
Returns: true if the primary selection has text, or false if it does not.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetPrimarySelectionText See Also: SDL_SetPrimarySelectionText