pub unsafe extern "C" fn SDL_HasScreenKeyboardSupport() -> boolExpand description
Check whether the platform has screen keyboard support.
Returns: true if the platform has some screen keyboard support or false if not.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_StartTextInput See Also: SDL_ScreenKeyboardShown