pub unsafe extern "C" fn SDL_InsertTrayEntryAt(
menu: *mut SDL_TrayMenu,
pos: c_int,
label: *const c_char,
flags: SDL_TrayEntryFlags,
) -> *mut SDL_TrayEntryExpand description
Insert a tray entry at a given position.
If label is NULL, the entry will be a separator. Many functions won’t work for an entry that is a separator.
An entry does not need to be destroyed; it will be destroyed with the tray.
Parameter: menu the menu to append the entry to. Parameter: pos the desired position for the new entry. Entries at or following this place will be moved. If pos is -1, the entry is appended. Parameter: label the text to be displayed on the entry, in UTF-8 encoding, or NULL for a separator. Parameter: flags a combination of flags, some of which are mandatory. Returns: the newly created entry, or NULL if pos is out of bounds.
Thread Safety: This function should be called on the thread that created the tray.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_TrayEntryFlags See Also: SDL_GetTrayEntries See Also: SDL_RemoveTrayEntry See Also: SDL_GetTrayEntryParent