pub unsafe extern "C" fn SDL_IsPhone() -> boolExpand description
Query if the current device is a phone.
If SDL can’t determine this, it will return false.
Returns: true if the device is a phone, false otherwise.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.6.0.