pub unsafe extern "C" fn SDL_LoadFile(
file: *const c_char,
datasize: *mut usize,
) -> *mut c_voidExpand description
Load all the data from a file path.
The data is allocated with a zero byte at the end (null terminated) for
convenience. This extra byte is not included in the value reported via
datasize.
The data should be freed with SDL_free().
Parameter: file the path to read all available data from. Parameter: datasize if not NULL, will store the number of bytes read. Returns: the data or NULL on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_LoadFile_IO See Also: SDL_SaveFile