pub unsafe extern "C" fn SDL_LoadFile_IO(
src: *mut SDL_IOStream,
datasize: *mut usize,
closeio: bool,
) -> *mut c_voidExpand description
Load all the data from an SDL data stream.
The data is allocated with a zero byte at the end (null terminated) for
convenience. This extra byte is not included in the value reported via
datasize.
The data should be freed with SDL_free().
Parameter: src the SDL_IOStream to read all available data from.
Parameter: datasize a pointer filled in with the number of bytes read, may be
NULL.
Parameter: closeio if true, calls SDL_CloseIO() on src before returning, even
in the case of an error.
Returns: the data or NULL on failure; call SDL_GetError() for more
information.
Thread Safety: Do not use the same SDL_IOStream from two threads at once.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_LoadFile See Also: SDL_SaveFile_IO