pub unsafe extern "C" fn SDL_LoadObject(
sofile: *const c_char,
) -> *mut SDL_SharedObjectExpand description
Dynamically load a shared object.
Parameter: sofile a system-dependent name of the object file. Returns: an opaque pointer to the object handle or NULL on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_LoadFunction See Also: SDL_UnloadObject