pub unsafe extern "C" fn SDL_OpenIO(
iface: *const SDL_IOStreamInterface,
userdata: *mut c_void,
) -> *mut SDL_IOStreamExpand description
Create a custom SDL_IOStream.
Applications do not need to use this function unless they are providing their own SDL_IOStream implementation. If you just need an SDL_IOStream to read/write a common data source, you should use the built-in implementations in SDL, like SDL_IOFromFile() or SDL_IOFromMem(), etc.
This function makes a copy of iface and the caller does not need to keep
it around after this call.
Parameter: iface the interface that implements this SDL_IOStream, initialized using SDL_INIT_INTERFACE(). Parameter: userdata the pointer that will be passed to the interface functions. Returns: a pointer to the allocated memory on success or NULL on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_CloseIO See Also: SDL_INIT_INTERFACE See Also: SDL_IOFromConstMem See Also: SDL_IOFromFile See Also: SDL_IOFromMem