pub unsafe extern "C" fn SDL_RegisterEvents(
numevents: c_int,
) -> Uint32Expand description
Allocate a set of user-defined events, and return the beginning event number for that set of events.
Parameter: numevents the number of events to be allocated. Returns: the beginning event number, or 0 if numevents is invalid or if there are not enough user-defined events left.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_PushEvent