pub unsafe extern "C" fn SDL_RenderGeometry(
renderer: *mut SDL_Renderer,
texture: *mut SDL_Texture,
vertices: *const SDL_Vertex,
num_vertices: c_int,
indices: *const c_int,
num_indices: c_int,
) -> boolExpand description
Render a list of triangles, optionally using a texture and indices into the vertex array.
Color and alpha modulation is done per vertex (SDL_SetTextureColorMod and SDL_SetTextureAlphaMod are ignored).
Parameter: renderer the rendering context. Parameter: texture (optional) The SDL texture to use. Parameter: vertices vertices. Parameter: num_vertices number of vertices. Parameter: indices (optional) An array of integer indices into the ‘vertices’ array, if NULL all vertices will be rendered in sequential order. Parameter: num_indices number of indices. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_RenderGeometryRaw See Also: SDL_SetRenderTextureAddressMode