pub unsafe extern "C" fn SDL_RenderLine(
renderer: *mut SDL_Renderer,
x1: f32,
y1: f32,
x2: f32,
y2: f32,
) -> boolExpand description
Draw a line on the current rendering target at subpixel precision.
Parameter: renderer the renderer which should draw a line. Parameter: x1 the x coordinate of the start point. Parameter: y1 the y coordinate of the start point. Parameter: x2 the x coordinate of the end point. Parameter: y2 the y coordinate of the end point. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_RenderLines