pub unsafe extern "C" fn SDL_RenderTextureTiled(
renderer: *mut SDL_Renderer,
texture: *mut SDL_Texture,
srcrect: *const SDL_FRect,
scale: f32,
dstrect: *const SDL_FRect,
) -> boolExpand description
Tile a portion of the texture to the current rendering target at subpixel precision.
The pixels in srcrect will be repeated as many times as needed to
completely fill dstrect.
Parameter: renderer the renderer which should copy parts of a texture. Parameter: texture the source texture. Parameter: srcrect a pointer to the source rectangle, or NULL for the entire texture. Parameter: scale the scale used to transform srcrect into the destination rectangle, e.g. a 32x32 texture with a scale of 2 would fill 64x64 tiles. Parameter: dstrect a pointer to the destination rectangle, or NULL for the entire rendering target. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_RenderTexture