pub unsafe extern "C" fn SDL_SaveFile(
file: *const c_char,
data: *const c_void,
datasize: usize,
) -> boolExpand description
Save all the data into a file path.
Parameter: file the path to write all available data into. Parameter: data the data to be written. If datasize is 0, may be NULL or a invalid pointer. Parameter: datasize the number of bytes to be written. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SaveFile_IO See Also: SDL_LoadFile