pub unsafe extern "C" fn SDL_SetErrorV(
fmt: *const c_char,
ap: *mut __va_list_tag,
) -> boolExpand description
Set the SDL error message for the current thread.
Calling this function will replace any previous error message that was set.
Parameter: fmt a printf()-style message format string. Parameter: ap a variable argument list. Returns: false.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_ClearError See Also: SDL_GetError See Also: SDL_SetError