pub unsafe extern "C" fn SDL_SetInitialized(
state: *mut SDL_InitState,
initialized: bool,
)Expand description
Finish an initialization state transition.
This function sets the status of the passed in state to
SDL_INIT_STATUS_INITIALIZED or SDL_INIT_STATUS_UNINITIALIZED and allows
any threads waiting for the status to proceed.
Parameter: state the initialization state to check. Parameter: initialized the new initialization state.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_ShouldInit See Also: SDL_ShouldQuit