pub unsafe extern "C" fn SDL_SetModState(modstate: SDL_Keymod)Expand description
Set the current key modifier state for the keyboard.
The inverse of SDL_GetModState(), SDL_SetModState() allows you to impose
modifier key states on your application. Simply pass your desired modifier
states into modstate. This value may be a bitwise, OR’d combination of
SDL_Keymod values.
This does not change the keyboard state, only the key modifier flags that SDL reports.
Parameter: modstate the desired SDL_Keymod for the keyboard.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetModState