pub unsafe extern "C" fn SDL_SetPrimarySelectionText(
text: *const c_char,
) -> boolExpand description
Put UTF-8 text into the primary selection.
Parameter: text the text to store in the primary selection. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetPrimarySelectionText See Also: SDL_HasPrimarySelectionText