pub unsafe extern "C" fn SDL_SetRenderDrawBlendMode(
renderer: *mut SDL_Renderer,
blendMode: SDL_BlendMode,
) -> boolExpand description
Set the blend mode used for drawing operations (Fill and Line).
If the blend mode is not supported, the closest supported mode is chosen.
Parameter: renderer the rendering context. Parameter: blendMode the SDL_BlendMode to use for blending. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetRenderDrawBlendMode