SDL_SetRenderTextureAddressMode

Function SDL_SetRenderTextureAddressMode 

pub unsafe extern "C" fn SDL_SetRenderTextureAddressMode(
    renderer: *mut SDL_Renderer,
    u_mode: SDL_TextureAddressMode,
    v_mode: SDL_TextureAddressMode,
) -> bool
Set the texture addressing mode used in SDL_RenderGeometry().

Parameter: renderer the rendering context. Parameter: u_mode the SDL_TextureAddressMode to use for horizontal texture coordinates in SDL_RenderGeometry(). Parameter: v_mode the SDL_TextureAddressMode to use for vertical texture coordinates in SDL_RenderGeometry(). Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should only be called on the main thread.

Available Since: This function is available since SDL 3.4.0.

See Also: SDL_RenderGeometry See Also: SDL_RenderGeometryRaw See Also: SDL_GetRenderTextureAddressMode