pub unsafe extern "C" fn SDL_SetRenderVSync(
renderer: *mut SDL_Renderer,
vsync: c_int,
) -> boolExpand description
Toggle VSync of the given renderer.
When a renderer is created, vsync defaults to SDL_RENDERER_VSYNC_DISABLED.
The vsync parameter can be 1 to synchronize present with every vertical
refresh, 2 to synchronize present with every second vertical refresh, etc.,
SDL_RENDERER_VSYNC_ADAPTIVE for late swap tearing (adaptive vsync), or
SDL_RENDERER_VSYNC_DISABLED to disable. Not every value is supported by
every driver, so you should check the return value to see whether the
requested setting is supported.
Parameter: renderer the renderer to toggle. Parameter: vsync the vertical refresh sync interval. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetRenderVSync