pub unsafe extern "C" fn SDL_SetScancodeName(
scancode: SDL_Scancode,
name: *const c_char,
) -> boolExpand description
Set a human-readable name for a scancode.
Parameter: scancode the desired SDL_Scancode. Parameter: name the name to use for the scancode, encoded as UTF-8. The string is not copied, so the pointer given to this function must stay valid while SDL is being used. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function is not thread safe.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetScancodeName