pub unsafe extern "C" fn SDL_SetTextInputArea(
window: *mut SDL_Window,
rect: *const SDL_Rect,
cursor: c_int,
) -> boolExpand description
Set the area used to type Unicode text input.
Native input methods may place a window with word suggestions near the cursor, without covering the text being entered.
Parameter: window the window for which to set the text input area.
Parameter: rect the SDL_Rect representing the text input area, in window
coordinates, or NULL to clear it.
Parameter: cursor the offset of the current cursor location relative to
rect->x, in window coordinates.
Returns: true on success or false on failure; call SDL_GetError() for more
information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetTextInputArea See Also: SDL_StartTextInput