pub unsafe extern "C" fn SDL_SetTextureBlendMode(
texture: *mut SDL_Texture,
blendMode: SDL_BlendMode,
) -> boolExpand description
Set the blend mode for a texture, used by SDL_RenderTexture().
If the blend mode is not supported, the closest supported mode is chosen and this function returns false.
Parameter: texture the texture to update. Parameter: blendMode the SDL_BlendMode to use for texture blending. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetTextureBlendMode