pub unsafe extern "C" fn SDL_SetWindowModal(
window: *mut SDL_Window,
modal: bool,
) -> boolExpand description
Toggle the state of the window as modal.
To enable modal status on a window, the window must currently be the child window of a parent, or toggling modal status on will fail.
Parameter: window the window on which to set the modal state. Parameter: modal true to toggle modal status on, false to toggle it off. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetWindowParent See Also: SDL_WINDOW_MODAL