pub unsafe extern "C" fn SDL_SetWindowMouseGrab(
window: *mut SDL_Window,
grabbed: bool,
) -> boolExpand description
Set a window’s mouse grab mode.
Mouse grab confines the mouse cursor to the window.
Parameter: window the window for which the mouse grab mode should be set. Parameter: grabbed this is true to grab mouse, and false to release. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GetWindowMouseRect See Also: SDL_SetWindowMouseRect See Also: SDL_SetWindowKeyboardGrab