pub unsafe extern "C" fn SDL_SetWindowProgressValue(
window: *mut SDL_Window,
value: f32,
) -> boolExpand description
Sets the value of the progress bar for the given window’s taskbar icon.
Parameter: window the window whose progress value is to be modified. Parameter: value the progress value in the range of [0.0f - 1.0f]. If the value is outside the valid range, it gets clamped. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.4.0.