pub unsafe extern "C" fn SDL_StartTextInput(
window: *mut SDL_Window,
) -> boolExpand description
Start accepting Unicode text input events in a window.
This function will enable text input (SDL_EVENT_TEXT_INPUT and SDL_EVENT_TEXT_EDITING events) in the specified window. Please use this function paired with SDL_StopTextInput().
Text input events are not received by default.
On some platforms using this function shows the screen keyboard and/or activates an IME, which can prevent some key press events from being passed through.
Parameter: window the window to enable text input. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_SetTextInputArea See Also: SDL_StartTextInputWithProperties See Also: SDL_StopTextInput See Also: SDL_TextInputActive