pub unsafe extern "C" fn SDL_StringToGUID(
pchGUID: *const c_char,
) -> SDL_GUIDExpand description
Convert a GUID string into a SDL_GUID structure.
Performs no error checking. If this function is given a string containing an invalid GUID, the function will silently succeed, but the GUID generated will not be useful.
Parameter: pchGUID string containing an ASCII representation of a GUID. Returns: a SDL_GUID structure.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_GUIDToString