pub unsafe extern "C" fn SDL_UnbindAudioStream(
stream: *mut SDL_AudioStream,
)Expand description
Unbind a single audio stream from its audio device.
This is a convenience function, equivalent to calling
SDL_UnbindAudioStreams(&stream, 1).
Parameter: stream an audio stream to unbind from a device. Can be NULL.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_BindAudioStream