pub unsafe extern "C" fn SDL_UnbindAudioStreams(
streams: *const *mut SDL_AudioStream,
num_streams: c_int,
)Expand description
Unbind a list of audio streams from their audio devices.
The streams being unbound do not all have to be on the same device. All streams on the same device will be unbound atomically (data will stop flowing through all unbound streams on the same device at the same time).
Unbinding a stream that isn’t bound to a device is a legal no-op.
Parameter: streams an array of audio streams to unbind. Can be NULL or contain
NULL.
Parameter: num_streams number streams listed in the streams array.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_BindAudioStreams