pub unsafe extern "C" fn SDL_UploadToGPUBuffer(
copy_pass: *mut SDL_GPUCopyPass,
source: *const SDL_GPUTransferBufferLocation,
destination: *const SDL_GPUBufferRegion,
cycle: bool,
)Expand description
Uploads data from a transfer buffer to a buffer.
The upload occurs on the GPU timeline. You may assume that the upload has finished in subsequent commands.
Parameter: copy_pass a copy pass handle. Parameter: source the source transfer buffer with offset. Parameter: destination the destination buffer with offset and size. Parameter: cycle if true, cycles the buffer if it is already bound, otherwise overwrites the data.
Available Since: This function is available since SDL 3.2.0.