pub unsafe extern "C" fn SDL_WaitConditionTimeout(
cond: *mut SDL_Condition,
mutex: *mut SDL_Mutex,
timeoutMS: Sint32,
) -> boolExpand description
Wait until a condition variable is signaled or a certain time has passed.
This function unlocks the specified mutex and waits for another thread to
call SDL_SignalCondition() or SDL_BroadcastCondition() on the condition
variable cond, or for the specified time to elapse. Once the condition
variable is signaled or the time elapsed, the mutex is re-locked and the
function returns.
The mutex must be locked before calling this function. Locking the mutex recursively (more than once) is not supported and leads to undefined behavior.
Parameter: cond the condition variable to wait on. Parameter: mutex the mutex used to coordinate thread access. Parameter: timeoutMS the maximum time to wait, in milliseconds, or -1 to wait indefinitely. Returns: true if the condition variable is signaled, false if the condition is not signaled in the allotted time.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_BroadcastCondition See Also: SDL_SignalCondition See Also: SDL_WaitCondition