pub unsafe extern "C" fn SDL_WarpMouseInWindow(
window: *mut SDL_Window,
x: f32,
y: f32,
)Expand description
Move the mouse cursor to the given position within the window.
This function generates a mouse motion event if relative mode is not enabled. If relative mode is enabled, you can force mouse events for the warp by setting the SDL_HINT_MOUSE_RELATIVE_WARP_MOTION hint.
Note that this function will appear to succeed, but not actually move the mouse when used over Microsoft Remote Desktop.
Parameter: window the window to move the mouse into, or NULL for the current mouse focus. Parameter: x the x coordinate within the window. Parameter: y the y coordinate within the window.
Thread Safety: This function should only be called on the main thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_WarpMouseGlobal