pub unsafe extern "C" fn SDL_WasInit(
flags: SDL_InitFlags,
) -> SDL_InitFlagsExpand description
Get a mask of the specified subsystems which are currently initialized.
Parameter: flags any of the flags used by SDL_Init(); see SDL_Init for details.
Returns: a mask of all initialized subsystems if flags is 0, otherwise it
returns the initialization status of the specified subsystems.
Thread Safety: This function is not thread safe.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_Init See Also: SDL_InitSubSystem