pub unsafe extern "C" fn SDL_WriteSurfacePixelFloat(
surface: *mut SDL_Surface,
x: c_int,
y: c_int,
r: f32,
g: f32,
b: f32,
a: f32,
) -> boolExpand description
Writes a single pixel to a surface.
This function prioritizes correctness over speed: it is suitable for unit tests, but is not intended for use in a game engine.
Parameter: surface the surface to write. Parameter: x the horizontal coordinate, 0 <= x < width. Parameter: y the vertical coordinate, 0 <= y < height. Parameter: r the red channel value, normally in the range 0-1. Parameter: g the green channel value, normally in the range 0-1. Parameter: b the blue channel value, normally in the range 0-1. Parameter: a the alpha channel value, normally in the range 0-1. Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function can be called on different threads with different surfaces.
Available Since: This function is available since SDL 3.2.0.