pub unsafe extern "C" fn SDL_aligned_alloc(
alignment: usize,
size: usize,
) -> *mut c_voidExpand description
Allocate memory aligned to a specific alignment.
The memory returned by this function must be freed with SDL_aligned_free(), not SDL_free().
If alignment is less than the size of void *, it will be increased to
match that.
The returned memory address will be a multiple of the alignment value, and the size of the memory allocated will be a multiple of the alignment value.
Parameter: alignment the alignment of the memory. Parameter: size the size to allocate. Returns: a pointer to the aligned memory, or NULL if allocation failed.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.
See Also: SDL_aligned_free