pub unsafe extern "C" fn SDL_strcasecmp(
str1: *const c_char,
str2: *const c_char,
) -> c_intExpand description
Compare two null-terminated UTF-8 strings, case-insensitively.
This will work with Unicode strings, using a technique called “case-folding” to handle the vast majority of case-sensitive human languages regardless of system locale. It can deal with expanding values: a German Eszett character can compare against two ASCII ‘s’ chars and be considered a match, for example. A notable exception: it does not handle the Turkish ‘i’ character; human language is complicated!
Since this handles Unicode, it expects the string to be well-formed UTF-8 and not a null-terminated string of arbitrary bytes. Bytes that are not valid UTF-8 are treated as Unicode character U+FFFD (REPLACEMENT CHARACTER), which is to say two strings of random bits may turn out to match if they convert to the same amount of replacement characters.
Parameter: str1 the first string to compare. NULL is not permitted! Parameter: str2 the second string to compare. NULL is not permitted! Returns: less than zero if str1 is “less than” str2, greater than zero if str1 is “greater than” str2, and zero if the strings match exactly.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.