pub unsafe extern "C" fn SDL_vasprintf(
strp: *mut *mut c_char,
fmt: *const c_char,
ap: *mut __va_list_tag,
) -> c_intExpand description
This works exactly like vasprintf() but doesn’t require access to a C runtime.
Functions identically to SDL_asprintf(), except it takes a va_list
instead of using ... variable arguments.
Parameter: strp on output, is set to the new string. Must not be NULL.
Parameter: fmt a printf-style format string. Must not be NULL.
Parameter: ap a va_list values to be used with the format string.
Returns: the number of bytes in the newly-allocated string, not counting
the null-terminator char, or a negative value on error.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL 3.2.0.