#[repr(transparent)]pub struct SDL_ChromaLocation(pub c_uint);Expand description
Colorspace chroma sample location.
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_ChromaLocation
impl SDL_ChromaLocation
Sourcepub const SDL_CHROMA_LOCATION_NONE: SDL_ChromaLocation
pub const SDL_CHROMA_LOCATION_NONE: SDL_ChromaLocation
< RGB, no chroma sampling
Sourcepub const SDL_CHROMA_LOCATION_LEFT: SDL_ChromaLocation
pub const SDL_CHROMA_LOCATION_LEFT: SDL_ChromaLocation
< In MPEG-2, MPEG-4, and AVC, Cb and Cr are taken on midpoint of the left-edge of the 2x2 square. In other words, they have the same horizontal location as the top-left pixel, but is shifted one-half pixel down vertically.
Sourcepub const SDL_CHROMA_LOCATION_CENTER: SDL_ChromaLocation
pub const SDL_CHROMA_LOCATION_CENTER: SDL_ChromaLocation
< In JPEG/JFIF, H.261, and MPEG-1, Cb and Cr are taken at the center of the 2x2 square. In other words, they are offset one-half pixel to the right and one-half pixel down compared to the top-left pixel.
Sourcepub const SDL_CHROMA_LOCATION_TOPLEFT: SDL_ChromaLocation
pub const SDL_CHROMA_LOCATION_TOPLEFT: SDL_ChromaLocation
< In HEVC for BT.2020 and BT.2100 content (in particular on Blu-rays), Cb and Cr are sampled at the same location as the group’s top-left Y pixel (“co-sited”, “co-located”).