#[repr(transparent)]pub struct SDL_Colorspace(pub c_uint);Expand description
Colorspace definitions.
Since similar colorspaces may vary in their details (matrix, transfer function, etc.), this is not an exhaustive list, but rather a representative sample of the kinds of colorspaces supported in SDL.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_ColorPrimaries See Also: SDL_ColorRange See Also: SDL_ColorType See Also: SDL_MatrixCoefficients See Also: SDL_TransferCharacteristics
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_Colorspace
impl SDL_Colorspace
pub const SDL_COLORSPACE_UNKNOWN: SDL_Colorspace
Sourcepub const SDL_COLORSPACE_SRGB: SDL_Colorspace
pub const SDL_COLORSPACE_SRGB: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_RGB_FULL_G22_NONE_P709
Sourcepub const SDL_COLORSPACE_SRGB_LINEAR: SDL_Colorspace
pub const SDL_COLORSPACE_SRGB_LINEAR: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_RGB_FULL_G10_NONE_P709
Sourcepub const SDL_COLORSPACE_HDR10: SDL_Colorspace
pub const SDL_COLORSPACE_HDR10: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_RGB_FULL_G2084_NONE_P2020
Sourcepub const SDL_COLORSPACE_JPEG: SDL_Colorspace
pub const SDL_COLORSPACE_JPEG: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_YCBCR_FULL_G22_NONE_P709_X601
Sourcepub const SDL_COLORSPACE_BT601_LIMITED: SDL_Colorspace
pub const SDL_COLORSPACE_BT601_LIMITED: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_YCBCR_STUDIO_G22_LEFT_P601
Sourcepub const SDL_COLORSPACE_BT601_FULL: SDL_Colorspace
pub const SDL_COLORSPACE_BT601_FULL: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_YCBCR_STUDIO_G22_LEFT_P601
Sourcepub const SDL_COLORSPACE_BT709_LIMITED: SDL_Colorspace
pub const SDL_COLORSPACE_BT709_LIMITED: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_YCBCR_STUDIO_G22_LEFT_P709
Sourcepub const SDL_COLORSPACE_BT709_FULL: SDL_Colorspace
pub const SDL_COLORSPACE_BT709_FULL: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_YCBCR_STUDIO_G22_LEFT_P709
Sourcepub const SDL_COLORSPACE_BT2020_LIMITED: SDL_Colorspace
pub const SDL_COLORSPACE_BT2020_LIMITED: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_YCBCR_STUDIO_G22_LEFT_P2020
Sourcepub const SDL_COLORSPACE_BT2020_FULL: SDL_Colorspace
pub const SDL_COLORSPACE_BT2020_FULL: SDL_Colorspace
< Equivalent to DXGI_COLOR_SPACE_YCBCR_FULL_G22_LEFT_P2020
Sourcepub const SDL_COLORSPACE_RGB_DEFAULT: SDL_Colorspace
pub const SDL_COLORSPACE_RGB_DEFAULT: SDL_Colorspace
< The default colorspace for RGB surfaces if no colorspace is specified
Sourcepub const SDL_COLORSPACE_YUV_DEFAULT: SDL_Colorspace
pub const SDL_COLORSPACE_YUV_DEFAULT: SDL_Colorspace
< The default colorspace for YUV surfaces if no colorspace is specified