#[repr(transparent)]pub struct SDL_GPUBlendFactor(pub c_uint);Expand description
Specifies a blending factor to be used when pixels in a render target are blended with existing pixels in the texture.
The source color is the value written by the fragment shader. The destination color is the value currently existing in the texture.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_CreateGPUGraphicsPipeline
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GPUBlendFactor
impl SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_INVALID: SDL_GPUBlendFactor
Sourcepub const SDL_GPU_BLENDFACTOR_ZERO: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_ZERO: SDL_GPUBlendFactor
< 0
Sourcepub const SDL_GPU_BLENDFACTOR_ONE: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_ONE: SDL_GPUBlendFactor
< 1
Sourcepub const SDL_GPU_BLENDFACTOR_SRC_COLOR: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_SRC_COLOR: SDL_GPUBlendFactor
< source color
Sourcepub const SDL_GPU_BLENDFACTOR_ONE_MINUS_SRC_COLOR: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_ONE_MINUS_SRC_COLOR: SDL_GPUBlendFactor
< 1 - source color
Sourcepub const SDL_GPU_BLENDFACTOR_DST_COLOR: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_DST_COLOR: SDL_GPUBlendFactor
< destination color
Sourcepub const SDL_GPU_BLENDFACTOR_ONE_MINUS_DST_COLOR: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_ONE_MINUS_DST_COLOR: SDL_GPUBlendFactor
< 1 - destination color
Sourcepub const SDL_GPU_BLENDFACTOR_SRC_ALPHA: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_SRC_ALPHA: SDL_GPUBlendFactor
< source alpha
Sourcepub const SDL_GPU_BLENDFACTOR_ONE_MINUS_SRC_ALPHA: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_ONE_MINUS_SRC_ALPHA: SDL_GPUBlendFactor
< 1 - source alpha
Sourcepub const SDL_GPU_BLENDFACTOR_DST_ALPHA: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_DST_ALPHA: SDL_GPUBlendFactor
< destination alpha
Sourcepub const SDL_GPU_BLENDFACTOR_ONE_MINUS_DST_ALPHA: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_ONE_MINUS_DST_ALPHA: SDL_GPUBlendFactor
< 1 - destination alpha
Sourcepub const SDL_GPU_BLENDFACTOR_CONSTANT_COLOR: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_CONSTANT_COLOR: SDL_GPUBlendFactor
< blend constant
Sourcepub const SDL_GPU_BLENDFACTOR_ONE_MINUS_CONSTANT_COLOR: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_ONE_MINUS_CONSTANT_COLOR: SDL_GPUBlendFactor
< 1 - blend constant
Sourcepub const SDL_GPU_BLENDFACTOR_SRC_ALPHA_SATURATE: SDL_GPUBlendFactor
pub const SDL_GPU_BLENDFACTOR_SRC_ALPHA_SATURATE: SDL_GPUBlendFactor
< min(source alpha, 1 - destination alpha)