#[repr(transparent)]pub struct SDL_GPUBlendOp(pub c_uint);Expand description
Specifies the operator to be used when pixels in a render target are blended with existing pixels in the texture.
The source color is the value written by the fragment shader. The destination color is the value currently existing in the texture.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_CreateGPUGraphicsPipeline
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_GPUBlendOp
impl SDL_GPUBlendOp
pub const SDL_GPU_BLENDOP_INVALID: SDL_GPUBlendOp
Sourcepub const SDL_GPU_BLENDOP_ADD: SDL_GPUBlendOp
pub const SDL_GPU_BLENDOP_ADD: SDL_GPUBlendOp
< (source * source_factor) + (destination * destination_factor)
Sourcepub const SDL_GPU_BLENDOP_SUBTRACT: SDL_GPUBlendOp
pub const SDL_GPU_BLENDOP_SUBTRACT: SDL_GPUBlendOp
< (source * source_factor) - (destination * destination_factor)
Sourcepub const SDL_GPU_BLENDOP_REVERSE_SUBTRACT: SDL_GPUBlendOp
pub const SDL_GPU_BLENDOP_REVERSE_SUBTRACT: SDL_GPUBlendOp
< (destination * destination_factor) - (source * source_factor)
Sourcepub const SDL_GPU_BLENDOP_MIN: SDL_GPUBlendOp
pub const SDL_GPU_BLENDOP_MIN: SDL_GPUBlendOp
< min(source, destination)
Sourcepub const SDL_GPU_BLENDOP_MAX: SDL_GPUBlendOp
pub const SDL_GPU_BLENDOP_MAX: SDL_GPUBlendOp
< max(source, destination)