#[repr(transparent)]pub struct SDL_GPUPresentMode(pub c_uint);Expand description
Specifies the timing that will be used to present swapchain textures to the OS.
VSYNC mode will always be supported. IMMEDIATE and MAILBOX modes may not be supported on certain systems.
It is recommended to query SDL_WindowSupportsGPUPresentMode after claiming the window if you wish to change the present mode to IMMEDIATE or MAILBOX.
- VSYNC: Waits for vblank before presenting. No tearing is possible. If there is a pending image to present, the new image is enqueued for presentation. Disallows tearing at the cost of visual latency.
- IMMEDIATE: Immediately presents. Lowest latency option, but tearing may occur.
- MAILBOX: Waits for vblank before presenting. No tearing is possible. If there is a pending image to present, the pending image is replaced by the new image. Similar to VSYNC, but with reduced visual latency.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_SetGPUSwapchainParameters See Also: SDL_WindowSupportsGPUPresentMode See Also: SDL_WaitAndAcquireGPUSwapchainTexture
Tuple Fields
0: c_uintImplementations