#[repr(C)]pub struct SDL_GPURenderStateCreateInfo {
pub fragment_shader: *mut SDL_GPUShader,
pub num_sampler_bindings: Sint32,
pub sampler_bindings: *const SDL_GPUTextureSamplerBinding,
pub num_storage_textures: Sint32,
pub storage_textures: *const *mut SDL_GPUTexture,
pub num_storage_buffers: Sint32,
pub storage_buffers: *const *mut SDL_GPUBuffer,
pub props: SDL_PropertiesID,
}Expand description
A structure specifying the parameters of a GPU render state.
Available Since: This struct is available since SDL 3.4.0.
See Also: SDL_CreateGPURenderState
Fields
fragment_shader: *mut SDL_GPUShader< The fragment shader to use when this render state is active
num_sampler_bindings: Sint32< The number of additional fragment samplers to bind when this render state is active
sampler_bindings: *const SDL_GPUTextureSamplerBinding< Additional fragment samplers to bind when this render state is active
num_storage_textures: Sint32< The number of storage textures to bind when this render state is active
storage_textures: *const *mut SDL_GPUTexture< Storage textures to bind when this render state is active
num_storage_buffers: Sint32< The number of storage buffers to bind when this render state is active
storage_buffers: *const *mut SDL_GPUBuffer< Storage buffers to bind when this render state is active
props: SDL_PropertiesID< A properties ID for extensions. Should be 0 if no extensions are needed.