#[repr(C)]pub struct SDL_GPUStorageTextureReadWriteBinding {
pub texture: *mut SDL_GPUTexture,
pub mip_level: Uint32,
pub layer: Uint32,
pub cycle: bool,
pub padding1: Uint8,
pub padding2: Uint8,
pub padding3: Uint8,
}Expand description
A structure specifying parameters related to binding textures in a compute pass.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_BeginGPUComputePass
Fields
texture: *mut SDL_GPUTexture< The texture to bind. Must have been created with SDL_GPU_TEXTUREUSAGE_COMPUTE_STORAGE_WRITE or SDL_GPU_TEXTUREUSAGE_COMPUTE_STORAGE_SIMULTANEOUS_READ_WRITE.
mip_level: Uint32< The mip level index to bind.
layer: Uint32< The layer index to bind.
cycle: bool< true cycles the texture if it is already bound.
padding1: Uint8padding2: Uint8padding3: Uint8Trait Implementations
Sourceimpl Clone for SDL_GPUStorageTextureReadWriteBinding
impl Clone for SDL_GPUStorageTextureReadWriteBinding
Sourcefn clone(&self) -> SDL_GPUStorageTextureReadWriteBinding
fn clone(&self) -> SDL_GPUStorageTextureReadWriteBinding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SDL_GPUStorageTextureReadWriteBinding