#[repr(C)]pub struct SDL_GamepadBinding {
pub input_type: SDL_GamepadBindingType,
pub input: SDL_GamepadBinding__bindgen_ty_1,
pub output_type: SDL_GamepadBindingType,
pub output: SDL_GamepadBinding__bindgen_ty_2,
}Expand description
A mapping between one joystick input to a gamepad control.
A gamepad has a collection of several bindings, to say, for example, when joystick button number 5 is pressed, that should be treated like the gamepad’s “start” button.
SDL has these bindings built-in for many popular controllers, and can add more with a simple text string. Those strings are parsed into a collection of these structs to make it easier to operate on the data.
Available Since: This struct is available since SDL 3.2.0.
See Also: SDL_GetGamepadBindings
Fields
input_type: SDL_GamepadBindingTypeinput: SDL_GamepadBinding__bindgen_ty_1output_type: SDL_GamepadBindingTypeoutput: SDL_GamepadBinding__bindgen_ty_2Trait Implementations
Sourceimpl Clone for SDL_GamepadBinding
impl Clone for SDL_GamepadBinding
Sourcefn clone(&self) -> SDL_GamepadBinding
fn clone(&self) -> SDL_GamepadBinding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SDL_GamepadBinding
impl Default for SDL_GamepadBinding
impl Copy for SDL_GamepadBinding