#[repr(transparent)]pub struct SDL_LogCategory(pub c_uint);Expand description
The predefined log categories
By default the application and gpu categories are enabled at the INFO level, the assert category is enabled at the WARN level, test is enabled at the VERBOSE level and all other categories are enabled at the ERROR level.
Available Since: This enum is available since SDL 3.2.0.
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_LogCategory
impl SDL_LogCategory
pub const SDL_LOG_CATEGORY_APPLICATION: SDL_LogCategory
pub const SDL_LOG_CATEGORY_ERROR: SDL_LogCategory
pub const SDL_LOG_CATEGORY_ASSERT: SDL_LogCategory
pub const SDL_LOG_CATEGORY_SYSTEM: SDL_LogCategory
pub const SDL_LOG_CATEGORY_AUDIO: SDL_LogCategory
pub const SDL_LOG_CATEGORY_VIDEO: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RENDER: SDL_LogCategory
pub const SDL_LOG_CATEGORY_INPUT: SDL_LogCategory
pub const SDL_LOG_CATEGORY_TEST: SDL_LogCategory
pub const SDL_LOG_CATEGORY_GPU: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED2: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED3: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED4: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED5: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED6: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED7: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED8: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED9: SDL_LogCategory
pub const SDL_LOG_CATEGORY_RESERVED10: SDL_LogCategory
pub const SDL_LOG_CATEGORY_CUSTOM: SDL_LogCategory