#[repr(transparent)]pub struct SDL_TextInputType(pub c_uint);Expand description
Text input type.
These are the valid values for SDL_PROP_TEXTINPUT_TYPE_NUMBER. Not every value is valid on every platform, but where a value isn’t supported, a reasonable fallback will be used.
Available Since: This enum is available since SDL 3.2.0.
See Also: SDL_StartTextInputWithProperties
Tuple Fields
0: c_uintImplementations
Sourceimpl SDL_TextInputType
impl SDL_TextInputType
Sourcepub const SDL_TEXTINPUT_TYPE_TEXT: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_TEXT: SDL_TextInputType
< The input is text
Sourcepub const SDL_TEXTINPUT_TYPE_TEXT_NAME: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_TEXT_NAME: SDL_TextInputType
< The input is a person’s name
Sourcepub const SDL_TEXTINPUT_TYPE_TEXT_EMAIL: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_TEXT_EMAIL: SDL_TextInputType
< The input is an e-mail address
Sourcepub const SDL_TEXTINPUT_TYPE_TEXT_USERNAME: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_TEXT_USERNAME: SDL_TextInputType
< The input is a username
Sourcepub const SDL_TEXTINPUT_TYPE_TEXT_PASSWORD_HIDDEN: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_TEXT_PASSWORD_HIDDEN: SDL_TextInputType
< The input is a secure password that is hidden
Sourcepub const SDL_TEXTINPUT_TYPE_TEXT_PASSWORD_VISIBLE: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_TEXT_PASSWORD_VISIBLE: SDL_TextInputType
< The input is a secure password that is visible
Sourcepub const SDL_TEXTINPUT_TYPE_NUMBER: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_NUMBER: SDL_TextInputType
< The input is a number
Sourcepub const SDL_TEXTINPUT_TYPE_NUMBER_PASSWORD_HIDDEN: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_NUMBER_PASSWORD_HIDDEN: SDL_TextInputType
< The input is a secure PIN that is hidden
Sourcepub const SDL_TEXTINPUT_TYPE_NUMBER_PASSWORD_VISIBLE: SDL_TextInputType
pub const SDL_TEXTINPUT_TYPE_NUMBER_PASSWORD_VISIBLE: SDL_TextInputType
< The input is a secure PIN that is visible