#[repr(C)]pub struct SDL_TouchFingerEvent {
pub type_: SDL_EventType,
pub reserved: Uint32,
pub timestamp: Uint64,
pub touchID: SDL_TouchID,
pub fingerID: SDL_FingerID,
pub x: f32,
pub y: f32,
pub dx: f32,
pub dy: f32,
pub pressure: f32,
pub windowID: SDL_WindowID,
}Expand description
Touch finger event structure (event.tfinger.*)
Coordinates in this event are normalized. x and y are normalized to a
range between 0.0f and 1.0f, relative to the window, so (0,0) is the top
left and (1,1) is the bottom right. Delta coordinates dx and dy are
normalized in the ranges of -1.0f (traversed all the way from the bottom or
right to all the way up or left) to 1.0f (traversed all the way from the
top or left to all the way down or right).
Note that while the coordinates are normalized, they are not clamped, which means in some circumstances you can get a value outside of this range. For example, a renderer using logical presentation might give a negative value when the touch is in the letterboxing. Some platforms might report a touch outside of the window, which will also be outside of the range.
Available Since: This struct is available since SDL 3.2.0.
Fields
type_: SDL_EventType< SDL_EVENT_FINGER_DOWN, SDL_EVENT_FINGER_UP, SDL_EVENT_FINGER_MOTION, or SDL_EVENT_FINGER_CANCELED
reserved: Uint32timestamp: Uint64< In nanoseconds, populated using SDL_GetTicksNS()
touchID: SDL_TouchID< The touch device id
fingerID: SDL_FingerIDx: f32< Normalized in the range 0…1
y: f32< Normalized in the range 0…1
dx: f32< Normalized in the range -1…1
dy: f32< Normalized in the range -1…1
pressure: f32< Normalized in the range 0…1
windowID: SDL_WindowID< The window underneath the finger, if any