pub type SDL_AppEvent_func = Option<unsafe extern "C" fn(appstate: *mut c_void, event: *mut SDL_Event) -> SDL_AppResult>;Expand description
Function pointer typedef for SDL_AppEvent.
These are used by SDL_EnterAppMainCallbacks. This mechanism operates behind the scenes for apps using the optional main callbacks. Apps that want to use this should just implement SDL_AppEvent directly.
Parameter: appstate an optional pointer, provided by the app in SDL_AppInit. Parameter: event the new event for the app to examine. Returns: SDL_APP_FAILURE to terminate with an error, SDL_APP_SUCCESS to terminate with success, SDL_APP_CONTINUE to continue.
Available Since: This datatype is available since SDL 3.2.0.
Aliased Type
pub enum SDL_AppEvent_func {
None,
Some(unsafe extern "C" fn(*mut c_void, *mut SDL_Event) -> SDL_AppResult),
}