pub type SDL_AppIterate_func = Option<unsafe extern "C" fn(appstate: *mut c_void) -> SDL_AppResult>;Expand description
Function pointer typedef for SDL_AppIterate.
These are used by SDL_EnterAppMainCallbacks. This mechanism operates behind the scenes for apps using the optional main callbacks. Apps that want to use this should just implement SDL_AppIterate directly.
Parameter: appstate an optional pointer, provided by the app in SDL_AppInit. Returns: SDL_APP_FAILURE to terminate with an error, SDL_APP_SUCCESS to terminate with success, SDL_APP_CONTINUE to continue.
Available Since: This datatype is available since SDL 3.2.0.
Aliased Type
pub enum SDL_AppIterate_func {
None,
Some(unsafe extern "C" fn(*mut c_void) -> SDL_AppResult),
}