pub type SDL_AppQuit_func = Option<unsafe extern "C" fn(appstate: *mut c_void, result: SDL_AppResult)>;Expand description
Function pointer typedef for SDL_AppQuit.
These are used by SDL_EnterAppMainCallbacks. This mechanism operates behind the scenes for apps using the optional main callbacks. Apps that want to use this should just implement SDL_AppEvent directly.
Parameter: appstate an optional pointer, provided by the app in SDL_AppInit. Parameter: result the result code that terminated the app (success or failure).
Available Since: This datatype is available since SDL 3.2.0.
Aliased Type
pub enum SDL_AppQuit_func {
None,
Some(unsafe extern "C" fn(*mut c_void, SDL_AppResult)),
}