pub type SDL_EnumeratePropertiesCallback = Option<unsafe extern "C" fn(userdata: *mut c_void, props: SDL_PropertiesID, name: *const c_char)>;Expand description
A callback used to enumerate all the properties in a group of properties.
This callback is called from SDL_EnumerateProperties(), and is called once per property in the set.
Parameter: userdata an app-defined pointer passed to the callback. Parameter: props the SDL_PropertiesID that is being enumerated. Parameter: name the next property name in the enumeration.
Thread Safety: SDL_EnumerateProperties holds a lock on props during this
callback.
Available Since: This datatype is available since SDL 3.2.0.
See Also: SDL_EnumerateProperties
Aliased Type
pub enum SDL_EnumeratePropertiesCallback {
None,
Some(unsafe extern "C" fn(*mut c_void, u32, *const i8)),
}