pub type SDL_ThreadID = Uint64;Expand description
A unique numeric ID that identifies a thread.
These are different from SDL_Thread objects, which are generally what an application will operate on, but having a way to uniquely identify a thread can be useful at times.
Available Since: This datatype is available since SDL 3.2.0.
See Also: SDL_GetThreadID See Also: SDL_GetCurrentThreadID