pub type SDL_malloc_func = Option<unsafe extern "C" fn(size: usize) -> *mut c_void>;Expand description
A callback used to implement SDL_malloc().
SDL will always ensure that the passed size is greater than 0.
Parameter: size the size to allocate. Returns: a pointer to the allocated memory, or NULL if allocation failed.
Thread Safety: It should be safe to call this callback from any thread.
Available Since: This datatype is available since SDL 3.2.0.
See Also: SDL_malloc See Also: SDL_GetOriginalMemoryFunctions See Also: SDL_GetMemoryFunctions See Also: SDL_SetMemoryFunctions
Aliased Type
pub enum SDL_malloc_func {
None,
Some(unsafe extern "C" fn(usize) -> *mut c_void),
}