pub type SDL_realloc_func = Option<unsafe extern "C" fn(mem: *mut c_void, size: usize) -> *mut c_void>;Expand description
A callback used to implement SDL_realloc().
SDL will always ensure that the passed size is greater than 0.
Parameter: mem a pointer to allocated memory to reallocate, or NULL. Parameter: size the new size of the memory. Returns: a pointer to the newly allocated memory, or NULL if allocation failed.
Thread Safety: It should be safe to call this callback from any thread.
Available Since: This datatype is available since SDL 3.2.0.
See Also: SDL_realloc See Also: SDL_GetOriginalMemoryFunctions See Also: SDL_GetMemoryFunctions See Also: SDL_SetMemoryFunctions
Aliased Type
pub enum SDL_realloc_func {
None,
Some(unsafe extern "C" fn(*mut c_void, usize) -> *mut c_void),
}